@@ -79,7 +79,7 @@ class Puppet::Daemon
   end
 
   def reexec
-    raise Puppet::DevError, "Cannot reexec unless ARGV arguments are set" unless argv
+    raise Puppet::DevError, _("Cannot reexec unless ARGV arguments are set") unless argv
     command = $0 + " " + argv.join(" ")
     Puppet.notice "Restarting with '#{command}'"
     stop(:exit => false)
@@ -88,17 +88,14 @@ class Puppet::Daemon
 
   def reload
     return unless agent
-    if agent.running?
-      Puppet.notice "Not triggering already-running agent"
-      return
-    end
-
     agent.run({:splay => false})
+  rescue Puppet::LockError
+    Puppet.notice "Not triggering already-running agent"
   end
 
   def restart
     Puppet::Application.restart!
-    reexec unless agent and agent.running?
+    reexec
   end
 
   def reopen_logs
@@ -141,11 +138,9 @@ class Puppet::Daemon
   end
 
   def start
-    set_signal_traps
-
     create_pidfile
 
-    raise Puppet::DevError, "Daemons must have an agent, server, or both" unless agent or server
+    raise Puppet::DevError, _("Daemons must have an agent, server, or both") unless agent or server
 
     # Start the listening server, if required.
     server.start if server
