@@ -5,6 +5,7 @@ require 'puppet/file_serving/mount'
 class Puppet::FileServing::Mount::Modules < Puppet::FileServing::Mount
   # Return an instance of the appropriate class.
   def find(path, request)
+    raise _("No module specified") if path.to_s.empty?
     module_name, relative_path = path.split("/", 2)
     return nil unless mod = request.environment.module(module_name)
 
@@ -12,11 +13,9 @@ class Puppet::FileServing::Mount::Modules < Puppet::FileServing::Mount
   end
 
   def search(path, request)
-    module_name, relative_path = path.split("/", 2)
-    return nil unless mod = request.environment.module(module_name)
-
-    return nil unless path = mod.file(relative_path)
-    [path]
+    if result = find(path, request)
+      [result]
+    end
   end
 
   def valid?
