@@ -6,4 +6,7 @@ class Puppet::Resource::StoreConfigs < Puppet::Indirector::StoreConfigs
 
   desc %q{Part of the "storeconfigs" feature. Should not be directly set by end users.}
 
+  def allow_remote_requests?
+    false
+  end
 end
