@@ -5,6 +5,8 @@ class Puppet::Indirector::Status::Local < Puppet::Indirector::Code
   desc "Get status locally. Only used internally."
 
   def find( *anything )
-    model.new
+    status = model.new
+    status.version= Puppet.version
+    status
   end
 end
