@@ -1,5 +1,5 @@
 require 'fileutils'
-require 'json'
+require 'puppet/util/json'
 require 'puppet/file_system'
 require 'pathspec'
 require 'facter'
@@ -103,7 +103,7 @@ module Puppet::ModuleTool
           end
 
           # make dir tree, copy files, and add symlinks to the symlinks list
-          dest = "#{build_path}/#{rel.to_s}"
+          dest = "#{build_path}/#{rel}"
           if File.directory? path
             FileUtils.mkdir dest, :mode => File.stat(path).mode
           elsif Puppet::FileSystem.symlink? path
@@ -140,7 +140,7 @@ module Puppet::ModuleTool
         end
 
         Puppet::FileSystem.open(File.join(build_path, 'checksums.json'), nil, 'wb') do |f|
-          f.write(JSON.pretty_generate(Checksums.new(build_path)))
+          f.write(Puppet::Util::Json.dump(Checksums.new(build_path), :pretty => true))
         end
       end
 
