@@ -10,7 +10,7 @@ module Puppet::Pops::Parser::InterpolationSupport
 
   # This is the starting point for a double quoted string with possible interpolation
   # The structure mimics that of the grammar.
-  # The logic is explicit (where the former implementation used parameters/strucures) given to a
+  # The logic is explicit (where the former implementation used parameters/structures) given to a
   # generic handler.
   # (This is both easier to understand and faster).
   #
@@ -23,7 +23,7 @@ module Puppet::Pops::Parser::InterpolationSupport
     value,terminator = slurp_dqstring()
     text = value
     after = scn.pos
-    while true
+    loop do
       case terminator
       when '"'
         # simple case, there was no interpolation, return directly
@@ -40,7 +40,7 @@ module Puppet::Pops::Parser::InterpolationSupport
         if varname = scn.scan(PATTERN_VARIABLE)
           # The $ is counted towards the variable
           enqueue_completed([:DQPRE, text, after-before-1], before)
-          enqueue_completed([:VARIABLE, varname, scn.pos - after + 1], after -1)
+          enqueue_completed([:VARIABLE, varname, scn.pos - after + 1], after - 1)
           break
         else
           # false $ variable start
@@ -63,7 +63,7 @@ module Puppet::Pops::Parser::InterpolationSupport
     value,terminator = slurp_dqstring
     text = value
     after = scn.pos
-    while true
+    loop do
       case terminator
       when '"'
         # simple case, there was no further interpolation, return directly
@@ -81,7 +81,7 @@ module Puppet::Pops::Parser::InterpolationSupport
         if varname = scn.scan(PATTERN_VARIABLE)
           # The $ is counted towards the variable
           enqueue_completed([:DQMID, text, after-before-1], before)
-          enqueue_completed([:VARIABLE, varname, scn.pos - after +1], after -1)
+          enqueue_completed([:VARIABLE, varname, scn.pos - after + 1], after - 1)
           break
         else
           # false $ variable start
@@ -107,7 +107,7 @@ module Puppet::Pops::Parser::InterpolationSupport
     value,terminator = slurp_uqstring()
     text = value
     after = scn.pos
-    while true
+    loop do
       case terminator
       when ''
         # simple case, there was no interpolation, return directly
@@ -125,7 +125,7 @@ module Puppet::Pops::Parser::InterpolationSupport
         if varname = scn.scan(PATTERN_VARIABLE)
           # The $ is counted towards the variable
           enqueue_completed([:DQPRE, text, after-before-1], before)
-          enqueue_completed([:VARIABLE, varname, scn.pos - after + 1], after -1)
+          enqueue_completed([:VARIABLE, varname, scn.pos - after + 1], after - 1)
           break
         else
           # false $ variable start
@@ -147,7 +147,7 @@ module Puppet::Pops::Parser::InterpolationSupport
     value,terminator = slurp_uqstring
     text = value
     after = scn.pos
-    while true
+    loop do
       case terminator
       when ''
         # simple case, there was no further interpolation, return directly
@@ -165,7 +165,7 @@ module Puppet::Pops::Parser::InterpolationSupport
         if varname = scn.scan(PATTERN_VARIABLE)
           # The $ is counted towards the variable
           enqueue_completed([:DQMID, text, after-before-1], before)
-          enqueue_completed([:VARIABLE, varname, scn.pos - after +1], after -1)
+          enqueue_completed([:VARIABLE, varname, scn.pos - after + 1], after - 1)
           break
         else
           # false $ variable start
@@ -185,11 +185,18 @@ module Puppet::Pops::Parser::InterpolationSupport
     scn = @scanner
     ctx = @lexing_context
     queue = @token_queue
+    queue_base = @token_queue[0]
 
     scn.skip(self.class::PATTERN_WS)
     queue_size = queue.size
     until scn.eos? do
       if token = lex_token
+        if token.equal?(queue_base)
+          # A nested #interpolate_dq call shifted the queue_base token from the @token_queue. It must
+          # be put back since it is intended for the top level #interpolate_dq call only.
+          queue.insert(0, token)
+          next # all relevant tokens are already on the queue
+        end
         token_name = token[0]
         ctx[:after] = token_name
         if token_name == :RBRACE && ctx[:brace_count] == brace_count
@@ -214,7 +221,7 @@ module Puppet::Pops::Parser::InterpolationSupport
 
   def transform_to_variable(token)
     token_name = token[0]
-    if [:NUMBER, :NAME, :WORD].include?(token_name) || self.class::KEYWORD_NAMES[token_name]
+    if [:NUMBER, :NAME, :WORD].include?(token_name) || self.class::KEYWORD_NAMES[token_name] || @taskm_keywords[token_name]
       t = token[1]
       ta = t.token_array
       [:VARIABLE, self.class::TokenValue.new([:VARIABLE, ta[1], ta[2]], t.offset, t.locator)]
