@@ -1,3 +1,4 @@
+module Puppet::Pops
 # A Visitor performs delegation to a given receiver based on the configuration of the Visitor.
 # A new visitor is created with a given receiver, a method prefix, min, and max argument counts.
 # e.g.
@@ -9,7 +10,7 @@
 # Raises RuntimeError if there are too few or too many arguments, or if the receiver is not
 # configured to handle a given visiting object.
 #
-class Puppet::Pops::Visitor
+class Visitor
   attr_reader :receiver, :message, :min_args, :max_args, :cache
   def initialize(receiver, message, min_args=0, max_args=nil)
     raise ArgumentError.new("min_args must be >= 0") if min_args < 0
@@ -27,8 +28,7 @@ class Puppet::Pops::Visitor
     visit_this(@receiver, thing, args)
   end
 
-  DOUBLE_COLON = '::'
-  NO_ARGS = [].freeze
+  NO_ARGS = EMPTY_ARRAY
 
   # Visit an explicit receiver
   def visit_this(receiver, thing, args)
@@ -51,6 +51,27 @@ class Puppet::Pops::Visitor
     raise "Visitor Error: the configured receiver (#{receiver.class}) can't handle instance of: #{thing.class}"
   end
 
+  # Visit an explicit receiver
+  def visit_this_class(receiver, clazz, args)
+    raise "Visitor Error: Too few arguments passed. min = #{@min_args}" unless args.length >= @min_args
+    if @max_args
+      raise "Visitor Error: Too many arguments passed. max = #{@max_args}" unless args.length <= @max_args
+    end
+    if method_name = @cache[clazz]
+      return receiver.send(method_name, clazz, *args)
+    else
+      clazz.ancestors().each do |ancestor|
+        name = ancestor.name
+        next if name.nil?
+        method_name = :"#{@message}_#{name.split(DOUBLE_COLON).last}"
+        next unless receiver.respond_to?(method_name, true)
+        @cache[clazz] = method_name
+        return receiver.send(method_name, clazz, *args)
+      end
+    end
+    raise "Visitor Error: the configured receiver (#{receiver.class}) can't handle instance of: #{clazz}"
+  end
+
   # Visit an explicit receiver with 0 args
   # (This is ~30% faster than calling the general method)
   #
@@ -92,3 +113,4 @@ class Puppet::Pops::Visitor
   end
 
 end
+end
