@@ -104,7 +104,7 @@ DOC
   # Specify how we expect to interact with our certificate authority.
   def self.ca_location=(mode)
     modes = CA_MODES.collect { |m, vals| m.to_s }.join(", ")
-    raise ArgumentError, "CA Mode can only be one of: #{modes}" unless CA_MODES.include?(mode)
+    raise ArgumentError, _("CA Mode can only be one of: %{modes}") % { modes: modes } unless CA_MODES.include?(mode)
 
     @ca_location = mode
 
@@ -207,18 +207,18 @@ DOC
   end
 
   def validate_certificate_with_key
-    raise Puppet::Error, "No certificate to validate." unless certificate
-    raise Puppet::Error, "No private key with which to validate certificate with fingerprint: #{certificate.fingerprint}" unless key
+    raise Puppet::Error, _("No certificate to validate.") unless certificate
+    raise Puppet::Error, _("No private key with which to validate certificate with fingerprint: %{fingerprint}") % { fingerprint: certificate.fingerprint } unless key
     unless certificate.content.check_private_key(key.content)
-      raise Puppet::Error, <<ERROR_STRING
-The certificate retrieved from the master does not match the agent's private key.
-Certificate fingerprint: #{certificate.fingerprint}
-To fix this, remove the certificate from both the master and the agent and then start a puppet run, which will automatically regenerate a certficate.
+      raise Puppet::Error, _(<<ERROR_STRING) % { fingerprint: certificate.fingerprint, cert_name: Puppet[:certname], ssl_dir: Puppet[:ssldir], cert_dir: Puppet[:certdir].tr('/', '\\') }
+The certificate retrieved from the master does not match the agent's private key. Did you forget to run as root?
+Certificate fingerprint: %{fingerprint}
+To fix this, remove the certificate from both the master and the agent and then start a puppet run, which will automatically regenerate a certificate.
 On the master:
-  puppet cert clean #{Puppet[:certname]}
+  puppet cert clean %{cert_name}
 On the agent:
-  1a. On most platforms: find #{Puppet[:ssldir]} -name #{Puppet[:certname]}.pem -delete
-  1b. On Windows: del "#{Puppet[:ssldir]}/#{Puppet[:certname]}.pem" /f
+  1a. On most platforms: find %{ssl_dir} -name %{cert_name}.pem -delete
+  1b. On Windows: del "%{cert_dir}\\%{cert_name}.pem" /f
   2. puppet agent -t
 ERROR_STRING
     end
@@ -227,13 +227,35 @@ ERROR_STRING
   # Generate all necessary parts of our ssl host.
   def generate
     generate_key unless key
-    generate_certificate_request unless certificate_request
+    # ask indirector to find any existing requests and download them
+    existing_request = certificate_request
+
+    # if CSR downloaded from master, but the local keypair was just generated and
+    # does not match the public key in the CSR, fail hard
+    if !existing_request.nil? &&
+      (key.content.public_key.to_s != existing_request.content.public_key.to_s)
+
+      raise Puppet::Error, _(<<ERROR_STRING) % { fingerprint: existing_request.fingerprint, csr_public_key: existing_request.content.public_key.to_text, agent_public_key: key.content.public_key.to_text, cert_name: Puppet[:certname], ssl_dir: Puppet[:ssldir], cert_dir: Puppet[:certdir].tr('/', '\\') }
+The CSR retrieved from the master does not match the agent's public key.
+CSR fingerprint: %{fingerprint}
+CSR public key: %{csr_public_key}
+Agent public key: %{agent_public_key}
+To fix this, remove the CSR from both the master and the agent and then start a puppet run, which will automatically regenerate a CSR.
+On the master:
+  puppet cert clean %{cert_name}
+On the agent:
+  1a. On most platforms: find %{ssl_dir} -name %{cert_name}.pem -delete
+  1b. On Windows: del "%{cert_dir}\\%{cert_name}.pem" /f
+  2. puppet agent -t
+ERROR_STRING
+    end
+    generate_certificate_request unless existing_request
 
     # If we can get a CA instance, then we're a valid CA, and we
     # should use it to sign our request; else, just try to read
     # the cert.
     if ! certificate and ca = Puppet::SSL::CertificateAuthority.instance
-      ca.sign(self.name, true)
+      ca.sign(self.name, {allow_dns_alt_names: true})
     end
   end
 
@@ -252,43 +274,29 @@ ERROR_STRING
   # Create/return a store that uses our SSL info to validate
   # connections.
   def ssl_store(purpose = OpenSSL::X509::PURPOSE_ANY)
-    unless @ssl_store
-      @ssl_store = OpenSSL::X509::Store.new
-      @ssl_store.purpose = purpose
-
-      # Use the file path here, because we don't want to cause
-      # a lookup in the middle of setting our ssl connection.
-      @ssl_store.add_file(Puppet[:localcacert])
-
-      # If we're doing revocation and there's a CRL, add it to our store.
-      if Puppet.settings[:certificate_revocation]
-        if crl = Puppet::SSL::CertificateRevocationList.indirection.find(CA_NAME)
-          @ssl_store.flags = OpenSSL::X509::V_FLAG_CRL_CHECK_ALL|OpenSSL::X509::V_FLAG_CRL_CHECK
-          @ssl_store.add_crl(crl.content)
-        end
-      end
-      return @ssl_store
+    if @ssl_store.nil?
+      @ssl_store = build_ssl_store(purpose)
     end
     @ssl_store
   end
 
   def to_data_hash
     my_cert = Puppet::SSL::Certificate.indirection.find(name)
-    result = { :name  => name }
+    result = { 'name'  => name }
 
     my_state = state
 
-    result[:state] = my_state
-    result[:desired_state] = desired_state if desired_state
+    result['state'] = my_state
+    result['desired_state'] = desired_state if desired_state
 
     thing_to_use = (my_state == 'requested') ? certificate_request : my_cert
 
     # this is for backwards-compatibility
     # we should deprecate it and transition people to using
-    # pson[:fingerprints][:default]
+    # json[:fingerprints][:default]
     # It appears that we have no internal consumers of this api
     # --jeffweiss 30 aug 2012
-    result[:fingerprint] = thing_to_use.fingerprint
+    result['fingerprint'] = thing_to_use.fingerprint
 
     # The above fingerprint doesn't tell us what message digest algorithm was used
     # No problem, except that the default is changing between 2.7 and 3.0. Also, as
@@ -297,13 +305,13 @@ ERROR_STRING
     # So, when we add the newer fingerprints, we're explicit about the hashing
     # algorithm used.
     # --jeffweiss 31 july 2012
-    result[:fingerprints] = {}
-    result[:fingerprints][:default] = thing_to_use.fingerprint
+    result['fingerprints'] = {}
+    result['fingerprints']['default'] = thing_to_use.fingerprint
 
     suitable_message_digest_algorithms.each do |md|
-      result[:fingerprints][md] = thing_to_use.fingerprint md
+      result['fingerprints'][md.to_s] = thing_to_use.fingerprint md
     end
-    result[:dns_alt_names] = thing_to_use.subject_alt_names
+    result['dns_alt_names'] = thing_to_use.subject_alt_names
 
     result
   end
@@ -312,7 +320,7 @@ ERROR_STRING
   # configurable
   # --jeffweiss 29 aug 2012
   def suitable_message_digest_algorithms
-    [:SHA1, :SHA256, :SHA512]
+    [:SHA1, :SHA224, :SHA256, :SHA384, :SHA512]
   end
 
   # Attempt to retrieve a cert, if we don't already have one.
@@ -322,9 +330,9 @@ ERROR_STRING
       generate
       return if certificate
     rescue StandardError => detail
-      Puppet.log_exception(detail, "Could not request certificate: #{detail.message}")
+      Puppet.log_exception(detail, _("Could not request certificate: %{message}") % { message: detail.message })
       if time < 1
-        puts "Exiting; failed to retrieve certificate and waitforcert is disabled"
+        puts _("Exiting; failed to retrieve certificate and waitforcert is disabled")
         exit(1)
       else
         sleep(time)
@@ -333,17 +341,17 @@ ERROR_STRING
     end
 
     if time < 1
-      puts "Exiting; no certificate found and waitforcert is disabled"
+      puts _("Exiting; no certificate found and waitforcert is disabled")
       exit(1)
     end
 
-    while true
+    loop do
       sleep time
       begin
         break if certificate
-        Puppet.notice "Did not receive certificate"
+        Puppet.notice _("Did not receive certificate")
       rescue StandardError => detail
-        Puppet.log_exception(detail, "Could not request certificate: #{detail.message}")
+        Puppet.log_exception(detail, _("Could not request certificate: %{message}") % { message: detail.message })
       end
     end
   end
@@ -360,6 +368,33 @@ ERROR_STRING
       return 'revoked'
     end
   end
+
+  private
+
+  def build_ssl_store(purpose)
+    store = OpenSSL::X509::Store.new
+    store.purpose = purpose
+
+    # Use the file path here, because we don't want to cause
+    # a lookup in the middle of setting our ssl connection.
+    store.add_file(Puppet[:localcacert])
+
+    # If we're doing revocation and there's a CRL, add it to our store.
+    if Puppet.lookup(:certificate_revocation)
+      if crl = Puppet::SSL::CertificateRevocationList.indirection.find(CA_NAME)
+        flags = OpenSSL::X509::V_FLAG_CRL_CHECK
+        if Puppet.lookup(:certificate_revocation) == :chain
+          flags |= OpenSSL::X509::V_FLAG_CRL_CHECK_ALL
+        end
+
+        store.flags = flags
+        store.add_crl(crl.content)
+      else
+        Puppet.debug _("Certificate revocation checking is enabled but a CRL cannot be found; CRL checking will not be performed.")
+      end
+    end
+    store
+  end
 end
 
 require 'puppet/ssl/certificate_authority'
