@@ -14,8 +14,7 @@ module Puppet
 
       **Autorequires:** If Puppet is managing any parents of a mount resource ---
       that is, other mount points higher up in the filesystem --- the child
-      mount will autorequire them. If Puppet is managing the file path of a
-      mount point, the mount resource will autorequire it.
+      mount will autorequire them.
 
       **Autobefores:**  If Puppet is managing any child file paths of a mount
       point, the mount resource will autobefore them."
@@ -66,7 +65,7 @@ module Puppet
                      # the wrong attributes so I sync AFTER the umount
           return :mount_unmounted
         else
-          raise Puppet::Error, "Unexpected change from #{current_value} to unmounted}"
+          raise Puppet::Error, _("Unexpected change from %{current} to unmounted") % { current: current_value }
         end
       end
 
@@ -113,7 +112,7 @@ module Puppet
         # Determine if there are any out-of-sync properties.
         oos = @resource.send(:properties).find_all do |prop|
           unless currentvalues.include?(prop)
-            raise Puppet::DevError, "Parent has property %s but it doesn't appear in the current values", [prop.name]
+            raise Puppet::DevError, _("Parent has property %{name} but it doesn't appear in the current values") % { name: prop.name }
           end
           if prop.name == :ensure
             false
@@ -132,7 +131,7 @@ module Puppet
         path, depending on the operating system."
 
       validate do |value|
-        raise Puppet::Error, "device must not contain whitespace: #{value}" if value =~ /\s/
+        raise Puppet::Error, _("device must not contain whitespace: %{value}") % { value: value } if value =~ /\s/
       end
     end
 
@@ -158,7 +157,7 @@ module Puppet
       end
 
       validate do |value|
-        raise Puppet::Error, "blockdevice must not contain whitespace: #{value}" if value =~ /\s/
+        raise Puppet::Error, _("blockdevice must not contain whitespace: %{value}") % { value: value } if value =~ /\s/
       end
     end
 
@@ -167,19 +166,23 @@ module Puppet
         operating system.  This is a required option."
 
       validate do |value|
-        raise Puppet::Error, "fstype must not contain whitespace: #{value}" if value =~ /\s/
-        raise Puppet::Error, "fstype must not be an empty string" if value.empty?
+        raise Puppet::Error, _("fstype must not contain whitespace: %{value}") % { value: value } if value =~ /\s/
+        raise Puppet::Error, _("fstype must not be an empty string") if value.empty?
       end
     end
 
     newproperty(:options) do
       desc "A single string containing options for the mount, as they would
-        appear in fstab. For many platforms this is a comma delimited string.
-        Consult the fstab(5) man page for system-specific details."
+        appear in fstab on Linux. For many platforms this is a comma-delimited
+        string. Consult the fstab(5) man page for system-specific details.
+        AIX options other than dev, nodename, or vfs can be defined here. If
+        specified, AIX options of account, boot, check, free, mount, size,
+        type, vol, log, and quota must be ordered alphabetically at the end of
+        the list."
 
       validate do |value|
-        raise Puppet::Error, "options must not contain whitespace: #{value}" if value =~ /\s/
-        raise Puppet::Error, "options must not be an empty string" if value.empty?
+        raise Puppet::Error, _("options must not contain whitespace: %{value}") % { value: value } if value =~ /\s/
+        raise Puppet::Error, _("options must not be an empty string") if value.empty?
       end
     end
 
@@ -244,7 +247,7 @@ module Puppet
       isnamevar
 
       validate do |value|
-        raise Puppet::Error, "name must not contain whitespace: #{value}" if value =~ /\s/
+        raise Puppet::Error, _("name must not contain whitespace: %{value}") % { value: value } if value =~ /\s/
       end
 
       munge do |value|
@@ -297,14 +300,11 @@ module Puppet
       dependencies[0..-2]
     end
 
-    # Autorequire the mount point's file resource
-    autorequire(:file) { Pathname.new(self[:name]) }
-
     # Autobefore the mount point's child file paths
     autobefore(:file) do
       dependencies = []
       file_resources = catalog.resources.select { |resource| resource.type == :file }
-      children_file_resources = file_resources.select { |resource| File.expand_path(resource[:path]) =~ %r(#{self[:name]}/.) }
+      children_file_resources = file_resources.select { |resource| File.expand_path(resource[:path]) =~ %r(^#{self[:name]}/.) }
       children_file_resources.each do |child|
         dependencies.push Pathname.new(child[:path])
       end
