@@ -97,7 +97,7 @@ end
         apply.options[:catalog] = file_containing('manifest', catalog.to_json)
 
         Puppet[:environmentpath] = envdir
-        Puppet::Pops::Loader::Runtime3TypeLoader.any_instance.expects(:find).never
+        expect_any_instance_of(Puppet::Pops::Loader::Runtime3TypeLoader).not_to receive(:find)
         expect { apply.run }.to have_printed(/the Puppet::Type says hello.*applytest was here/m)
       end
 
@@ -108,8 +108,8 @@ end
         tn = Puppet::Pops::Loader::TypedName.new(:resource_type_pp, 'applytest')
         rt = Puppet::Pops::Resource::ResourceTypeImpl.new('applytest', [Puppet::Pops::Resource::Param.new(String, 'message')], [Puppet::Pops::Resource::Param.new(String, 'name', true)])
 
-        compiler.loaders.runtime3_type_loader.instance_variable_get(:@resource_3x_loader).expects(:set_entry).once.with(tn, rt, is_a(String))
-          .returns(Puppet::Pops::Loader::Loader::NamedEntry.new(tn, rt, nil))
+        expect(compiler.loaders.runtime3_type_loader.instance_variable_get(:@resource_3x_loader)).to receive(:set_entry).once.with(tn, rt, instance_of(String))
+          .and_return(Puppet::Pops::Loader::Loader::NamedEntry.new(tn, rt, nil))
         expect { compiler.compile }.not_to have_printed(/the Puppet::Type says hello/)
       end
 
@@ -237,7 +237,7 @@ end
     Puppet.override(:current_environment => special) do
       Puppet[:environment] = 'special'
       puppet = Puppet::Application[:apply]
-      puppet.stubs(:command_line).returns(stub('command_line', :args => [manifest]))
+      allow(puppet).to receive(:command_line).and_return(double('command_line', :args => [manifest]))
       expect { puppet.run_command }.to exit_with(0)
     end
 
@@ -248,7 +248,7 @@ end
     manifest = file_containing("manifest.pp", "notice(\"$server_facts\")")
 
     puppet = Puppet::Application[:apply]
-    puppet.stubs(:command_line).returns(stub('command_line', :args => [manifest]))
+    allow(puppet).to receive(:command_line).and_return(double('command_line', :args => [manifest]))
 
     expect { puppet.run_command }.to exit_with(0)
 
@@ -269,7 +269,7 @@ end
       Puppet[:node_terminus] = 'exec'
       Puppet[:external_nodes] = enc
       puppet = Puppet::Application[:apply]
-      puppet.stubs(:command_line).returns(stub('command_line', :args => [manifest]))
+      allow(puppet).to receive(:command_line).and_return(double('command_line', :args => [manifest]))
       expect { puppet.run_command }.to exit_with(0)
     end
 
@@ -279,7 +279,7 @@ end
   context "handles errors" do
     it "logs compile errors once" do
       Puppet.initialize_settings([])
-      apply = Puppet::Application.find(:apply).new(stub('command_line', :subcommand_name => :apply, :args => []))
+      apply = Puppet::Application.find(:apply).new(double('command_line', :subcommand_name => :apply, :args => []))
       apply.options[:code] = '08'
 
       msg = 'valid octal'
@@ -294,7 +294,7 @@ end
 
     it "logs compile post processing errors once" do
       Puppet.initialize_settings([])
-      apply = Puppet::Application.find(:apply).new(stub('command_line', :subcommand_name => :apply, :args => []))
+      apply = Puppet::Application.find(:apply).new(double('command_line', :subcommand_name => :apply, :args => []))
       path = File.expand_path('/tmp/content_file_test.Q634Dlmtime')
       apply.options[:code] = "file { '#{path}':
         content => 'This is the test file content',
@@ -336,7 +336,7 @@ end
 
     def init_cli_args_and_apply_app(args, execute)
       Puppet.initialize_settings(args)
-      puppet = Puppet::Application.find(:apply).new(stub('command_line', :subcommand_name => :apply, :args => args))
+      puppet = Puppet::Application.find(:apply).new(double('command_line', :subcommand_name => :apply, :args => args))
       puppet.options[:code] = execute
       return puppet
     end
@@ -470,14 +470,15 @@ class amod::bad_type {
         catalog = compile_to_catalog(execute, node)
         apply = Puppet::Application[:apply]
         apply.options[:catalog] = file_containing('manifest', catalog.to_json)
-        apply.expects(:apply_catalog).with do |cat|
-          cat.resource(:notify, 'rx')['message'].is_a?(String)
-          cat.resource(:notify, 'bin')['message'].is_a?(String)
-          cat.resource(:notify, 'ver')['message'].is_a?(String)
-          cat.resource(:notify, 'vrange')['message'].is_a?(String)
-          cat.resource(:notify, 'tspan')['message'].is_a?(String)
-          cat.resource(:notify, 'tstamp')['message'].is_a?(String)
+        expect(apply).to receive(:apply_catalog) do |cat|
+          expect(cat.resource(:notify, 'rx')['message']).to be_a(String)
+          expect(cat.resource(:notify, 'bin')['message']).to be_a(String)
+          expect(cat.resource(:notify, 'ver')['message']).to be_a(String)
+          expect(cat.resource(:notify, 'vrange')['message']).to be_a(String)
+          expect(cat.resource(:notify, 'tspan')['message']).to be_a(String)
+          expect(cat.resource(:notify, 'tstamp')['message']).to be_a(String)
         end
+
         apply.run
       end
 
@@ -485,9 +486,10 @@ class amod::bad_type {
         json = compile_to_catalog('include amod::bad_type', node).to_json
         apply = Puppet::Application[:apply]
         apply.options[:catalog] = file_containing('manifest', json)
-        apply.expects(:apply_catalog).with do |catalog|
-          catalog.resource(:notify, 'bogus')['message'].is_a?(String)
+        expect(apply).to receive(:apply_catalog) do |cat|
+          expect(cat.resource(:notify, 'bogus')['message']).to be_a(String)
         end
+
         apply.run
       end
 
@@ -509,17 +511,17 @@ class amod::bad_type {
         catalog = compile_to_catalog(execute, node)
         apply = Puppet::Application[:apply]
         apply.options[:catalog] = file_containing('manifest', catalog.to_json)
-        apply.expects(:apply_catalog).with do |cat|
-          cat.resource(:notify, 'rx')['message'].is_a?(Regexp)
-          cat.resource(:notify, 'bin')['message'].is_a?(Puppet::Pops::Types::PBinaryType::Binary)
-          cat.resource(:notify, 'ver')['message'].is_a?(SemanticPuppet::Version)
-          cat.resource(:notify, 'vrange')['message'].is_a?(SemanticPuppet::VersionRange)
-          cat.resource(:notify, 'tspan')['message'].is_a?(Puppet::Pops::Time::Timespan)
-          cat.resource(:notify, 'tstamp')['message'].is_a?(Puppet::Pops::Time::Timestamp)
+        expect(apply).to receive(:apply_catalog) do |cat|
+          expect(cat.resource(:notify, 'rx')['message']).to be_a(Regexp)
+          expect(cat.resource(:notify, 'bin')['message']).to be_a(Puppet::Pops::Types::PBinaryType::Binary)
+          expect(cat.resource(:notify, 'ver')['message']).to be_a(SemanticPuppet::Version)
+          expect(cat.resource(:notify, 'vrange')['message']).to be_a(SemanticPuppet::VersionRange)
+          expect(cat.resource(:notify, 'tspan')['message']).to be_a(Puppet::Pops::Time::Timespan)
+          expect(cat.resource(:notify, 'tstamp')['message']).to be_a(Puppet::Pops::Time::Timestamp)
         end
+
         apply.run
       end
     end
-
   end
 end
