@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 require 'puppet_spec/files'
 require 'puppet/application/doc'
@@ -8,7 +7,7 @@ describe Puppet::Application::Doc do
 
   it "should respect the -o option" do
     puppetdoc = Puppet::Application[:doc]
-    puppetdoc.command_line.stubs(:args).returns(['foo', '-o', 'bar'])
+    allow(puppetdoc.command_line).to receive(:args).and_return(['foo', '-o', 'bar'])
     puppetdoc.parse_options
     expect(puppetdoc.options[:outputdir]).to eq('bar')
   end
