@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 provider = Puppet::Type.type(:service).provider(:init)
@@ -6,7 +5,7 @@ provider = Puppet::Type.type(:service).provider(:init)
 describe provider do
   describe "when running on FreeBSD" do
     before :each do
-      Facter.stubs(:value).with(:operatingsystem).returns 'FreeBSD'
+      allow(Facter).to receive(:value).with(:operatingsystem).and_return('FreeBSD')
     end
 
     it "should set its default path to include /etc/rc.d and /usr/local/etc/rc.d" do
@@ -16,7 +15,7 @@ describe provider do
 
   describe "when running on HP-UX" do
     before :each do
-      Facter.stubs(:value).with(:operatingsystem).returns 'HP-UX'
+      allow(Facter).to receive(:value).with(:operatingsystem).and_return('HP-UX')
     end
 
     it "should set its default path to include /sbin/init.d" do
@@ -26,7 +25,7 @@ describe provider do
 
   describe "when running on Archlinux" do
     before :each do
-      Facter.stubs(:value).with(:operatingsystem).returns 'Archlinux'
+      allow(Facter).to receive(:value).with(:operatingsystem).and_return('Archlinux')
     end
 
     it "should set its default path to include /etc/rc.d" do
@@ -36,7 +35,7 @@ describe provider do
 
   describe "when not running on FreeBSD, HP-UX or Archlinux" do
     before :each do
-      Facter.stubs(:value).with(:operatingsystem).returns 'RedHat'
+      allow(Facter).to receive(:value).with(:operatingsystem).and_return('RedHat')
     end
 
     it "should set its default path to include /etc/init.d" do
