@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 require 'puppet_spec/compiler'
 
@@ -9,7 +8,7 @@ describe Puppet::Transaction do
   include PuppetSpec::Compiler
 
   before do
-    Puppet::Util::Storage.stubs(:store)
+    allow(Puppet::Util::Storage).to receive(:store)
   end
 
   def mk_catalog(*resources)
@@ -37,14 +36,14 @@ describe Puppet::Transaction do
 
     child_resource = Puppet::Type.type(:file).new :path => make_absolute("/foo/bar/baz"), :backup => false
 
-    resource.expects(:eval_generate).returns([child_resource])
+    expect(resource).to receive(:eval_generate).and_return([child_resource])
 
     transaction = Puppet::Transaction.new(catalog, nil, Puppet::Graph::RandomPrioritizer.new)
 
-    resource.expects(:retrieve).raises "this is a failure"
-    resource.stubs(:err)
+    expect(resource).to receive(:retrieve).and_raise("this is a failure")
+    allow(resource).to receive(:err)
 
-    child_resource.expects(:retrieve).never
+    expect(child_resource).not_to receive(:retrieve)
 
     transaction.evaluate
   end
@@ -57,7 +56,7 @@ describe Puppet::Transaction do
 
     transaction = Puppet::Transaction.new(catalog, nil, Puppet::Graph::RandomPrioritizer.new)
 
-    resource.expects(:evaluate).never
+    expect(resource).not_to receive(:evaluate)
 
     transaction.evaluate
   end
@@ -82,7 +81,7 @@ describe Puppet::Transaction do
 
     transaction = Puppet::Transaction.new(catalog, nil, Puppet::Graph::RandomPrioritizer.new)
 
-    resource.expects(:evaluate).never
+    expect(resource).not_to receive(:evaluate)
 
     transaction.evaluate
   end
@@ -95,7 +94,7 @@ describe Puppet::Transaction do
     transaction = Puppet::Transaction.new(catalog, nil, Puppet::Graph::RandomPrioritizer.new)
     transaction.for_network_device = false
 
-    transaction.expects(:apply).never.with(resource, nil)
+    expect(transaction).not_to receive(:apply).with(resource, nil)
 
     transaction.evaluate
     expect(transaction.resource_status(resource)).to be_skipped
@@ -109,7 +108,7 @@ describe Puppet::Transaction do
     transaction = Puppet::Transaction.new(catalog, nil, Puppet::Graph::RandomPrioritizer.new)
     transaction.for_network_device = true
 
-    transaction.expects(:apply).never.with(resource, nil)
+    expect(transaction).not_to receive(:apply).with(resource, nil)
 
     transaction.evaluate
     expect(transaction.resource_status(resource)).to be_skipped
@@ -123,7 +122,7 @@ describe Puppet::Transaction do
     transaction = Puppet::Transaction.new(catalog, nil, Puppet::Graph::RandomPrioritizer.new)
     transaction.for_network_device = true
 
-    transaction.expects(:apply).with(resource, nil)
+    expect(transaction).to receive(:apply).with(resource, nil)
 
     transaction.evaluate
     expect(transaction.resource_status(resource)).not_to be_skipped
@@ -137,7 +136,7 @@ describe Puppet::Transaction do
     transaction = Puppet::Transaction.new(catalog, nil, Puppet::Graph::RandomPrioritizer.new)
     transaction.for_network_device = true
 
-    transaction.expects(:apply).with(resource, nil)
+    expect(transaction).to receive(:apply).with(resource, nil)
 
     transaction.evaluate
     expect(transaction.resource_status(resource)).not_to be_skipped
@@ -163,7 +162,7 @@ describe Puppet::Transaction do
     ecomp[:subscribe] = Puppet::Resource.new(:foo, "file")
     exec[:refreshonly] = true
 
-    exec.expects(:refresh)
+    expect(exec).to receive(:refresh)
     catalog.apply
   end
 
@@ -227,7 +226,7 @@ describe Puppet::Transaction do
     notify = Puppet::Type.type(:notify).new(
       :title => "foo"
     )
-    notify.expects(:pre_run_check).raises(Puppet::Error, "fail for testing")
+    expect(notify).to receive(:pre_run_check).and_raise(Puppet::Error, "fail for testing")
 
     catalog = mk_catalog(file, notify)
     expect { catalog.apply }.to raise_error(Puppet::Error, /Some pre-run checks failed/)
@@ -260,7 +259,7 @@ describe Puppet::Transaction do
       :title => "two"
     )
 
-    exec1.stubs(:err)
+    allow(exec1).to receive(:err)
 
     catalog = mk_catalog(file, exec1, exec2)
     catalog.apply
@@ -317,8 +316,8 @@ describe Puppet::Transaction do
           :command     => touch(file1),
         )
 
-        exec1.stubs(:eval_generate).returns(
-          [ (Puppet::Type.type(:notify).new :name => "eval1_notify")]
+        allow(exec1).to receive(:eval_generate).and_return(
+          [ Puppet::Type.type(:notify).new(:name => "eval1_notify") ]
         )
 
         exec2 = Puppet::Type.type(:exec).new(
@@ -328,8 +327,8 @@ describe Puppet::Transaction do
           :refreshonly => true,
           :subscribe   => exec1,
         )
-        exec2.stubs(:eval_generate).returns(
-          [ (Puppet::Type.type(:notify).new :name => "eval2_notify")]
+        allow(exec2).to receive(:eval_generate).and_return(
+          [ Puppet::Type.type(:notify).new(:name => "eval2_notify") ]
         )
 
         Puppet[:tags] = "exec"
