@@ -1,5 +1,3 @@
-#! /usr/bin/env ruby
-
 shared_examples_for "a file_serving model" do
   include PuppetSpec::Files
 
@@ -9,7 +7,7 @@ shared_examples_for "a file_serving model" do
 
     before :each do
       # Never connect to the network, no matter what
-      described_class.indirection.terminus(:rest).class.any_instance.stubs(:find)
+      allow_any_instance_of(described_class.indirection.terminus(:rest).class).to receive(:find)
     end
 
     describe "when running the master application" do
@@ -24,7 +22,7 @@ shared_examples_for "a file_serving model" do
        "puppet://server/modules/foo/bar" => :file_server,
       }.each do |key, terminus|
         it "should use the #{terminus} terminus when requesting #{key.inspect}" do
-          described_class.indirection.terminus(terminus).class.any_instance.expects(:find)
+          expect_any_instance_of(described_class.indirection.terminus(terminus).class).to receive(:find)
 
           described_class.indirection.find(key)
         end
@@ -43,7 +41,7 @@ shared_examples_for "a file_serving model" do
        "puppet://server/modules/foo/bar" => :rest,
       }.each do |key, terminus|
         it "should use the #{terminus} terminus when requesting #{key.inspect}" do
-          described_class.indirection.terminus(terminus).class.any_instance.expects(:find)
+          expect_any_instance_of(described_class.indirection.terminus(terminus).class).to receive(:find)
 
           described_class.indirection.find(key)
         end
@@ -62,7 +60,7 @@ shared_examples_for "a file_serving model" do
        "puppet://server/modules/foo/bar" => :rest,
       }.each do |key, terminus|
         it "should use the #{terminus} terminus when requesting #{key.inspect}" do
-          described_class.indirection.terminus(terminus).class.any_instance.expects(:find)
+          expect_any_instance_of(described_class.indirection.terminus(terminus).class).to receive(:find)
 
           described_class.indirection.find(key)
         end
