@@ -77,7 +77,14 @@ RSpec.configure do |config|
   exclude_filters[:benchmark] = true unless ENV['BENCHMARK']
   config.filter_run_excluding exclude_filters
 
-  config.mock_with :mocha
+  config.filter_run_when_matching :focus
+
+  config.mock_with :rspec do |mocks|
+    # We really should have this on, but it breaks a _lot_ of tests. We'll
+    # need to go through and fix those tests first before it can be enabled
+    # for real.
+    mocks.verify_partial_doubles = false
+  end
 
   tmpdir = Puppet::FileSystem.expand_path(Dir.mktmpdir("rspecrun"))
   oldtmpdir = Puppet::FileSystem.expand_path(Dir.tmpdir())
@@ -115,7 +122,7 @@ RSpec.configure do |config|
     # REVISIT: I think this conceals other bad tests, but I don't have time to
     # fully diagnose those right now.  When you read this, please come tell me
     # I suck for letting this float. --daniel 2011-04-21
-    Signal.stubs(:trap)
+    allow(Signal).to receive(:trap)
 
     # TODO: in a more sane world, we'd move this logging redirection into our TestHelper class.
     #  Without doing so, external projects will all have to roll their own solution for
@@ -127,6 +134,7 @@ RSpec.configure do |config|
     # redirecting logging away from console, because otherwise the test output will be
     #  obscured by all of the log output
     @logs = []
+    Puppet::Util::Log.close_all
     if ENV["PUPPET_TEST_LOG_LEVEL"]
       Puppet::Util::Log.level = ENV["PUPPET_TEST_LOG_LEVEL"].intern
     end
@@ -156,6 +164,7 @@ RSpec.configure do |config|
     Puppet::Test::TestHelper.after_each_test()
 
     # TODO: would like to move this into puppetlabs_spec_helper, but there are namespace issues at the moment.
+    allow(Dir).to receive(:entries).and_call_original
     PuppetSpec::Files.cleanup
 
     # TODO: this should be abstracted in the future--see comments above the '@logs' block in the
