@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 require 'puppet/application/certificate'
 
@@ -6,14 +5,14 @@ describe Puppet::Application::Certificate do
   it "should have a 'ca-location' option" do
     # REVISIT: This is delegated from the face, and we will have a test there,
     # so is this actually a valuable test? --daniel 2011-04-07
-    subject.command_line.stubs(:args).returns %w{list}
+    allow(subject.command_line).to receive(:args).and_return(%w{list})
     subject.preinit
     subject.parse_options
     expect(subject).to respond_to(:handle_ca_location)
   end
 
   it "should accept the ca-location option" do
-    subject.command_line.stubs(:args).returns %w{--ca-location local list}
+    allow(subject.command_line).to receive(:args).and_return(%w{--ca-location local list})
     subject.preinit
     subject.parse_options
     subject.setup
