@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 require 'puppet/application/doc'
@@ -8,9 +7,9 @@ require 'puppet/util/rdoc'
 describe Puppet::Application::Doc do
   before :each do
     @doc = Puppet::Application[:doc]
-    @doc.stubs(:puts)
+    allow(@doc).to receive(:puts)
     @doc.preinit
-    Puppet::Util::Log.stubs(:newdestination)
+    allow(Puppet::Util::Log).to receive(:newdestination)
   end
 
   it "should declare an other command" do
@@ -56,49 +55,49 @@ describe Puppet::Application::Doc do
       end
 
       it "should store argument value when calling handle_#{option}" do
-        @doc.options.expects(:[]=).with(option, 'arg')
+        expect(@doc.options).to receive(:[]=).with(option, 'arg')
         @doc.send("handle_#{option}".to_sym, 'arg')
       end
     end
 
     it "should store the format if valid" do
-      Puppet::Util::Reference.stubs(:method_defined?).with('to_format').returns(true)
+      allow(Puppet::Util::Reference).to receive(:method_defined?).with('to_format').and_return(true)
 
       @doc.handle_format('format')
       expect(@doc.options[:format]).to eq('to_format')
     end
 
     it "should raise an error if the format is not valid" do
-      Puppet::Util::Reference.stubs(:method_defined?).with('to_format').returns(false)
+      allow(Puppet::Util::Reference).to receive(:method_defined?).with('to_format').and_return(false)
       expect { @doc.handle_format('format') }.to raise_error(RuntimeError, /Invalid output format/)
     end
 
     it "should store the mode if valid" do
-      Puppet::Util::Reference.stubs(:modes).returns(stub('mode', :include? => true))
+      allow(Puppet::Util::Reference).to receive(:modes).and_return(double('mode', :include? => true))
 
       @doc.handle_mode('mode')
       expect(@doc.options[:mode]).to eq(:mode)
     end
 
     it "should store the mode if :rdoc" do
-      Puppet::Util::Reference.modes.stubs(:include?).with('rdoc').returns(false)
+      allow(Puppet::Util::Reference.modes).to receive(:include?).with('rdoc').and_return(false)
 
       @doc.handle_mode('rdoc')
       expect(@doc.options[:mode]).to eq(:rdoc)
     end
 
     it "should raise an error if the mode is not valid" do
-      Puppet::Util::Reference.modes.stubs(:include?).with('unknown').returns(false)
+      allow(Puppet::Util::Reference.modes).to receive(:include?).with('unknown').and_return(false)
       expect { @doc.handle_mode('unknown') }.to raise_error(RuntimeError, /Invalid output mode/)
     end
 
     it "should list all references on list and exit" do
-      reference = stubs 'reference'
-      ref = stubs 'ref'
-      Puppet::Util::Reference.stubs(:references).returns([reference])
+      reference = double('reference')
+      ref = double('ref')
+      allow(Puppet::Util::Reference).to receive(:references).and_return([reference])
 
-      Puppet::Util::Reference.expects(:reference).with(reference).returns(ref)
-      ref.expects(:doc)
+      expect(Puppet::Util::Reference).to receive(:reference).with(reference).and_return(ref)
+      expect(ref).to receive(:doc)
 
       expect { @doc.handle_list(nil) }.to exit_with 0
     end
@@ -113,15 +112,14 @@ describe Puppet::Application::Doc do
   end
 
   describe "during setup" do
-
     before :each do
-      Puppet::Log.stubs(:newdestination)
-      @doc.command_line.stubs(:args).returns([])
+      allow(Puppet::Log).to receive(:newdestination)
+      allow(@doc.command_line).to receive(:args).and_return([])
     end
 
     it "should default to rdoc mode if there are command line arguments" do
-      @doc.command_line.stubs(:args).returns(["1"])
-      @doc.stubs(:setup_rdoc)
+      allow(@doc.command_line).to receive(:args).and_return(["1"])
+      allow(@doc).to receive(:setup_rdoc)
 
       @doc.setup
       expect(@doc.options[:mode]).to eq(:rdoc)
@@ -130,7 +128,7 @@ describe Puppet::Application::Doc do
     it "should call setup_rdoc in rdoc mode" do
       @doc.options[:mode] = :rdoc
 
-      @doc.expects(:setup_rdoc)
+      expect(@doc).to receive(:setup_rdoc)
 
       @doc.setup
     end
@@ -138,14 +136,14 @@ describe Puppet::Application::Doc do
     it "should call setup_reference if not rdoc" do
       @doc.options[:mode] = :test
 
-      @doc.expects(:setup_reference)
+      expect(@doc).to receive(:setup_reference)
 
       @doc.setup
     end
 
     describe "configuring logging" do
       before :each do
-        Puppet::Util::Log.stubs(:newdestination)
+        allow(Puppet::Util::Log).to receive(:newdestination)
       end
 
       describe "with --debug" do
@@ -159,7 +157,7 @@ describe Puppet::Application::Doc do
         end
 
         it "should set log destination to console" do
-          Puppet::Util::Log.expects(:newdestination).with(:console)
+          expect(Puppet::Util::Log).to receive(:newdestination).with(:console)
           @doc.setup
         end
       end
@@ -175,7 +173,7 @@ describe Puppet::Application::Doc do
         end
 
         it "should set log destination to console" do
-          Puppet::Util::Log.expects(:newdestination).with(:console)
+          expect(Puppet::Util::Log).to receive(:newdestination).with(:console)
           @doc.setup
         end
       end
@@ -192,7 +190,7 @@ describe Puppet::Application::Doc do
         end
 
         it "should set log destination to console" do
-          Puppet::Util::Log.expects(:newdestination).with(:console)
+          expect(Puppet::Util::Log).to receive(:newdestination).with(:console)
           @doc.setup
         end
       end
@@ -201,11 +199,11 @@ describe Puppet::Application::Doc do
     describe "in non-rdoc mode" do
       it "should get all non-dynamic reference if --all" do
         @doc.options[:all] = true
-        static = stub 'static', :dynamic? => false
-        dynamic = stub 'dynamic', :dynamic? => true
-        Puppet::Util::Reference.stubs(:reference).with(:static).returns(static)
-        Puppet::Util::Reference.stubs(:reference).with(:dynamic).returns(dynamic)
-        Puppet::Util::Reference.stubs(:references).returns([:static,:dynamic])
+        static = double('static', :dynamic? => false)
+        dynamic = double('dynamic', :dynamic? => true)
+        allow(Puppet::Util::Reference).to receive(:reference).with(:static).and_return(static)
+        allow(Puppet::Util::Reference).to receive(:reference).with(:dynamic).and_return(dynamic)
+        allow(Puppet::Util::Reference).to receive(:references).and_return([:static,:dynamic])
 
         @doc.setup_reference
         expect(@doc.options[:references]).to eq([:static])
@@ -221,7 +219,7 @@ describe Puppet::Application::Doc do
       describe "when there are unknown args" do
         it "should expand --modulepath if any" do
           @doc.unknown_args = [ { :opt => "--modulepath", :arg => "path" } ]
-          Puppet.settings.stubs(:handlearg)
+          allow(Puppet.settings).to receive(:handlearg)
 
           @doc.setup_rdoc
 
@@ -230,7 +228,7 @@ describe Puppet::Application::Doc do
 
         it "should give them to Puppet.settings" do
           @doc.unknown_args = [ { :opt => :option, :arg => :argument } ]
-          Puppet.settings.expects(:handlearg).with(:option,:argument)
+          expect(Puppet.settings).to receive(:handlearg).with(:option,:argument)
 
           @doc.setup_rdoc
         end
@@ -255,16 +253,16 @@ describe Puppet::Application::Doc do
 
       before :each do
         @doc.manifest = false
-        Puppet.stubs(:info)
+        allow(Puppet).to receive(:info)
         Puppet[:trace] = false
         Puppet[:modulepath] = modules
         Puppet[:manifest] = manifests
         @doc.options[:all] = false
         @doc.options[:outputdir] = 'doc'
         @doc.options[:charset] = nil
-        Puppet.settings.stubs(:define_settings)
-        Puppet::Util::RDoc.stubs(:rdoc)
-        @doc.command_line.stubs(:args).returns([])
+        allow(Puppet.settings).to receive(:define_settings)
+        allow(Puppet::Util::RDoc).to receive(:rdoc)
+        allow(@doc.command_line).to receive(:args).and_return([])
       end
 
       around(:each) do |example|
@@ -277,31 +275,31 @@ describe Puppet::Application::Doc do
 
       it "should set document_all on --all" do
         @doc.options[:all] = true
-        Puppet.settings.expects(:[]=).with(:document_all, true)
+        expect(Puppet.settings).to receive(:[]=).with(:document_all, true)
 
         expect { @doc.rdoc }.to exit_with(0)
       end
 
       it "should call Puppet::Util::RDoc.rdoc in full mode" do
-        Puppet::Util::RDoc.expects(:rdoc).with('doc', [modules, manifests], nil)
+        expect(Puppet::Util::RDoc).to receive(:rdoc).with('doc', [modules, manifests], nil)
         expect { @doc.rdoc }.to exit_with(0)
       end
 
       it "should call Puppet::Util::RDoc.rdoc with a charset if --charset has been provided" do
         @doc.options[:charset] = 'utf-8'
-        Puppet::Util::RDoc.expects(:rdoc).with('doc', [modules, manifests], "utf-8")
+        expect(Puppet::Util::RDoc).to receive(:rdoc).with('doc', [modules, manifests], "utf-8")
         expect { @doc.rdoc }.to exit_with(0)
       end
 
       it "should call Puppet::Util::RDoc.rdoc in full mode with outputdir set to doc if no --outputdir" do
         @doc.options[:outputdir] = false
-        Puppet::Util::RDoc.expects(:rdoc).with('doc', [modules, manifests], nil)
+        expect(Puppet::Util::RDoc).to receive(:rdoc).with('doc', [modules, manifests], nil)
         expect { @doc.rdoc }.to exit_with(0)
       end
 
       it "should call Puppet::Util::RDoc.manifestdoc in manifest mode" do
         @doc.manifest = true
-        Puppet::Util::RDoc.expects(:manifestdoc)
+        expect(Puppet::Util::RDoc).to receive(:manifestdoc)
         expect { @doc.rdoc }.to exit_with(0)
       end
 
@@ -312,7 +310,7 @@ describe Puppet::Application::Doc do
           [modules, modules2],
           "envmanifests/site.pp")
         Puppet.override({:environments => Puppet::Environments::Static.new(env), :current_environment => env}) do
-           Puppet::Util::RDoc.stubs(:rdoc).with('doc', [modules.to_s, modules2.to_s, env.manifest.to_s], nil)
+           allow(Puppet::Util::RDoc).to receive(:rdoc).with('doc', [modules.to_s, modules2.to_s, env.manifest.to_s], nil)
           expect { @doc.rdoc }.to exit_with(0)
         end
       end
@@ -320,14 +318,14 @@ describe Puppet::Application::Doc do
 
     describe "in the other modes" do
       it "should get reference in given format" do
-        reference = stub 'reference'
+        reference = double('reference')
         @doc.options[:mode] = :none
         @doc.options[:references] = [:ref]
-        Puppet::Util::Reference.expects(:reference).with(:ref).returns(reference)
+        expect(Puppet::Util::Reference).to receive(:reference).with(:ref).and_return(reference)
         @doc.options[:format] = :format
-        @doc.stubs(:exit)
+        allow(@doc).to receive(:exit)
 
-        reference.expects(:send).with { |format,contents| format == :format }.returns('doc')
+        expect(reference).to receive(:send).with(:format, anything).and_return('doc')
         @doc.other
       end
     end
