@@ -1,16 +1,15 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 require 'puppet/application/facts'
 
 describe Puppet::Application::Facts do
   before :each do
-    subject.command_line.stubs(:subcommand_name).returns 'facts'
+    allow(subject.command_line).to receive(:subcommand_name).and_return('facts')
   end
 
   it "should return facts if a key is given to find" do
     Puppet::Node::Facts.indirection.reset_terminus_class
-    Puppet::Node::Facts.indirection.expects(:find).returns(Puppet::Node::Facts.new('whatever', {}))
-    subject.command_line.stubs(:args).returns %w{find whatever --render-as yaml}
+    expect(Puppet::Node::Facts.indirection).to receive(:find).and_return(Puppet::Node::Facts.new('whatever', {}))
+    allow(subject.command_line).to receive(:args).and_return(%w{find whatever --render-as yaml})
 
     expect {
       expect {
