@@ -30,7 +30,7 @@ describe Puppet::Application::Lookup do
     it "does not allow invalid arguments for '--merge'" do
       lookup.options[:node] = 'dantooine.local'
       lookup.options[:merge] = 'something_bad'
-      lookup.command_line.stubs(:args).returns(['atton', 'kreia'])
+      allow(lookup.command_line).to receive(:args).and_return(['atton', 'kreia'])
 
       expected_error = "The --merge option only accepts 'first', 'hash', 'unique', or 'deep'\nRun 'puppet lookup --help' for more details"
 
@@ -41,7 +41,7 @@ describe Puppet::Application::Lookup do
       lookup.options[:node] = 'dantooine.local'
       lookup.options[:merge_hash_arrays] = true
       lookup.options[:merge] = 'hash'
-      lookup.command_line.stubs(:args).returns(['atton', 'kreia'])
+      allow(lookup.command_line).to receive(:args).and_return(['atton', 'kreia'])
 
       expected_error = "The options --knock-out-prefix, --sort-merged-arrays, and --merge-hash-arrays are only available with '--merge deep'\nRun 'puppet lookup --help' for more details"
 
@@ -57,12 +57,12 @@ describe Puppet::Application::Lookup do
       lookup.options[:render_as] = :s;
       lookup.options[:merge_hash_arrays] = true
       lookup.options[:merge] = 'deep'
-      lookup.command_line.stubs(:args).returns(['atton', 'kreia'])
-      lookup.stubs(:generate_scope).yields('scope')
+      allow(lookup.command_line).to receive(:args).and_return(['atton', 'kreia'])
+      allow(lookup).to receive(:generate_scope).and_yield('scope')
 
       expected_merge = { "strategy" => "deep", "sort_merged_arrays" => false, "merge_hash_arrays" => true }
 
-      (Puppet::Pops::Lookup).expects(:lookup).with(['atton', 'kreia'], nil, nil, false, expected_merge, anything).returns('rand')
+      expect(Puppet::Pops::Lookup).to receive(:lookup).with(['atton', 'kreia'], nil, nil, false, expected_merge, anything).and_return('rand')
 
       expect(run_lookup(lookup)).to eql("rand")
     end
@@ -72,19 +72,19 @@ describe Puppet::Application::Lookup do
       it "accepts --merge #{opt}" do
         lookup.options[:node] = 'dantooine.local'
         lookup.options[:merge] = opt
-        lookup.command_line.stubs(:args).returns(['atton', 'kreia'])
-        lookup.stubs(:generate_scope).yields('scope')
-        Puppet::Pops::Lookup.stubs(:lookup).returns('rand')
+        allow(lookup.command_line).to receive(:args).and_return(['atton', 'kreia'])
+        allow(lookup).to receive(:generate_scope).and_yield('scope')
+        allow(Puppet::Pops::Lookup).to receive(:lookup).and_return('rand')
         expect(run_lookup(lookup)).to eql("--- rand")
       end
     end
 
     it "prints the value found by lookup" do
       lookup.options[:node] = 'dantooine.local'
-      lookup.command_line.stubs(:args).returns(['atton', 'kreia'])
-      lookup.stubs(:generate_scope).yields('scope')
+      allow(lookup.command_line).to receive(:args).and_return(['atton', 'kreia'])
+      allow(lookup).to receive(:generate_scope).and_yield('scope')
 
-      Puppet::Pops::Lookup.stubs(:lookup).returns('rand')
+      allow(Puppet::Pops::Lookup).to receive(:lookup).and_return('rand')
 
       expect(run_lookup(lookup)).to eql("--- rand")
     end
@@ -269,7 +269,7 @@ describe Puppet::Application::Lookup do
     it '--explain produces human readable text by default and does not produce output to debug logger' do
       lookup.options[:node] = node
       lookup.options[:explain] = true
-      lookup.command_line.stubs(:args).returns(['a'])
+      allow(lookup.command_line).to receive(:args).and_return(['a'])
       logs = []
       Puppet::Util::Log.with_destination(Puppet::Test::LogCollector.new(logs)) do
         expect(run_lookup(lookup)).to eql(<<-EXPLANATION.chomp)
@@ -298,7 +298,7 @@ Searching for "a"
 
     it '--debug using multiple interpolation functions produces output to the logger' do
       lookup.options[:node] = node
-      lookup.command_line.stubs(:args).returns(['ab'])
+      allow(lookup.command_line).to receive(:args).and_return(['ab'])
       Puppet.debug = true
       logs = []
       begin
@@ -318,7 +318,7 @@ Searching for "a"
     it '--explain produces human readable text by default and --debug produces the same output to debug logger' do
       lookup.options[:node] = node
       lookup.options[:explain] = true
-      lookup.command_line.stubs(:args).returns(['a'])
+      allow(lookup.command_line).to receive(:args).and_return(['a'])
       Puppet.debug = true
       logs = []
       Puppet::Util::Log.with_destination(Puppet::Test::LogCollector.new(logs)) do
@@ -432,7 +432,7 @@ Lookup of '__global__'
       lookup.options[:node] = node
       lookup.options[:explain] = true
       lookup.options[:explain_options] = true
-      lookup.command_line.stubs(:args).returns(['a'])
+      allow(lookup.command_line).to receive(:args).and_return(['a'])
       expect(run_lookup(lookup)).to eql(<<-EXPLANATION.chomp)
 Searching for "lookup_options"
   Global Data Provider (hiera configuration version 5)
@@ -459,7 +459,7 @@ Searching for "a"
       lookup.options[:node] = node
       lookup.options[:explain] = true
       lookup.options[:render_as] = :yaml
-      lookup.command_line.stubs(:args).returns(['a'])
+      allow(lookup.command_line).to receive(:args).and_return(['a'])
       output = run_lookup(lookup)
       expect(YAML.load(output)).to eq(expected_yaml_hash)
     end
@@ -468,7 +468,7 @@ Searching for "a"
       lookup.options[:node] = node
       lookup.options[:explain] = true
       lookup.options[:render_as] = :json
-      lookup.command_line.stubs(:args).returns(['a'])
+      allow(lookup.command_line).to receive(:args).and_return(['a'])
       output = run_lookup(lookup)
       expect(JSON.parse(output)).to eq(expected_json_hash)
     end
@@ -476,7 +476,7 @@ Searching for "a"
     it 'can access values using dotted keys' do
       lookup.options[:node] = node
       lookup.options[:render_as] = :json
-      lookup.command_line.stubs(:args).returns(['d.one.two.three'])
+      allow(lookup.command_line).to receive(:args).and_return(['d.one.two.three'])
       output = run_lookup(lookup)
       expect(JSON.parse("[#{output}]")).to eq(['the value'])
     end
@@ -484,7 +484,7 @@ Searching for "a"
     it 'can access values using quoted dotted keys' do
       lookup.options[:node] = node
       lookup.options[:render_as] = :json
-      lookup.command_line.stubs(:args).returns(['"e.one.two.three"'])
+      allow(lookup.command_line).to receive(:args).and_return(['"e.one.two.three"'])
       output = run_lookup(lookup)
       expect(JSON.parse("[#{output}]")).to eq(['the value'])
     end
@@ -492,7 +492,7 @@ Searching for "a"
     it 'can access values using mix of dotted keys and quoted dotted keys' do
       lookup.options[:node] = node
       lookup.options[:render_as] = :json
-      lookup.command_line.stubs(:args).returns(['"f.one"."two.three".1'])
+      allow(lookup.command_line).to receive(:args).and_return(['"f.one"."two.three".1'])
       output = run_lookup(lookup)
       expect(JSON.parse("[#{output}]")).to eq(['second value'])
     end
@@ -502,14 +502,14 @@ Searching for "a"
 
       it "is unaffected by global variables unless '--compile' is used" do
         lookup.options[:node] = node
-        lookup.command_line.stubs(:args).returns(['c'])
+        allow(lookup.command_line).to receive(:args).and_return(['c'])
         expect(run_lookup(lookup)).to eql("--- This is")
       end
 
       it "is affected by global variables when '--compile' is used" do
         lookup.options[:node] = node
         lookup.options[:compile] = true
-        lookup.command_line.stubs(:args).returns(['c'])
+        allow(lookup.command_line).to receive(:args).and_return(['c'])
         expect(run_lookup(lookup)).to eql("--- This is C from site.pp")
       end
 
@@ -523,7 +523,7 @@ Searching for "a"
 
         lookup.options[:node] = node
         lookup.options[:fact_file] = filename
-        lookup.command_line.stubs(:args).returns(['c'])
+        allow(lookup.command_line).to receive(:args).and_return(['c'])
         expect(run_lookup(lookup)).to eql("--- This is C from facts")
       end
 
@@ -537,7 +537,7 @@ Searching for "a"
 
         lookup.options[:node] = node
         lookup.options[:fact_file] = filename
-        lookup.command_line.stubs(:args).returns(['g'])
+        allow(lookup.command_line).to receive(:args).and_return(['g'])
         expect(run_lookup(lookup)).to eql("--- This is G from facts in facts hash")
       end
     end
@@ -547,14 +547,14 @@ Searching for "a"
 
       it "works OK in the absense of '--compile'" do
         lookup.options[:node] = node
-        lookup.command_line.stubs(:args).returns(['c'])
+        allow(lookup.command_line).to receive(:args).and_return(['c'])
         expect(run_lookup(lookup)).to eql("--- This is C from data.pp")
       end
 
       it "global scope is affected by global variables when '--compile' is used" do
         lookup.options[:node] = node
         lookup.options[:compile] = true
-        lookup.command_line.stubs(:args).returns(['c'])
+        allow(lookup.command_line).to receive(:args).and_return(['c'])
         expect(run_lookup(lookup)).to eql("--- This is C from site.pp")
       end
     end
