@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 require 'puppet/application/resource'
@@ -6,9 +5,10 @@ require 'puppet_spec/character_encoding'
 
 describe Puppet::Application::Resource do
   include PuppetSpec::Files
+
   before :each do
     @resource_app = Puppet::Application[:resource]
-    Puppet::Util::Log.stubs(:newdestination)
+    allow(Puppet::Util::Log).to receive(:newdestination)
   end
 
   describe "in preinit" do
@@ -21,17 +21,17 @@ describe Puppet::Application::Resource do
   describe "when handling options" do
     [:debug, :verbose, :edit].each do |option|
       it "should store argument value when calling handle_#{option}" do
-        @resource_app.options.expects(:[]=).with(option, 'arg')
+        expect(@resource_app.options).to receive(:[]=).with(option, 'arg')
         @resource_app.send("handle_#{option}".to_sym, 'arg')
       end
     end
 
     it "should load a display all types with types option" do
-      type1 = stub_everything 'type1', :name => :type1
-      type2 = stub_everything 'type2', :name => :type2
-      Puppet::Type.stubs(:loadall)
-      Puppet::Type.stubs(:eachtype).multiple_yields(type1,type2)
-      @resource_app.expects(:puts).with(['type1','type2'])
+      type1 = double('type1', :name => :type1)
+      type2 = double('type2', :name => :type2)
+      allow(Puppet::Type).to receive(:loadall)
+      allow(Puppet::Type).to receive(:eachtype).and_yield(type1).and_yield(type2)
+      expect(@resource_app).to receive(:puts).with(['type1','type2'])
       expect { @resource_app.handle_types(nil) }.to exit_with 0
     end
 
@@ -43,10 +43,10 @@ describe Puppet::Application::Resource do
     end
 
     it "should get a parameter in the printed data if extra_params are passed" do
-      tty  = stub("tty",  :tty? => true )
+      tty  = double("tty",  :tty? => true )
       path = tmpfile('testfile')
       command_line = Puppet::Util::CommandLine.new("puppet", [ 'resource', 'file', path ], tty )
-      @resource_app.stubs(:command_line).returns command_line
+      allow(@resource_app).to receive(:command_line).and_return(command_line)
 
       # provider is a parameter that should always be available
       @resource_app.extra_params = [ :provider ]
@@ -57,75 +57,70 @@ describe Puppet::Application::Resource do
 
   describe "during setup" do
     before :each do
-      Puppet::Log.stubs(:newdestination)
+      allow(Puppet::Log).to receive(:newdestination)
     end
 
     it "should set console as the log destination" do
-      Puppet::Log.expects(:newdestination).with(:console)
+      expect(Puppet::Log).to receive(:newdestination).with(:console)
 
       @resource_app.setup
     end
 
     it "should set log level to debug if --debug was passed" do
-      @resource_app.options.stubs(:[]).with(:debug).returns(true)
+      allow(@resource_app.options).to receive(:[]).with(:debug).and_return(true)
       @resource_app.setup
       expect(Puppet::Log.level).to eq(:debug)
     end
 
     it "should set log level to info if --verbose was passed" do
-      @resource_app.options.stubs(:[]).with(:debug).returns(false)
-      @resource_app.options.stubs(:[]).with(:verbose).returns(true)
+      allow(@resource_app.options).to receive(:[]).with(:debug).and_return(false)
+      allow(@resource_app.options).to receive(:[]).with(:verbose).and_return(true)
       @resource_app.setup
       expect(Puppet::Log.level).to eq(:info)
     end
-
   end
 
   describe "when running" do
     before :each do
-      @type = stub_everything 'type', :properties => []
-      @resource_app.command_line.stubs(:args).returns(['mytype'])
-      Puppet::Type.stubs(:type).returns(@type)
+      @type = double('type', :properties => [])
+      allow(@resource_app.command_line).to receive(:args).and_return(['mytype'])
+      allow(Puppet::Type).to receive(:type).and_return(@type)
 
-      @res = stub_everything "resource"
-      @res.stubs(:prune_parameters).returns(@res)
-      @res.stubs(:to_manifest).returns("resource")
-      @report = stub_everything "report"
+      @res = double("resource")
+      allow(@res).to receive(:prune_parameters).and_return(@res)
+      allow(@res).to receive(:to_manifest).and_return("resource")
+      @report = double("report")
 
-      @resource_app.stubs(:puts)
-
-      Puppet::Resource.indirection.stubs(:find  ).never
-      Puppet::Resource.indirection.stubs(:search).never
-      Puppet::Resource.indirection.stubs(:save  ).never
+      allow(@resource_app).to receive(:puts)
     end
 
     it "should raise an error if no type is given" do
-      @resource_app.command_line.stubs(:args).returns([])
+      allow(@resource_app.command_line).to receive(:args).and_return([])
       expect { @resource_app.main }.to raise_error(RuntimeError, "You must specify the type to display")
     end
 
     it "should raise an error if the type is not found" do
-      Puppet::Type.stubs(:type).returns(nil)
+      allow(Puppet::Type).to receive(:type).and_return(nil)
 
       expect { @resource_app.main }.to raise_error(RuntimeError, 'Could not find type mytype')
     end
 
     it "should search for resources" do
-      Puppet::Resource.indirection.expects(:search).with('mytype/', {}).returns([])
+      expect(Puppet::Resource.indirection).to receive(:search).with('mytype/', {}).and_return([])
       @resource_app.main
     end
 
     it "should describe the given resource" do
-      @resource_app.command_line.stubs(:args).returns(['type','name'])
-      Puppet::Resource.indirection.expects(:find).with('type/name').returns(@res)
+      allow(@resource_app.command_line).to receive(:args).and_return(['type','name'])
+      expect(Puppet::Resource.indirection).to receive(:find).with('type/name').and_return(@res)
       @resource_app.main
     end
 
     it "should add given parameters to the object" do
-      @resource_app.command_line.stubs(:args).returns(['type','name','param=temp'])
+      allow(@resource_app.command_line).to receive(:args).and_return(['type','name','param=temp'])
 
-      Puppet::Resource.indirection.expects(:save).with(@res, 'type/name').returns([@res, @report])
-      Puppet::Resource.expects(:new).with('type', 'name', :parameters => {'param' => 'temp'}).returns(@res)
+      expect(Puppet::Resource.indirection).to receive(:save).with(@res, 'type/name').and_return([@res, @report])
+      expect(Puppet::Resource).to receive(:new).with('type', 'name', :parameters => {'param' => 'temp'}).and_return(@res)
 
       @resource_app.main
     end
@@ -137,11 +132,11 @@ describe Puppet::Application::Resource do
         Puppet::Type.type(:user).new(:name => "\u2603".force_encoding(Encoding::UTF_8)).to_resource,
         Puppet::Type.type(:user).new(:name => "Jos\xE9".force_encoding(Encoding::ISO_8859_1)).to_resource
       ]
-      Puppet::Resource.indirection.expects(:search).with('user/', {}).returns(resources)
-      @resource_app.command_line.stubs(:args).returns(['user'])
+      expect(Puppet::Resource.indirection).to receive(:search).with('user/', {}).and_return(resources)
+      allow(@resource_app.command_line).to receive(:args).and_return(['user'])
 
       # All of our output should be in external encoding
-      @resource_app.expects(:puts).with { |args| expect(args.encoding).to eq(Encoding::ISO_8859_1) }
+      expect(@resource_app).to receive(:puts) { |args| expect(args.encoding).to eq(Encoding::ISO_8859_1) }
 
       # This would raise an error if we weren't handling it
       PuppetSpec::CharacterEncoding.with_external_encoding(Encoding::ISO_8859_1) do
@@ -152,12 +147,12 @@ describe Puppet::Application::Resource do
 
   describe "when handling file type" do
     before :each do
-      Facter.stubs(:loadfacts)
+      allow(Facter).to receive(:loadfacts)
       @resource_app.preinit
     end
 
     it "should raise an exception if no file specified" do
-      @resource_app.command_line.stubs(:args).returns(['file'])
+      allow(@resource_app.command_line).to receive(:args).and_return(['file'])
 
       expect { @resource_app.main }.to raise_error(RuntimeError, /Listing all file instances is not supported/)
     end
@@ -165,12 +160,10 @@ describe Puppet::Application::Resource do
     it "should output a file resource when given a file path" do
       path = File.expand_path('/etc')
       res = Puppet::Type.type(:file).new(:path => path).to_resource
-      Puppet::Resource.indirection.expects(:find).returns(res)
+      expect(Puppet::Resource.indirection).to receive(:find).and_return(res)
 
-      @resource_app.command_line.stubs(:args).returns(['file', path])
-      @resource_app.expects(:puts).with do |args|
-        expect(args).to match(/file \{ '#{Regexp.escape(path)}'/m)
-      end
+      allow(@resource_app.command_line).to receive(:args).and_return(['file', path])
+      expect(@resource_app).to receive(:puts).with(/file \{ '#{Regexp.escape(path)}'/m)
 
       @resource_app.main
     end
@@ -187,8 +180,9 @@ describe Puppet::Application::Resource do
           @instances ||= [new(:name => name)]
         end
       end
-      @resource_app.command_line.stubs(:args).returns(['testing', 'hello'])
-      @resource_app.expects(:puts).with { |args| expect(args).to eql("testing { 'hello':\n}") }
+
+      allow(@resource_app.command_line).to receive(:args).and_return(['testing', 'hello'])
+      expect(@resource_app).to receive(:puts).with("testing { 'hello':\n}")
       expect { @resource_app.main }.not_to raise_error
     end
   end
