@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 require 'puppet/configurer'
 require 'puppet/configurer/fact_handler'
@@ -23,10 +22,6 @@ describe Puppet::Configurer::FactHandler do
 
   let(:facthandler) { FactHandlerTester.new('production') }
 
-  before :each do
-    Puppet::Node::Facts.indirection.terminus_class = :memory
-  end
-
   describe "when finding facts" do
     it "should use the node name value to retrieve the facts" do
       foo_facts = Puppet::Node::Facts.new('foo')
@@ -58,13 +53,13 @@ describe Puppet::Configurer::FactHandler do
     end
 
     it "should fail if finding facts fails" do
-      Puppet::Node::Facts.indirection.expects(:find).raises RuntimeError
+      expect(Puppet::Node::Facts.indirection).to receive(:find).and_raise(RuntimeError)
 
       expect { facthandler.find_facts }.to raise_error(Puppet::Error, /Could not retrieve local facts/)
     end
 
     it "should only load fact plugins once" do
-      Puppet::Node::Facts.indirection.expects(:find).once
+      expect(Puppet::Node::Facts.indirection).to receive(:find).once
       facthandler.find_facts
     end
   end
