@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 require 'puppet/file_serving/configuration'
@@ -25,17 +24,16 @@ describe Puppet::FileServing::Configuration do
   end
 
   describe "when initializing" do
-
     it "should work without a configuration file" do
-      Puppet::FileSystem.stubs(:exist?).with(@path).returns(false)
+      allow(Puppet::FileSystem).to receive(:exist?).with(@path).and_return(false)
       expect { Puppet::FileServing::Configuration.configuration }.to_not raise_error
     end
 
     it "should parse the configuration file if present" do
-      Puppet::FileSystem.stubs(:exist?).with(@path).returns(true)
-      @parser = mock 'parser'
-      @parser.expects(:parse).returns({})
-      Puppet::FileServing::Configuration::Parser.stubs(:new).returns(@parser)
+      allow(Puppet::FileSystem).to receive(:exist?).with(@path).and_return(true)
+      @parser = double('parser')
+      expect(@parser).to receive(:parse).and_return({})
+      allow(Puppet::FileServing::Configuration::Parser).to receive(:new).and_return(@parser)
       Puppet::FileServing::Configuration.configuration
     end
 
@@ -45,38 +43,37 @@ describe Puppet::FileServing::Configuration do
   end
 
   describe "when parsing the configuration file" do
-
     before do
-      Puppet::FileSystem.stubs(:exist?).with(@path).returns(true)
-      @parser = mock 'parser'
-      Puppet::FileServing::Configuration::Parser.stubs(:new).returns(@parser)
+      allow(Puppet::FileSystem).to receive(:exist?).with(@path).and_return(true)
+      @parser = double('parser')
+      allow(Puppet::FileServing::Configuration::Parser).to receive(:new).and_return(@parser)
     end
 
     it "should set the mount list to the results of parsing" do
-      @parser.expects(:parse).returns("one" => mock("mount"))
+      expect(@parser).to receive(:parse).and_return("one" => double("mount"))
       config = Puppet::FileServing::Configuration.configuration
       expect(config.mounted?("one")).to be_truthy
     end
 
     it "should not raise exceptions" do
-      @parser.expects(:parse).raises(ArgumentError)
+      expect(@parser).to receive(:parse).and_raise(ArgumentError)
       expect { Puppet::FileServing::Configuration.configuration }.to_not raise_error
     end
 
     it "should replace the existing mount list with the results of reparsing" do
-      @parser.expects(:parse).returns("one" => mock("mount"))
+      expect(@parser).to receive(:parse).and_return("one" => double("mount"))
       config = Puppet::FileServing::Configuration.configuration
       expect(config.mounted?("one")).to be_truthy
       # Now parse again
-      @parser.expects(:parse).returns("two" => mock('other'))
+      expect(@parser).to receive(:parse).and_return("two" => double('other'))
       config.send(:readconfig, false)
       expect(config.mounted?("one")).to be_falsey
       expect(config.mounted?("two")).to be_truthy
     end
 
     it "should not replace the mount list until the file is entirely parsed successfully" do
-      @parser.expects(:parse).returns("one" => mock("mount"))
-      @parser.expects(:parse).raises(ArgumentError)
+      expect(@parser).to receive(:parse).and_return("one" => double("mount"))
+      expect(@parser).to receive(:parse).and_raise(ArgumentError)
       config = Puppet::FileServing::Configuration.configuration
       # Now parse again, so the exception gets thrown
       config.send(:readconfig, false)
@@ -84,7 +81,7 @@ describe Puppet::FileServing::Configuration do
     end
 
     it "should add modules, plugins, and tasks mounts even if the file does not exist" do
-      Puppet::FileSystem.expects(:exist?).returns false # the file doesn't exist
+      expect(Puppet::FileSystem).to receive(:exist?).and_return(false) # the file doesn't exist
       config = Puppet::FileServing::Configuration.configuration
       expect(config.mounted?("modules")).to be_truthy
       expect(config.mounted?("plugins")).to be_truthy
@@ -92,43 +89,43 @@ describe Puppet::FileServing::Configuration do
     end
 
     it "should allow all access to modules, plugins, and tasks if no fileserver.conf exists" do
-      Puppet::FileSystem.expects(:exist?).returns false # the file doesn't exist
-      modules = stub 'modules', :empty? => true
-      Puppet::FileServing::Mount::Modules.stubs(:new).returns(modules)
-      modules.expects(:allow).with('*')
+      expect(Puppet::FileSystem).to receive(:exist?).and_return(false) # the file doesn't exist
+      modules = double('modules', :empty? => true)
+      allow(Puppet::FileServing::Mount::Modules).to receive(:new).and_return(modules)
+      expect(modules).to receive(:allow).with('*')
 
-      plugins = stub 'plugins', :empty? => true
-      Puppet::FileServing::Mount::Plugins.stubs(:new).returns(plugins)
-      plugins.expects(:allow).with('*')
+      plugins = double('plugins', :empty? => true)
+      allow(Puppet::FileServing::Mount::Plugins).to receive(:new).and_return(plugins)
+      expect(plugins).to receive(:allow).with('*')
 
-      tasks = stub 'tasks', :empty? => true
-      Puppet::FileServing::Mount::Tasks.stubs(:new).returns(tasks)
-      tasks.expects(:allow).with('*')
+      tasks = double('tasks', :empty? => true)
+      allow(Puppet::FileServing::Mount::Tasks).to receive(:new).and_return(tasks)
+      expect(tasks).to receive(:allow).with('*')
 
       Puppet::FileServing::Configuration.configuration
     end
 
     it "should not allow access from all to modules, plugins, and tasks if the fileserver.conf provided some rules" do
-      Puppet::FileSystem.expects(:exist?).returns false # the file doesn't exist
+      expect(Puppet::FileSystem).to receive(:exist?).and_return(false) # the file doesn't exist
 
-      modules = stub 'modules', :empty? => false
-      Puppet::FileServing::Mount::Modules.stubs(:new).returns(modules)
-      modules.expects(:allow).with('*').never
+      modules = double('modules', :empty? => false)
+      allow(Puppet::FileServing::Mount::Modules).to receive(:new).and_return(modules)
+      expect(modules).not_to receive(:allow).with('*')
 
-      plugins = stub 'plugins', :empty? => false
-      Puppet::FileServing::Mount::Plugins.stubs(:new).returns(plugins)
-      plugins.expects(:allow).with('*').never
+      plugins = double('plugins', :empty? => false)
+      allow(Puppet::FileServing::Mount::Plugins).to receive(:new).and_return(plugins)
+      expect(plugins).not_to receive(:allow).with('*')
 
-      tasks = stub 'tasks', :empty? => false
-      Puppet::FileServing::Mount::Tasks.stubs(:new).returns(tasks)
-      tasks.expects(:allow).with('*').never
+      tasks = double('tasks', :empty? => false)
+      allow(Puppet::FileServing::Mount::Tasks).to receive(:new).and_return(tasks)
+      expect(tasks).not_to receive(:allow).with('*')
 
       Puppet::FileServing::Configuration.configuration
     end
 
     it "should add modules, plugins, and tasks mounts even if they are not returned by the parser" do
-      @parser.expects(:parse).returns("one" => mock("mount"))
-      Puppet::FileSystem.expects(:exist?).returns true # the file doesn't exist
+      expect(@parser).to receive(:parse).and_return("one" => double("mount"))
+      expect(Puppet::FileSystem).to receive(:exist?).and_return(true) # the file doesn't exist
       config = Puppet::FileServing::Configuration.configuration
       expect(config.mounted?("modules")).to be_truthy
       expect(config.mounted?("plugins")).to be_truthy
@@ -139,16 +136,16 @@ describe Puppet::FileServing::Configuration do
   describe "when finding the specified mount" do
     it "should choose the named mount if one exists" do
       config = Puppet::FileServing::Configuration.configuration
-      config.expects(:mounts).returns("one" => "foo")
-      expect(config.find_mount("one", mock('env'))).to eq("foo")
+      expect(config).to receive(:mounts).and_return("one" => "foo")
+      expect(config.find_mount("one", double('env'))).to eq("foo")
     end
 
     it "should return nil if there is no such named mount" do
       config = Puppet::FileServing::Configuration.configuration
 
-      env = mock 'environment'
-      mount = mock 'mount'
-      config.stubs(:mounts).returns("modules" => mount)
+      env = double('environment')
+      mount = double('mount')
+      allow(config).to receive(:mounts).and_return("modules" => mount)
 
       expect(config.find_mount("foo", env)).to be_nil
     end
@@ -156,66 +153,66 @@ describe Puppet::FileServing::Configuration do
 
   describe "#split_path" do
     let(:config) { Puppet::FileServing::Configuration.configuration }
-    let(:request) { stub 'request', :key => "foo/bar/baz", :options => {}, :node => nil, :environment => mock("env") }
+    let(:request) { double('request', :key => "foo/bar/baz", :options => {}, :node => nil, :environment => double("env")) }
 
     before do
-      config.stubs(:find_mount)
+      allow(config).to receive(:find_mount)
     end
 
     it "should reread the configuration" do
-      config.expects(:readconfig)
+      expect(config).to receive(:readconfig)
 
       config.split_path(request)
     end
 
     it "should treat the first field of the URI path as the mount name" do
-      config.expects(:find_mount).with { |name, node| name == "foo" }
+      expect(config).to receive(:find_mount).with("foo", anything)
 
       config.split_path(request)
     end
 
     it "should fail if the mount name is not alpha-numeric" do
-      request.expects(:key).returns "foo&bar/asdf"
+      expect(request).to receive(:key).and_return("foo&bar/asdf")
 
       expect { config.split_path(request) }.to raise_error(ArgumentError)
     end
 
     it "should support dashes in the mount name" do
-      request.expects(:key).returns "foo-bar/asdf"
+      expect(request).to receive(:key).and_return("foo-bar/asdf")
 
       expect { config.split_path(request) }.to_not raise_error
     end
 
     it "should use the mount name and environment to find the mount" do
-      config.expects(:find_mount).with { |name, env| name == "foo" and env == request.environment }
-      request.stubs(:node).returns("mynode")
+      expect(config).to receive(:find_mount).with("foo", request.environment)
+      allow(request).to receive(:node).and_return("mynode")
 
       config.split_path(request)
     end
 
     it "should return nil if the mount cannot be found" do
-      config.expects(:find_mount).returns nil
+      expect(config).to receive(:find_mount).and_return(nil)
 
       expect(config.split_path(request)).to be_nil
     end
 
     it "should return the mount and the relative path if the mount is found" do
-      mount = stub 'mount', :name => "foo"
-      config.expects(:find_mount).returns mount
+      mount = double('mount', :name => "foo")
+      expect(config).to receive(:find_mount).and_return(mount)
 
       expect(config.split_path(request)).to eq([mount, "bar/baz"])
     end
 
     it "should remove any double slashes" do
-      request.stubs(:key).returns "foo/bar//baz"
-      mount = stub 'mount', :name => "foo"
-      config.expects(:find_mount).returns mount
+      allow(request).to receive(:key).and_return("foo/bar//baz")
+      mount = double('mount', :name => "foo")
+      expect(config).to receive(:find_mount).and_return(mount)
 
       expect(config.split_path(request)).to eq([mount, "bar/baz"])
     end
 
     it "should fail if the path contains .." do
-      request.stubs(:key).returns 'module/foo/../../bar'
+      allow(request).to receive(:key).and_return('module/foo/../../bar')
 
       expect do
         config.split_path(request)
@@ -223,17 +220,17 @@ describe Puppet::FileServing::Configuration do
     end
 
     it "should return the relative path as nil if it is an empty string" do
-      request.expects(:key).returns "foo"
-      mount = stub 'mount', :name => "foo"
-      config.expects(:find_mount).returns mount
+      expect(request).to receive(:key).and_return("foo")
+      mount = double('mount', :name => "foo")
+      expect(config).to receive(:find_mount).and_return(mount)
 
       expect(config.split_path(request)).to eq([mount, nil])
     end
 
     it "should add 'modules/' to the relative path if the modules mount is used but not specified, for backward compatibility" do
-      request.expects(:key).returns "foo/bar"
-      mount = stub 'mount', :name => "modules"
-      config.expects(:find_mount).returns mount
+      expect(request).to receive(:key).and_return("foo/bar")
+      mount = double('mount', :name => "modules")
+      expect(config).to receive(:find_mount).and_return(mount)
 
       expect(config.split_path(request)).to eq([mount, "foo/bar"])
     end
