@@ -330,7 +330,7 @@ describe "Puppet::FileSystem" do
     end
 
     it "should fall back to stat when trying to lstat a file" do
-      Puppet::Util::Windows::File.expects(:stat).with(Puppet::FileSystem.assert_path(file))
+      expect(Puppet::Util::Windows::File).to receive(:stat).with(Puppet::FileSystem.assert_path(file))
 
       Puppet::FileSystem.lstat(file)
     end
@@ -809,7 +809,7 @@ describe "Puppet::FileSystem" do
       describe 'on non-Windows', :unless => Puppet::Util::Platform.windows? do
         it 'should produce the same results as the Ruby File.expand_path' do
           # on Windows this may be 8.3 style, but not so on other platforms
-          # only done since ::File.expects(:expand_path).with(path).at_least_once
+          # only done since expect(::File).to receive(:expand_path).with(path).at_least(:once)
           # cannot be used since it will cause a stack overflow
           path = tmpdir('foobar')
 
