@@ -83,7 +83,7 @@ describe "the inline_epp function" do
   end
 
   def epp_function()
-    epp_func = scope.compiler.loaders.public_environment_loader.load(:function, 'inline_epp')
+    scope.compiler.loaders.public_environment_loader.load(:function, 'inline_epp')
   end
 
 end
