@@ -41,6 +41,15 @@ describe 'the match function' do
     it "matches string and type #{pattern} with captures" do
       expect(func.call({}, 'abc123', type(pattern))).to eql(['abc123', 'abc', '123'])
     end
+
+    it "matches string with an alias type for #{pattern} with captures" do
+      expect(func.call({}, 'abc123', alias_type("MyAlias", type(pattern)))).to eql(['abc123', 'abc', '123'])
+    end
+
+    it "matches string with a  matching variant type for #{pattern} with captures" do
+      expect(func.call({}, 'abc123', variant_type(type(pattern)))).to eql(['abc123', 'abc', '123'])
+    end
+
   end
 
   it 'matches an array of strings and yields a map of the result' do
@@ -51,6 +60,15 @@ describe 'the match function' do
     expect{func.call({}, 'abc123', type('Regexp'))}.to raise_error(ArgumentError, /Given Regexp Type has no regular expression/)
   end
 
+  def variant_type(*t)
+    Puppet::Pops::Types::PVariantType.new(t)
+  end
+
+  def alias_type(name, t)
+    # Create an alias using a nil AST (which is never used because it is given a type as resolution)
+    Puppet::Pops::Types::PTypeAliasType.new(name, nil, t)
+  end
+
   def type(s)
     Puppet::Pops::Types::TypeParser.singleton.parse(s)
   end
