@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 require 'puppet/indirector/certificate/disabled_ca'
 
@@ -25,7 +24,7 @@ describe Puppet::SSL::Certificate::DisabledCa do
       end
 
       it "should forward local #{name} requests" do
-        Puppet::SSL::Certificate.indirection.terminus(:file).expects(name)
+        expect(Puppet::SSL::Certificate.indirection.terminus(:file)).to receive(name)
         subject.send(name, request(name, false))
       end
     end
