@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 require 'puppet/node/facts'
@@ -33,10 +32,10 @@ describe Puppet::Node::Facts::Yaml do
     def assert_search_matches(matching, nonmatching, query)
       request = Puppet::Indirector::Request.new(:inventory, :search, nil, nil, query)
 
-      Dir.stubs(:glob).returns(matching.keys + nonmatching.keys)
+      allow(Dir).to receive(:glob).and_return(matching.keys + nonmatching.keys)
       [matching, nonmatching].each do |examples|
         examples.each do |key, value|
-          YAML.stubs(:load_file).with(key).returns value
+          allow(YAML).to receive(:load_file).with(key).and_return(value)
         end
       end
       expect(Puppet::Node::Facts::Yaml.new.search(request)).to match_array(matching.values.map {|facts| facts.name})
@@ -68,7 +67,6 @@ describe Puppet::Node::Facts::Yaml do
       )
     end
 
-
     it "should return node names that match the search query options with the greater than operator" do
       assert_search_matches({
           '/path/to/matching.yaml'  => Puppet::Node::Facts.new("matchingnode",  "architecture" => "i386",    'processor_count' => '5'),
