@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 require 'puppet/node'
@@ -6,7 +5,7 @@ require 'puppet/indirector/node/write_only_yaml'
 
 describe Puppet::Node::WriteOnlyYaml do
   it "should be deprecated" do
-    Puppet.expects(:warn_once).with('deprecations', 'Puppet::Node::WriteOnlyYaml', 'Puppet::Node::WriteOnlyYaml is deprecated and will be removed in a future release of Puppet.')
+    expect(Puppet).to receive(:warn_once).with('deprecations', 'Puppet::Node::WriteOnlyYaml', 'Puppet::Node::WriteOnlyYaml is deprecated and will be removed in a future release of Puppet.')
     described_class.new
   end
 end
