@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 require 'matchers/json'
 require 'puppet/indirector/request'
@@ -20,7 +19,7 @@ describe Puppet::Indirector::Request do
     end
 
     it "should use the name of the provided instance as its key if an instance is provided as the key instead of a string" do
-      instance = mock 'instance', :name => "mykey"
+      instance = double('instance', :name => "mykey")
       request = Puppet::Indirector::Request.new(:ind, :method, nil, instance)
       expect(request.key).to eq("mykey")
       expect(request.instance).to equal(instance)
@@ -195,25 +194,25 @@ describe Puppet::Indirector::Request do
   end
 
   it "should look use the Indirection class to return the appropriate indirection" do
-    ind = mock 'indirection'
-    Puppet::Indirector::Indirection.expects(:instance).with(:myind).returns ind
+    ind = double('indirection')
+    expect(Puppet::Indirector::Indirection).to receive(:instance).with(:myind).and_return(ind)
     request = Puppet::Indirector::Request.new(:myind, :method, :key, nil)
 
     expect(request.indirection).to equal(ind)
   end
 
   it "should use its indirection to look up the appropriate model" do
-    ind = mock 'indirection'
-    Puppet::Indirector::Indirection.expects(:instance).with(:myind).returns ind
+    ind = double('indirection')
+    expect(Puppet::Indirector::Indirection).to receive(:instance).with(:myind).and_return(ind)
     request = Puppet::Indirector::Request.new(:myind, :method, :key, nil)
 
-    ind.expects(:model).returns "mymodel"
+    expect(ind).to receive(:model).and_return("mymodel")
 
     expect(request.model).to eq("mymodel")
   end
 
   it "should fail intelligently when asked to find a model but the indirection cannot be found" do
-    Puppet::Indirector::Indirection.expects(:instance).with(:myind).returns nil
+    expect(Puppet::Indirector::Indirection).to receive(:instance).with(:myind).and_return(nil)
     request = Puppet::Indirector::Request.new(:myind, :method, :key, nil)
 
     expect { request.model }.to raise_error(ArgumentError)
@@ -442,16 +441,16 @@ describe Puppet::Indirector::Request do
 
       context "when SRV returns servers" do
         before :each do
-          @dns_mock = mock('dns')
-          Resolv::DNS.expects(:new).returns(@dns_mock)
+          @dns_mock = double('dns')
+          expect(Resolv::DNS).to receive(:new).and_return(@dns_mock)
 
           @port = 7205
           @host = '_x-puppet._tcp.example.com'
           @srv_records = [Resolv::DNS::Resource::IN::SRV.new(0, 0, @port, @host)]
 
-          @dns_mock.expects(:getresources).
+          expect(@dns_mock).to receive(:getresources).
             with("_x-puppet._tcp.#{Puppet.settings[:srv_domain]}", Resolv::DNS::Resource::IN::SRV).
-            returns(@srv_records)
+            and_return(@srv_records)
         end
 
         it "yields a request using the server and port from the SRV record" do
