@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 require 'puppet/util/json'
 require 'puppet/indirector'
@@ -17,14 +16,14 @@ shared_examples_for "a REST terminus method" do |terminus_method|
     end
 
     it "falls back to pson for future requests" do
-      response.stubs(:[]).with(Puppet::Network::HTTP::HEADER_PUPPET_VERSION).returns("4.10.1")
+      allow(response).to receive(:[]).with(Puppet::Network::HTTP::HEADER_PUPPET_VERSION).and_return("4.10.1")
       terminus.send(terminus_method, request)
 
       expect(Puppet[:preferred_serialization_format]).to eq("pson")
     end
 
     it "doesn't change the serialization format if the X-Puppet-Version header is missing" do
-      response.stubs(:[]).with(Puppet::Network::HTTP::HEADER_PUPPET_VERSION).returns(nil)
+      allow(response).to receive(:[]).with(Puppet::Network::HTTP::HEADER_PUPPET_VERSION).and_return(nil)
 
       terminus.send(terminus_method, request)
 
@@ -32,7 +31,7 @@ shared_examples_for "a REST terminus method" do |terminus_method|
     end
 
     it "doesn't change the serialization format if the server major version is 5" do
-      response.stubs(:[]).with(Puppet::Network::HTTP::HEADER_PUPPET_VERSION).returns("5.0.3")
+      allow(response).to receive(:[]).with(Puppet::Network::HTTP::HEADER_PUPPET_VERSION).and_return("5.0.3")
 
       terminus.send(terminus_method, request)
 
@@ -40,7 +39,7 @@ shared_examples_for "a REST terminus method" do |terminus_method|
     end
 
     it "doesn't change the serialization format if the current format is already pson" do
-      response.stubs(:[]).with(Puppet::Network::HTTP::HEADER_PUPPET_VERSION).returns("4.10.1")
+      allow(response).to receive(:[]).with(Puppet::Network::HTTP::HEADER_PUPPET_VERSION).and_return("4.10.1")
       Puppet[:preferred_serialization_format] = "pson"
       terminus.send(terminus_method, request)
 
@@ -77,7 +76,7 @@ shared_examples_for "a REST terminus method" do |terminus_method|
       end
 
       it "does not attempt to deserialize the response into a model" do
-        model.expects(:convert_from).never
+        expect(model).not_to receive(:convert_from)
 
         expect {
           terminus.send(terminus_method, request)
@@ -86,8 +85,8 @@ shared_examples_for "a REST terminus method" do |terminus_method|
 
       # I'm not sure what this means or if it's used
       it "if the body is empty raises an http error with the response header" do
-        response.stubs(:body).returns ""
-        response.stubs(:message).returns "fhqwhgads"
+        allow(response).to receive(:body).and_return("")
+        allow(response).to receive(:message).and_return("fhqwhgads")
 
         expect {
           terminus.send(terminus_method, request)
@@ -99,7 +98,7 @@ shared_examples_for "a REST terminus method" do |terminus_method|
           compressed_body = Zlib::Deflate.deflate(body)
 
           compressed_response = mock_response(code, compressed_body, 'application/json', 'deflate')
-          connection.expects(http_method).returns(compressed_response)
+          expect(connection).to receive(http_method).and_return(compressed_response)
 
           expect {
             terminus.send(terminus_method, request)
@@ -121,7 +120,7 @@ shared_examples_for "a deserializing terminus method" do |terminus_method|
   end
 
   it "doesn't catch errors in deserialization" do
-    model.expects(:convert_from).raises(Puppet::Error, "Whoa there")
+    expect(model).to receive(:convert_from).and_raise(Puppet::Error, "Whoa there")
 
     expect { terminus.send(terminus_method, request) }.to raise_error(Puppet::Error, "Whoa there")
   end
@@ -182,10 +181,10 @@ describe Puppet::Indirector::REST do
   end
 
   def mock_response(code, body, content_type='text/plain', encoding=nil)
-    obj = stub('http 200 ok', :code => code.to_s, :body => body)
-    obj.stubs(:[]).with('content-type').returns(content_type)
-    obj.stubs(:[]).with('content-encoding').returns(encoding)
-    obj.stubs(:[]).with(Puppet::Network::HTTP::HEADER_PUPPET_VERSION).returns(Puppet.version)
+    obj = double('http 200 ok', :code => code.to_s, :body => body)
+    allow(obj).to receive(:[]).with('content-type').and_return(content_type)
+    allow(obj).to receive(:[]).with('content-encoding').and_return(encoding)
+    allow(obj).to receive(:[]).with(Puppet::Network::HTTP::HEADER_PUPPET_VERSION).and_return(Puppet.version)
     obj
   end
 
@@ -214,13 +213,13 @@ describe Puppet::Indirector::REST do
   end
 
   it "should use any specified setting to pick the server" do
-    terminus_class.expects(:server_setting).returns :ca_server
+    expect(terminus_class).to receive(:server_setting).and_return(:ca_server)
     Puppet[:ca_server] = "myserver"
     expect(terminus_class.server).to eq("myserver")
   end
 
   it "should default to :server for the server setting" do
-    terminus_class.expects(:server_setting).returns nil
+    expect(terminus_class).to receive(:server_setting).and_return(nil)
     Puppet[:server] = "myserver"
     expect(terminus_class.server).to eq("myserver")
   end
@@ -230,39 +229,39 @@ describe Puppet::Indirector::REST do
   end
 
   it "should use any specified setting to pick the port" do
-    terminus_class.expects(:port_setting).returns :ca_port
+    expect(terminus_class).to receive(:port_setting).and_return(:ca_port)
     Puppet[:ca_port] = "321"
     expect(terminus_class.port).to eq(321)
   end
 
   it "should default to :port for the port setting" do
-    terminus_class.expects(:port_setting).returns nil
+    expect(terminus_class).to receive(:port_setting).and_return(nil)
     Puppet[:masterport] = "543"
     expect(terminus_class.port).to eq(543)
   end
 
   it "should use a failover-selected server if set" do
-    terminus_class.expects(:server_setting).returns nil
+    expect(terminus_class).to receive(:server_setting).and_return(nil)
     Puppet.override(:server => "myserver") do
       expect(terminus_class.server).to eq("myserver")
     end
   end
 
   it "should use a failover-selected port if set" do
-    terminus_class.expects(:port_setting).returns nil
+    expect(terminus_class).to receive(:port_setting).and_return(nil)
     Puppet.override(:serverport => 321) do
       expect(terminus_class.port).to eq(321)
     end
   end
 
   it "should use server_list for server when available" do
-    terminus_class.expects(:server_setting).returns nil
+    expect(terminus_class).to receive(:server_setting).and_return(nil)
     Puppet[:server_list] = [["foo", "123"]]
     expect(terminus_class.server).to eq("foo")
   end
 
   it "should prefer failover-selected server from server list" do
-    terminus_class.expects(:server_setting).returns nil
+    expect(terminus_class).to receive(:server_setting).and_return(nil)
     Puppet[:server_list] = [["foo", "123"],["bar", "321"]]
     Puppet.override(:server => "bar") do
       expect(terminus_class.server).to eq("bar")
@@ -270,13 +269,13 @@ describe Puppet::Indirector::REST do
   end
 
   it "should use server_list for port when available" do
-    terminus_class.expects(:port_setting).returns nil
+    expect(terminus_class).to receive(:port_setting).and_return(nil)
     Puppet[:server_list] = [["foo", "123"]]
     expect(terminus_class.port).to eq(123)
   end
 
   it "should prefer failover-selected port from server list" do
-    terminus_class.expects(:port_setting).returns nil
+    expect(terminus_class).to receive(:port_setting).and_return(nil)
     Puppet[:server_list] = [["foo", "123"],["bar", "321"]]
     Puppet.override(:serverport => "321") do
       expect(terminus_class.port).to eq(321)
@@ -284,7 +283,7 @@ describe Puppet::Indirector::REST do
   end
 
   it "should use an explicitly specified more-speciic server when failover is active" do
-    terminus_class.expects(:server_setting).returns :ca_server
+    expect(terminus_class).to receive(:server_setting).and_return(:ca_server)
     Puppet[:ca_server] = "myserver"
     Puppet.override(:server => "anotherserver") do
       expect(terminus_class.server).to eq("myserver")
@@ -292,7 +291,7 @@ describe Puppet::Indirector::REST do
   end
 
   it "should use an explicitly specified more-specific port when failover is active" do
-    terminus_class.expects(:port_setting).returns :ca_port
+    expect(terminus_class).to receive(:port_setting).and_return(:ca_port)
     Puppet[:ca_port] = 321
     Puppet.override(:serverport => 543) do
       expect(terminus_class.port).to eq(321)
@@ -300,8 +299,8 @@ describe Puppet::Indirector::REST do
   end
 
   it "should use a default port when a more-specific server is set" do
-    terminus_class.expects(:server_setting).returns :ca_server
-    terminus_class.expects(:port_setting).returns :ca_port
+    expect(terminus_class).to receive(:server_setting).and_return(:ca_server)
+    expect(terminus_class).to receive(:port_setting).and_return(:ca_port)
     Puppet[:ca_server] = "myserver"
     Puppet.override(:server => "anotherserver", :port => 666) do
       expect(terminus_class.port).to eq(8140)
@@ -313,43 +312,43 @@ describe Puppet::Indirector::REST do
   end
 
   it 'excludes yaml from the Accept header' do
-    model.expects(:supported_formats).returns([:json, :pson, :yaml, :binary])
+    expect(model).to receive(:supported_formats).and_return([:json, :pson, :yaml, :binary])
 
     expect(terminus.headers['Accept']).to eq('application/json, text/pson, application/octet-stream')
   end
 
   it 'excludes b64_zlib_yaml from the Accept header' do
-    model.expects(:supported_formats).returns([:json, :pson, :b64_zlib_yaml])
+    expect(model).to receive(:supported_formats).and_return([:json, :pson, :b64_zlib_yaml])
 
     expect(terminus.headers['Accept']).to eq('application/json, text/pson')
   end
 
   it 'excludes dot from the Accept header' do
-    model.expects(:supported_formats).returns([:json, :dot])
+    expect(model).to receive(:supported_formats).and_return([:json, :dot])
 
     expect(terminus.headers['Accept']).to eq('application/json')
   end
 
   describe "when creating an HTTP client" do
     it "should use the class's server and port if the indirection request provides neither" do
-      @request = stub 'request', :key => "foo", :server => nil, :port => nil
-      terminus.class.expects(:port).returns 321
-      terminus.class.expects(:server).returns "myserver"
-      Puppet::Network::HttpPool.expects(:http_instance).with("myserver", 321).returns "myconn"
+      @request = double('request', :key => "foo", :server => nil, :port => nil)
+      expect(terminus.class).to receive(:port).and_return(321)
+      expect(terminus.class).to receive(:server).and_return("myserver")
+      expect(Puppet::Network::HttpPool).to receive(:http_instance).with("myserver", 321).and_return("myconn")
       expect(terminus.network(@request)).to eq("myconn")
     end
 
     it "should use the server from the indirection request if one is present" do
-      @request = stub 'request', :key => "foo", :server => "myserver", :port => nil
-      terminus.class.stubs(:port).returns 321
-      Puppet::Network::HttpPool.expects(:http_instance).with("myserver", 321).returns "myconn"
+      @request = double('request', :key => "foo", :server => "myserver", :port => nil)
+      allow(terminus.class).to receive(:port).and_return(321)
+      expect(Puppet::Network::HttpPool).to receive(:http_instance).with("myserver", 321).and_return("myconn")
       expect(terminus.network(@request)).to eq("myconn")
     end
 
     it "should use the port from the indirection request if one is present" do
-      @request = stub 'request', :key => "foo", :server => nil, :port => 321
-      terminus.class.stubs(:server).returns "myserver"
-      Puppet::Network::HttpPool.expects(:http_instance).with("myserver", 321).returns "myconn"
+      @request = double('request', :key => "foo", :server => nil, :port => 321)
+      allow(terminus.class).to receive(:server).and_return("myserver")
+      expect(Puppet::Network::HttpPool).to receive(:http_instance).with("myserver", 321).and_return("myconn")
       expect(terminus.network(@request)).to eq("myconn")
     end
   end
@@ -357,11 +356,11 @@ describe Puppet::Indirector::REST do
   describe "#find" do
     let(:http_method) { :get }
     let(:response) { mock_response(200, 'body') }
-    let(:connection) { stub('mock http connection', :get => response, :verify_callback= => nil) }
+    let(:connection) { double('mock http connection', :get => response, :verify_callback= => nil) }
     let(:request) { find_request('foo') }
 
     before :each do
-      terminus.stubs(:network).returns(connection)
+      allow(terminus).to receive(:network).and_return(connection)
     end
 
     it_behaves_like 'a REST terminus method', :find
@@ -383,9 +382,11 @@ describe Puppet::Indirector::REST do
 
         request = find_request('whoa', params)
 
-        connection.expects(:post).with do |uri, body|
-            body.split("&").sort == params.map {|key,value| "#{key}=#{value}"}.sort
-        end.returns(mock_response(200, 'body'))
+        expect(connection).to receive(:post) do |_,req,_|
+          expect(req.split("&").flatten).to match_array(params.map {|key,value| "#{key}=#{value}"})
+
+          mock_response(200, 'body')
+        end
 
         terminus.find(request)
       end
@@ -395,7 +396,7 @@ describe Puppet::Indirector::REST do
       it "calls get on the connection" do
         request = find_request('foo bar')
 
-        connection.expects(:get).with("#{url_prefix}/test_model/foo%20bar?environment=production&", anything).returns(mock_response('200', 'response body'))
+        expect(connection).to receive(:get).with("#{url_prefix}/test_model/foo%20bar?environment=production&", anything).and_return(mock_response('200', 'response body'))
 
         expect(terminus.find(request)).to eq(model.new('foo bar', 'response body'))
       end
@@ -404,14 +405,14 @@ describe Puppet::Indirector::REST do
     it "returns nil on 404" do
       response = mock_response('404', nil)
 
-      connection.expects(:get).returns(response)
+      expect(connection).to receive(:get).and_return(response)
 
       expect(terminus.find(request)).to eq(nil)
     end
 
     it 'raises no warning for a 404 (when not asked to do so)' do
       response = mock_response('404', 'this is the notfound you are looking for')
-      connection.expects(:get).returns(response)
+      expect(connection).to receive(:get).and_return(response)
       expect{terminus.find(request)}.to_not raise_error()
     end
 
@@ -419,7 +420,7 @@ describe Puppet::Indirector::REST do
       it 'raises an error for a 404 when asked to do so' do
         request = find_request('foo', :fail_on_404 => true)
         response = mock_response('404', 'this is the notfound you are looking for')
-        connection.expects(:get).returns(response)
+        expect(connection).to receive(:get).and_return(response)
 
         expect do
           terminus.find(request)
@@ -431,7 +432,7 @@ describe Puppet::Indirector::REST do
       it 'truncates the URI when it is very long' do
         request = find_request('foo', :fail_on_404 => true, :long_param => ('A' * 100) + 'B')
         response = mock_response('404', 'this is the notfound you are looking for')
-        connection.expects(:get).returns(response)
+        expect(connection).to receive(:get).and_return(response)
 
         expect do
           terminus.find(request)
@@ -444,7 +445,7 @@ describe Puppet::Indirector::REST do
         Puppet.debug = true
         request = find_request('foo', :fail_on_404 => true, :long_param => ('A' * 100) + 'B')
         response = mock_response('404', 'this is the notfound you are looking for')
-        connection.expects(:get).returns(response)
+        expect(connection).to receive(:get).and_return(response)
 
         expect do
           terminus.find(request)
@@ -455,9 +456,9 @@ describe Puppet::Indirector::REST do
     end
 
     it "asks the model to deserialize the response body and sets the name on the resulting object to the find key" do
-      connection.expects(:get).returns response
+      expect(connection).to receive(:get).and_return(response)
 
-      model.expects(:convert_from).with(response['content-type'], response.body).returns(
+      expect(model).to receive(:convert_from).with(response['content-type'], response.body).and_return(
         model.new('overwritten', 'decoded body')
       )
 
@@ -465,42 +466,44 @@ describe Puppet::Indirector::REST do
     end
 
     it "doesn't require the model to support name=" do
-      connection.expects(:get).returns response
-      instance = model.new('name', 'decoded body')
+      class Puppet::TestModel2 < Puppet::TestModel
+        undef_method :name=
+      end
 
-      model.expects(:convert_from).with(response['content-type'], response.body).returns(instance)
-      instance.expects(:respond_to?).with(:name=).returns(false)
-      instance.expects(:name=).never
+      expect(connection).to receive(:get).and_return(response)
+      instance = Puppet::TestModel2.new('name', 'decoded body')
+
+      expect(model).to receive(:convert_from).with(response['content-type'], response.body).and_return(instance)
 
       expect(terminus.find(request)).to eq(model.new('name', 'decoded body'))
     end
 
     it "provides an Accept header containing the list of supported mime types joined with commas" do
-      connection.expects(:get).with(anything, has_entry("Accept" => "application/json, text/pson")).returns(response)
+      expect(connection).to receive(:get).with(anything, hash_including("Accept" => "application/json, text/pson")).and_return(response)
 
-      terminus.model.expects(:supported_formats).returns [:json, :pson]
+      expect(terminus.model).to receive(:supported_formats).and_return([:json, :pson])
       terminus.find(request)
     end
 
     it "provides a version header with the current puppet version" do
-      connection.expects(:get).with(anything, has_entry(Puppet::Network::HTTP::HEADER_PUPPET_VERSION => Puppet.version)).returns(response)
+      expect(connection).to receive(:get).with(anything, hash_including(Puppet::Network::HTTP::HEADER_PUPPET_VERSION => Puppet.version)).and_return(response)
 
       terminus.find(request)
     end
 
     it "adds an Accept-Encoding header" do
-      terminus.expects(:add_accept_encoding).returns({"accept-encoding" => "gzip"})
+      expect(terminus).to receive(:add_accept_encoding).and_return({"accept-encoding" => "gzip"})
 
-      connection.expects(:get).with(anything, has_entry("accept-encoding" => "gzip")).returns(response)
+      expect(connection).to receive(:get).with(anything, hash_including("accept-encoding" => "gzip")).and_return(response)
 
       terminus.find(request)
     end
 
     it "uses only the mime-type from the content-type header when asking the model to deserialize" do
       response = mock_response('200', 'mydata', "text/plain; charset=utf-8")
-      connection.expects(:get).returns(response)
+      expect(connection).to receive(:get).and_return(response)
 
-      model.expects(:convert_from).with("text/plain", "mydata").returns "myobject"
+      expect(model).to receive(:convert_from).with("text/plain", "mydata").and_return("myobject")
 
       expect(terminus.find(request)).to eq("myobject")
     end
@@ -510,9 +513,9 @@ describe Puppet::Indirector::REST do
       compressed_body = Zlib::Deflate.deflate(uncompressed_body)
 
       response = mock_response('200', compressed_body, 'text/plain', 'deflate')
-      connection.expects(:get).returns(response)
+      expect(connection).to receive(:get).and_return(response)
 
-      model.expects(:convert_from).with("text/plain", uncompressed_body).returns "myobject"
+      expect(model).to receive(:convert_from).with("text/plain", uncompressed_body).and_return("myobject")
 
       expect(terminus.find(request)).to eq("myobject")
     end
@@ -521,29 +524,29 @@ describe Puppet::Indirector::REST do
   describe "#head" do
     let(:http_method) { :head }
     let(:response) { mock_response(200, nil) }
-    let(:connection) { stub('mock http connection', :head => response, :verify_callback= => nil) }
+    let(:connection) { double('mock http connection', :head => response, :verify_callback= => nil) }
     let(:request) { head_request('foo') }
 
     before :each do
-      terminus.stubs(:network).returns(connection)
+      allow(terminus).to receive(:network).and_return(connection)
     end
 
     it_behaves_like 'a REST terminus method', :head
 
     it "returns true if there was a successful http response" do
-      connection.expects(:head).returns mock_response('200', nil)
+      expect(connection).to receive(:head).and_return(mock_response('200', nil))
 
       expect(terminus.head(request)).to eq(true)
     end
 
     it "returns false on a 404 response" do
-      connection.expects(:head).returns mock_response('404', nil)
+      expect(connection).to receive(:head).and_return(mock_response('404', nil))
 
       expect(terminus.head(request)).to eq(false)
     end
 
     it "provides a version header with the current puppet version" do
-      connection.expects(:head).with(anything, has_entry(Puppet::Network::HTTP::HEADER_PUPPET_VERSION => Puppet.version)).returns(response)
+      expect(connection).to receive(:head).with(anything, hash_including(Puppet::Network::HTTP::HEADER_PUPPET_VERSION => Puppet.version)).and_return(response)
 
       terminus.head(request)
     end
@@ -552,18 +555,18 @@ describe Puppet::Indirector::REST do
   describe "#search" do
     let(:http_method) { :get }
     let(:response) { mock_response(200, 'data1,data2,data3') }
-    let(:connection) { stub('mock http connection', :get => response, :verify_callback= => nil) }
+    let(:connection) { double('mock http connection', :get => response, :verify_callback= => nil) }
     let(:request) { search_request('foo') }
 
     before :each do
-      terminus.stubs(:network).returns(connection)
+      allow(terminus).to receive(:network).and_return(connection)
     end
 
     it_behaves_like 'a REST terminus method', :search
     it_behaves_like 'a deserializing terminus method', :search
 
     it "should call the GET http method on a network connection" do
-      connection.expects(:get).with("#{url_prefix}/test_models/foo?environment=production&", has_key('Accept')).returns mock_response(200, 'data3, data4')
+      expect(connection).to receive(:get).with("#{url_prefix}/test_models/foo?environment=production&", hash_including('Accept' => anything)).and_return(mock_response(200, 'data3, data4'))
 
       terminus.search(request)
     end
@@ -571,7 +574,7 @@ describe Puppet::Indirector::REST do
     it "returns an empty list on 404" do
       response = mock_response('404', nil)
 
-      connection.expects(:get).returns(response)
+      expect(connection).to receive(:get).and_return(response)
 
       expect(terminus.search(request)).to eq([])
     end
@@ -581,20 +584,20 @@ describe Puppet::Indirector::REST do
     end
 
     it "should provide an Accept header containing the list of supported formats joined with commas" do
-      connection.expects(:get).with(anything, has_entry("Accept" => "application/json, text/pson")).returns(mock_response(200, ''))
+      expect(connection).to receive(:get).with(anything, hash_including("Accept" => "application/json, text/pson")).and_return(mock_response(200, ''))
 
-      terminus.model.expects(:supported_formats).returns [:json, :pson]
+      expect(terminus.model).to receive(:supported_formats).and_return([:json, :pson])
       terminus.search(request)
     end
 
     it "provides a version header with the current puppet version" do
-      connection.expects(:get).with(anything, has_entry(Puppet::Network::HTTP::HEADER_PUPPET_VERSION => Puppet.version)).returns(mock_response(200, ''))
+      expect(connection).to receive(:get).with(anything, hash_including(Puppet::Network::HTTP::HEADER_PUPPET_VERSION => Puppet.version)).and_return(mock_response(200, ''))
 
       terminus.search(request)
     end
 
     it "should return an empty array if serialization returns nil" do
-      model.stubs(:convert_from_multiple).returns nil
+      allow(model).to receive(:convert_from_multiple).and_return(nil)
 
       expect(terminus.search(request)).to eq([])
     end
@@ -603,18 +606,18 @@ describe Puppet::Indirector::REST do
   describe "#destroy" do
     let(:http_method) { :delete }
     let(:response) { mock_response(200, 'body') }
-    let(:connection) { stub('mock http connection', :delete => response, :verify_callback= => nil) }
+    let(:connection) { double('mock http connection', :delete => response, :verify_callback= => nil) }
     let(:request) { delete_request('foo') }
 
     before :each do
-      terminus.stubs(:network).returns(connection)
+      allow(terminus).to receive(:network).and_return(connection)
     end
 
     it_behaves_like 'a REST terminus method', :destroy
     it_behaves_like 'a deserializing terminus method', :destroy
 
     it "should call the DELETE http method on a network connection" do
-      connection.expects(:delete).with("#{url_prefix}/test_model/foo?environment=production&", has_key('Accept')).returns(response)
+      expect(connection).to receive(:delete).with("#{url_prefix}/test_model/foo?environment=production&", hash_including('Accept' => anything)).and_return(response)
 
       terminus.destroy(request)
     end
@@ -626,7 +629,7 @@ describe Puppet::Indirector::REST do
     end
 
     it "should deserialize and return the http response" do
-      connection.expects(:delete).returns response
+      expect(connection).to receive(:delete).and_return(response)
 
       expect(terminus.destroy(request)).to eq(model.new('', 'body'))
     end
@@ -634,20 +637,20 @@ describe Puppet::Indirector::REST do
     it "returns nil on 404" do
       response = mock_response('404', nil)
 
-      connection.expects(:delete).returns(response)
+      expect(connection).to receive(:delete).and_return(response)
 
       expect(terminus.destroy(request)).to eq(nil)
     end
 
     it "should provide an Accept header containing the list of supported formats joined with commas" do
-      connection.expects(:delete).with(anything, has_entry("Accept" => "application/json, text/pson")).returns(response)
+      expect(connection).to receive(:delete).with(anything, hash_including("Accept" => "application/json, text/pson")).and_return(response)
 
-      terminus.model.expects(:supported_formats).returns [:json, :pson]
+      expect(terminus.model).to receive(:supported_formats).and_return([:json, :pson])
       terminus.destroy(request)
     end
 
     it "provides a version header with the current puppet version" do
-      connection.expects(:delete).with(anything, has_entry(Puppet::Network::HTTP::HEADER_PUPPET_VERSION => Puppet.version)).returns(response)
+      expect(connection).to receive(:delete).with(anything, hash_including(Puppet::Network::HTTP::HEADER_PUPPET_VERSION => Puppet.version)).and_return(response)
 
       terminus.destroy(request)
     end
@@ -656,18 +659,18 @@ describe Puppet::Indirector::REST do
   describe "#save" do
     let(:http_method) { :put }
     let(:response) { mock_response(200, 'body') }
-    let(:connection) { stub('mock http connection', :put => response, :verify_callback= => nil) }
+    let(:connection) { double('mock http connection', :put => response, :verify_callback= => nil) }
     let(:instance) { model.new('the thing', 'some contents') }
     let(:request) { save_request(instance.name, instance) }
 
     before :each do
-      terminus.stubs(:network).returns(connection)
+      allow(terminus).to receive(:network).and_return(connection)
     end
 
     it_behaves_like 'a REST terminus method', :save
 
     it "should call the PUT http method on a network connection" do
-      connection.expects(:put).with("#{url_prefix}/test_model/the%20thing?environment=production&", anything, has_key("Content-Type")).returns response
+      expect(connection).to receive(:put).with("#{url_prefix}/test_model/the%20thing?environment=production&", anything, hash_including("Content-Type")).and_return(response)
 
       terminus.save(request)
     end
@@ -679,8 +682,8 @@ describe Puppet::Indirector::REST do
     end
 
     it "should serialize the instance using the default format and pass the result as the body of the request" do
-      instance.expects(:render).returns "serial_instance"
-      connection.expects(:put).with(anything, "serial_instance", anything).returns response
+      expect(instance).to receive(:render).and_return("serial_instance")
+      expect(connection).to receive(:put).with(anything, "serial_instance", anything).and_return(response)
 
       terminus.save(request)
     end
@@ -688,36 +691,36 @@ describe Puppet::Indirector::REST do
     it "returns nil on 404" do
       response = mock_response('404', nil)
 
-      connection.expects(:put).returns(response)
+      expect(connection).to receive(:put).and_return(response)
 
       expect(terminus.save(request)).to eq(nil)
     end
 
     it "returns nil" do
-      connection.expects(:put).returns response
+      expect(connection).to receive(:put).and_return(response)
 
       expect(terminus.save(request)).to be_nil
     end
 
     it "should provide an Accept header containing the list of supported formats joined with commas" do
-      connection.expects(:put).with(anything, anything, has_entry("Accept" => "application/json, text/pson")).returns(response)
+      expect(connection).to receive(:put).with(anything, anything, hash_including("Accept" => "application/json, text/pson")).and_return(response)
 
-      instance.expects(:render).returns('')
-      model.expects(:supported_formats).returns [:json, :pson]
-      instance.expects(:mime).returns "supported"
+      expect(instance).to receive(:render).and_return('')
+      expect(model).to receive(:supported_formats).and_return([:json, :pson])
+      expect(instance).to receive(:mime).and_return("supported")
 
       terminus.save(request)
     end
 
     it "provides a version header with the current puppet version" do
-      connection.expects(:put).with(anything, anything, has_entry(Puppet::Network::HTTP::HEADER_PUPPET_VERSION => Puppet.version)).returns(response)
+      expect(connection).to receive(:put).with(anything, anything, hash_including(Puppet::Network::HTTP::HEADER_PUPPET_VERSION => Puppet.version)).and_return(response)
 
       terminus.save(request)
     end
 
     it "should provide a Content-Type header containing the mime-type of the sent object" do
-      instance.expects(:mime).returns "mime"
-      connection.expects(:put).with(anything, anything, has_entry('Content-Type' => "mime")).returns(response)
+      expect(instance).to receive(:mime).and_return("mime")
+      expect(connection).to receive(:put).with(anything, anything, hash_including('Content-Type' => "mime")).and_return(response)
 
       terminus.save(request)
     end
@@ -726,31 +729,31 @@ describe Puppet::Indirector::REST do
   describe '#handle_response' do
     # There are multiple request types to choose from, this may not be the one I want for this situation
     let(:response) { mock_response(200, 'body') }
-    let(:connection) { stub('mock http connection', :put => response, :verify_callback= => nil) }
+    let(:connection) { double('mock http connection', :put => response, :verify_callback= => nil) }
     let(:instance) { model.new('the thing', 'some contents') }
     let(:request) { save_request(instance.name, instance) }
 
     before :each do
-      terminus.stubs(:network).returns(connection)
+      allow(terminus).to receive(:network).and_return(connection)
     end
 
     it 'adds server_agent_version to the context if not already set' do
-      Puppet.expects(:push_context).with(:server_agent_version => Puppet.version)
+      expect(Puppet).to receive(:push_context).with(:server_agent_version => Puppet.version)
       terminus.handle_response(request, response)
     end
 
     it 'does not add server_agent_version to the context if it is already set' do
       Puppet.override(:server_agent_version => "5.3.4") do
-        Puppet.expects(:push_context).never
+        expect(Puppet).not_to receive(:push_context)
         terminus.handle_response(request, response)
       end
     end
 
     it 'downgrades to pson and emits a warning' do
-      response.stubs(:[]).with(Puppet::Network::HTTP::HEADER_PUPPET_VERSION).returns('4.2.8')
+      allow(response).to receive(:[]).with(Puppet::Network::HTTP::HEADER_PUPPET_VERSION).and_return('4.2.8')
       Puppet[:preferred_serialization_format] = 'other'
 
-      Puppet.expects(:warning).with('Downgrading to PSON for future requests')
+      expect(Puppet).to receive(:warning).with('Downgrading to PSON for future requests')
 
       terminus.handle_response(request, response)
 
@@ -778,7 +781,7 @@ describe Puppet::Indirector::REST do
         request = Puppet::Indirector::Request.new(:indirection, method, 'key', nil)
         stub_response = mock_response('200', 'body')
 
-        request.expects(:do_request).with(terminus.class.srv_service, terminus.class.server, terminus.class.port).returns(stub_response)
+        expect(request).to receive(:do_request).with(terminus.class.srv_service, terminus.class.server, terminus.class.port).and_return(stub_response)
 
         terminus.send(method, request)
       end
