@@ -61,7 +61,7 @@ describe Puppet::Interface do
     end
 
     it "should load actions" do
-      subject.any_instance.expects(:load_actions)
+      expect_any_instance_of(subject).to receive(:load_actions)
       subject.define(:face_test_load_actions, '0.0.1')
     end
 
@@ -121,8 +121,8 @@ describe Puppet::Interface do
   end
 
   it "should try to require faces that are not known" do
-    subject::FaceCollection.expects(:load_face).with(:foo, :current)
-    subject::FaceCollection.expects(:load_face).with(:foo, '0.0.1')
+    expect(subject::FaceCollection).to receive(:load_face).with(:foo, :current)
+    expect(subject::FaceCollection).to receive(:load_face).with(:foo, '0.0.1')
     expect { subject[:foo, '0.0.1'] }.to raise_error Puppet::Error
   end
 
