@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 require 'puppet/network/format_handler'
@@ -21,13 +20,13 @@ describe Puppet::Network::FormatHandler do
   describe "when listing formats" do
     before(:each) do
       one = Puppet::Network::FormatHandler.create(:one, :weight => 1)
-      one.stubs(:supported?).returns(true)
+      allow(one).to receive(:supported?).and_return(true)
       two = Puppet::Network::FormatHandler.create(:two, :weight => 6)
-      two.stubs(:supported?).returns(true)
+      allow(two).to receive(:supported?).and_return(true)
       three = Puppet::Network::FormatHandler.create(:three, :weight => 2)
-      three.stubs(:supported?).returns(true)
+      allow(three).to receive(:supported?).and_return(true)
       four = Puppet::Network::FormatHandler.create(:four, :weight => 8)
-      four.stubs(:supported?).returns(false)
+      allow(four).to receive(:supported?).and_return(false)
     end
 
     it "should return all supported formats in decreasing order of weight" do
@@ -36,16 +35,16 @@ describe Puppet::Network::FormatHandler do
   end
 
   it "should return the first format as the default format" do
-    FormatTester.expects(:supported_formats).returns [:one, :two]
+    expect(FormatTester).to receive(:supported_formats).and_return [:one, :two]
     expect(FormatTester.default_format).to eq(:one)
   end
 
   describe "with a preferred serialization format setting" do
     before do
       one = Puppet::Network::FormatHandler.create(:one, :weight => 1)
-      one.stubs(:supported?).returns(true)
+      allow(one).to receive(:supported?).and_return(true)
       two = Puppet::Network::FormatHandler.create(:two, :weight => 6)
-      two.stubs(:supported?).returns(true)
+      allow(two).to receive(:supported?).and_return(true)
     end
 
     describe "that is supported" do
@@ -68,8 +67,8 @@ describe Puppet::Network::FormatHandler do
       end
 
       it "should log a debug message" do
-        Puppet.expects(:debug).with("Value of 'preferred_serialization_format' (unsupported) is invalid for FormatTester, using default (two)")
-        Puppet.expects(:debug).with("FormatTester supports formats: two one")
+        expect(Puppet).to receive(:debug).with("Value of 'preferred_serialization_format' (unsupported) is invalid for FormatTester, using default (two)")
+        expect(Puppet).to receive(:debug).with("FormatTester supports formats: two one")
         FormatTester.supported_formats
       end
     end
@@ -79,27 +78,27 @@ describe Puppet::Network::FormatHandler do
     let(:format) { Puppet::Network::FormatHandler.create(:my_format, :mime => "text/myformat") }
 
     it "should use the Format to determine whether a given format is supported" do
-      format.expects(:supported?).with(FormatTester)
+      expect(format).to receive(:supported?).with(FormatTester)
       FormatTester.support_format?(:my_format)
     end
 
     it "should call the format-specific converter when asked to convert from a given format" do
-      format.expects(:intern).with(FormatTester, "mydata")
+      expect(format).to receive(:intern).with(FormatTester, "mydata")
       FormatTester.convert_from(:my_format, "mydata")
     end
 
     it "should call the format-specific converter when asked to convert from a given format by mime-type" do
-      format.expects(:intern).with(FormatTester, "mydata")
+      expect(format).to receive(:intern).with(FormatTester, "mydata")
       FormatTester.convert_from("text/myformat", "mydata")
     end
 
     it "should call the format-specific converter when asked to convert from a given format by format instance" do
-      format.expects(:intern).with(FormatTester, "mydata")
+      expect(format).to receive(:intern).with(FormatTester, "mydata")
       FormatTester.convert_from(format, "mydata")
     end
 
     it "should raise a FormatError when an exception is encountered when converting from a format" do
-      format.expects(:intern).with(FormatTester, "mydata").raises "foo"
+      expect(format).to receive(:intern).with(FormatTester, "mydata").and_raise("foo")
       expect do
         FormatTester.convert_from(:my_format, "mydata")
       end.to raise_error(
@@ -109,26 +108,26 @@ describe Puppet::Network::FormatHandler do
     end
 
     it "should be able to use a specific hook for converting into multiple instances" do
-      format.expects(:intern_multiple).with(FormatTester, "mydata")
+      expect(format).to receive(:intern_multiple).with(FormatTester, "mydata")
 
       FormatTester.convert_from_multiple(:my_format, "mydata")
     end
 
     it "should raise a FormatError when an exception is encountered when converting multiple items from a format" do
-      format.expects(:intern_multiple).with(FormatTester, "mydata").raises "foo"
+      expect(format).to receive(:intern_multiple).with(FormatTester, "mydata").and_raise("foo")
       expect do
         FormatTester.convert_from_multiple(:my_format, "mydata")
       end.to raise_error(Puppet::Network::FormatHandler::FormatError, 'Could not intern_multiple from my_format: foo')
     end
 
     it "should be able to use a specific hook for rendering multiple instances" do
-      format.expects(:render_multiple).with("mydata")
+      expect(format).to receive(:render_multiple).with("mydata")
 
       FormatTester.render_multiple(:my_format, "mydata")
     end
 
     it "should raise a FormatError when an exception is encountered when rendering multiple items into a format" do
-      format.expects(:render_multiple).with("mydata").raises "foo"
+      expect(format).to receive(:render_multiple).with("mydata").and_raise("foo")
       expect do
         FormatTester.render_multiple(:my_format, "mydata")
       end.to raise_error(Puppet::Network::FormatHandler::FormatError, 'Could not render_multiple to my_format: foo')
@@ -139,13 +138,13 @@ describe Puppet::Network::FormatHandler do
     let(:format) { Puppet::Network::FormatHandler.create(:foo, :mime => "text/foo") }
 
     it "should list as supported a format that reports itself supported" do
-      format.expects(:supported?).returns true
+      expect(format).to receive(:supported?).and_return(true)
       expect(FormatTester.new.support_format?(:foo)).to be_truthy
     end
 
     it "should raise a FormatError when a rendering error is encountered" do
       tester = FormatTester.new
-      format.expects(:render).with(tester).raises "eh"
+      expect(format).to receive(:render).with(tester).and_raise("eh")
 
       expect do
         tester.render(:foo)
@@ -154,45 +153,45 @@ describe Puppet::Network::FormatHandler do
 
     it "should call the format-specific converter when asked to convert to a given format" do
       tester = FormatTester.new
-      format.expects(:render).with(tester).returns "foo"
+      expect(format).to receive(:render).with(tester).and_return("foo")
 
       expect(tester.render(:foo)).to eq("foo")
     end
 
     it "should call the format-specific converter when asked to convert to a given format by mime-type" do
       tester = FormatTester.new
-      format.expects(:render).with(tester).returns "foo"
+      expect(format).to receive(:render).with(tester).and_return("foo")
 
       expect(tester.render("text/foo")).to eq("foo")
     end
 
     it "should call the format converter when asked to convert to a given format instance" do
       tester = FormatTester.new
-      format.expects(:render).with(tester).returns "foo"
+      expect(format).to receive(:render).with(tester).and_return("foo")
 
       expect(tester.render(format)).to eq("foo")
     end
 
     it "should render to the default format if no format is provided when rendering" do
-      FormatTester.expects(:default_format).returns :foo
+      expect(FormatTester).to receive(:default_format).and_return(:foo)
       tester = FormatTester.new
 
-      format.expects(:render).with(tester)
+      expect(format).to receive(:render).with(tester)
       tester.render
     end
 
     it "should call the format-specific converter when asked for the mime-type of a given format" do
       tester = FormatTester.new
-      format.expects(:mime).returns "text/foo"
+      expect(format).to receive(:mime).and_return("text/foo")
 
       expect(tester.mime(:foo)).to eq("text/foo")
     end
 
     it "should return the default format mime-type if no format is provided" do
-      FormatTester.expects(:default_format).returns :foo
+      expect(FormatTester).to receive(:default_format).and_return(:foo)
       tester = FormatTester.new
 
-      format.expects(:mime).returns "text/foo"
+      expect(format).to receive(:mime).and_return("text/foo")
       expect(tester.mime).to eq("text/foo")
     end
   end
