@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 require 'puppet/network/http/connection'
 
@@ -62,131 +61,6 @@ describe Puppet::Network::HTTP::Connection do
     end
   end
 
-  class ConstantErrorValidator
-    def initialize(args)
-      @fails_with = args[:fails_with]
-      @error_string = args[:error_string] || ""
-      @peer_certs = args[:peer_certs] || []
-    end
-
-    def setup_connection(connection)
-      connection.stubs(:start).raises(OpenSSL::SSL::SSLError.new(@fails_with))
-    end
-
-    def peer_certs
-      @peer_certs
-    end
-
-    def verify_errors
-      [@error_string]
-    end
-  end
-
-  class NoProblemsValidator
-    def initialize(cert)
-      @cert = cert
-    end
-
-    def setup_connection(connection)
-    end
-
-    def peer_certs
-      [@cert]
-    end
-
-    def verify_errors
-      []
-    end
-  end
-
-  shared_examples_for 'ssl verifier' do
-    include PuppetSpec::Files
-
-    let (:host) { "my_server" }
-    let (:port) { 8140 }
-
-    before :all do
-      WebMock.disable!
-    end
-
-    after :all do
-      WebMock.enable!
-    end
-
-    it "should provide a useful error message when one is available and certificate validation fails", :unless => Puppet.features.microsoft_windows? do
-      connection = Puppet::Network::HTTP::Connection.new(
-        host, port,
-        :verify => ConstantErrorValidator.new(:fails_with => 'certificate verify failed',
-                                              :error_string => 'shady looking signature'))
-
-      expect do
-        connection.get('request')
-      end.to raise_error(Puppet::Error, "certificate verify failed: [shady looking signature]")
-    end
-
-    it "should provide a helpful error message when hostname was not match with server certificate", :unless => Puppet.features.microsoft_windows? do
-      Puppet[:confdir] = tmpdir('conf')
-
-      connection = Puppet::Network::HTTP::Connection.new(
-      host, port,
-      :verify => ConstantErrorValidator.new(
-        :fails_with => 'hostname was not match with server certificate',
-        :peer_certs => [Puppet::SSL::CertificateAuthority.new.generate(
-          'not_my_server', :dns_alt_names => 'foo,bar,baz')]))
-
-      expect do
-        connection.get('request')
-      end.to raise_error(Puppet::Error) do |error|
-        error.message =~ /\AServer hostname 'my_server' did not match server certificate; expected one of (.+)/
-        expect($1.split(', ')).to match_array(%w[DNS:foo DNS:bar DNS:baz DNS:not_my_server not_my_server])
-      end
-    end
-
-    it "should pass along the error message otherwise" do
-      connection = Puppet::Network::HTTP::Connection.new(
-        host, port,
-        :verify => ConstantErrorValidator.new(:fails_with => 'some other message'))
-
-      expect do
-        connection.get('request')
-      end.to raise_error(/some other message/)
-    end
-
-    it "should check all peer certificates for upcoming expiration", :unless => Puppet.features.microsoft_windows? do
-      Puppet[:confdir] = tmpdir('conf')
-      cert = Puppet::SSL::CertificateAuthority.new.generate(
-        'server', :dns_alt_names => 'foo,bar,baz')
-
-      connection = Puppet::Network::HTTP::Connection.new(
-        host, port,
-        :verify => NoProblemsValidator.new(cert))
-
-      Net::HTTP.any_instance.stubs(:start)
-      Net::HTTP.any_instance.stubs(:request).returns(httpok)
-      Puppet::Network::HTTP::Pool.any_instance.stubs(:setsockopts)
-
-      connection.get('request')
-    end
-  end
-
-  context "when using single use HTTPS connections" do
-    it_behaves_like 'ssl verifier' do
-    end
-  end
-
-  context "when using persistent HTTPS connections" do
-    around :each do |example|
-      pool = Puppet::Network::HTTP::Pool.new
-      Puppet.override(:http_pool => pool) do
-        example.run
-      end
-      pool.close
-    end
-
-    it_behaves_like 'ssl verifier' do
-    end
-  end
-
   context "when response is a redirect" do
     let (:site)       { Puppet::Network::HTTP::Site.new('http', 'my_server', 8140) }
     let (:other_site) { Puppet::Network::HTTP::Site.new('http', 'redirected', 9292) }
@@ -196,7 +70,7 @@ describe Puppet::Network::HTTP::Connection do
     let (:httpredirection) do
       response = Net::HTTPFound.new('1.1', 302, 'Moved Temporarily')
       response['location'] = "#{other_site.addr}/#{other_path}"
-      response.stubs(:read_body).returns("This resource has moved")
+      allow(response).to receive(:read_body).and_return("This resource has moved")
       response
     end
 
@@ -206,24 +80,23 @@ describe Puppet::Network::HTTP::Connection do
     end
 
     it "should redirect to the final resource location" do
-      http = stub('http')
-      http.stubs(:request).returns(httpredirection).then.returns(httpok)
+      http = double('http')
+      allow(http).to receive(:request).and_return(httpredirection, httpok)
 
-      seq = sequence('redirection')
       pool = Puppet.lookup(:http_pool)
-      pool.expects(:with_connection).with(site, anything).yields(http).in_sequence(seq)
-      pool.expects(:with_connection).with(other_site, anything).yields(http).in_sequence(seq)
+      expect(pool).to receive(:with_connection).with(site, anything).and_yield(http).ordered
+      expect(pool).to receive(:with_connection).with(other_site, anything).and_yield(http).ordered
 
       conn = create_connection(site, :verify => verify)
       conn.get('/foo')
     end
 
     def expects_redirection(conn, &block)
-      http = stub('http')
-      http.stubs(:request).returns(httpredirection)
+      http = double('http')
+      allow(http).to receive(:request).and_return(httpredirection)
 
       pool = Puppet.lookup(:http_pool)
-      pool.expects(:with_connection).with(site, anything).yields(http)
+      expect(pool).to receive(:with_connection).with(site, anything).and_yield(http)
       pool
     end
 
@@ -237,7 +110,7 @@ describe Puppet::Network::HTTP::Connection do
       conn = create_connection(site, :verify => verify, :redirect_limit => 0)
 
       pool = expects_redirection(conn)
-      pool.expects(:with_connection).with(other_site, anything).never
+      expect(pool).not_to receive(:with_connection).with(other_site, anything)
 
       expects_limit_exceeded(conn)
     end
@@ -246,7 +119,7 @@ describe Puppet::Network::HTTP::Connection do
       conn = create_connection(site, :verify => verify, :redirect_limit => 1)
 
       pool = expects_redirection(conn)
-      pool.expects(:with_connection).with(other_site, anything).once
+      expect(pool).to receive(:with_connection).with(other_site, anything).once
 
       expects_limit_exceeded(conn)
     end
@@ -255,14 +128,14 @@ describe Puppet::Network::HTTP::Connection do
       conn = create_connection(site, :verify => verify, :redirect_limit => 3)
 
       pool = expects_redirection(conn)
-      pool.expects(:with_connection).with(other_site, anything).times(3)
+      expect(pool).to receive(:with_connection).with(other_site, anything).exactly(3).times
 
       expects_limit_exceeded(conn)
     end
   end
 
   context "when response indicates an overloaded server" do
-    let(:http) { stub('http') }
+    let(:http) { double('http', :started? => true) }
     let(:site) { Puppet::Network::HTTP::Site.new('http', 'my_server', 8140) }
     let(:verify) { Puppet::SSL::Validator.no_validator }
     let(:httpunavailable) { Net::HTTPServiceUnavailable.new('1.1', 503, 'Service Unavailable') }
@@ -281,10 +154,11 @@ describe Puppet::Network::HTTP::Connection do
     end
 
     it "should return a 503 response if Retry-After is not set" do
-      http.stubs(:request).returns(httpunavailable)
+      allow(http).to receive(:request).and_return(httpunavailable)
 
       pool = Puppet.lookup(:http_pool)
-      pool.expects(:with_connection).with(site, anything).yields(http)
+      expect(pool).to receive(:with_connection).with(site, anything).and_yield(http)
+      allow(http).to receive(:finish)
 
       result = subject.get('/foo')
 
@@ -293,24 +167,37 @@ describe Puppet::Network::HTTP::Connection do
 
     it "should return a 503 response if Retry-After is not convertible to an Integer or RFC 2822 Date" do
       httpunavailable['Retry-After'] = 'foo'
-      http.stubs(:request).returns(httpunavailable)
+      allow(http).to receive(:request).and_return(httpunavailable)
+      allow(http).to receive(:finish)
 
       pool = Puppet.lookup(:http_pool)
-      pool.expects(:with_connection).with(site, anything).yields(http)
+      expect(pool).to receive(:with_connection).with(site, anything).and_yield(http)
 
       result = subject.get('/foo')
 
       expect(result.code).to eq(503)
     end
 
-    it "should sleep and retry if Retry-After is an Integer" do
-      httpunavailable['Retry-After'] = '42'
-      http.stubs(:request).returns(httpunavailable).then.returns(httpok)
+    it "should close the connection before sleeping" do
+      allow(http).to receive(:request).and_return(httpunavailable, httpok)
 
       pool = Puppet.lookup(:http_pool)
-      pool.expects(:with_connection).with(site, anything).twice.yields(http)
+      expect(pool).to receive(:with_connection).with(site, anything).and_yield(http)
 
-      ::Kernel.expects(:sleep).with(42)
+      expect(http).to receive(:finish)
+
+      subject.get('/foo')
+    end
+
+    it "should sleep and retry if Retry-After is an Integer" do
+      httpunavailable['Retry-After'] = '42'
+      allow(http).to receive(:request).and_return(httpunavailable, httpok)
+      allow(http).to receive(:finish)
+
+      pool = Puppet.lookup(:http_pool)
+      expect(pool).to receive(:with_connection).with(site, anything).twice.and_yield(http)
+
+      expect(::Kernel).to receive(:sleep).with(42)
 
       result = subject.get('/foo')
 
@@ -319,15 +206,16 @@ describe Puppet::Network::HTTP::Connection do
 
     it "should sleep and retry if Retry-After is an RFC 2822 Date" do
       httpunavailable['Retry-After'] = 'Wed, 13 Apr 2005 15:18:05 GMT'
-      http.stubs(:request).returns(httpunavailable).then.returns(httpok)
+      allow(http).to receive(:request).and_return(httpunavailable, httpok)
+      allow(http).to receive(:finish)
 
       now = DateTime.new(2005, 4, 13, 8, 17, 5, '-07:00')
-      DateTime.stubs(:now).returns(now)
+      allow(DateTime).to receive(:now).and_return(now)
 
       pool = Puppet.lookup(:http_pool)
-      pool.expects(:with_connection).with(site, anything).twice.yields(http)
+      expect(pool).to receive(:with_connection).with(site, anything).twice.and_yield(http)
 
-      ::Kernel.expects(:sleep).with(60)
+      expect(::Kernel).to receive(:sleep).with(60)
 
       result = subject.get('/foo')
 
@@ -336,13 +224,14 @@ describe Puppet::Network::HTTP::Connection do
 
     it "should sleep for no more than the Puppet runinterval" do
       httpunavailable['Retry-After'] = '60'
-      http.stubs(:request).returns(httpunavailable).then.returns(httpok)
+      allow(http).to receive(:request).and_return(httpunavailable, httpok)
+      allow(http).to receive(:finish)
       Puppet[:runinterval] = 30
 
       pool = Puppet.lookup(:http_pool)
-      pool.expects(:with_connection).with(site, anything).twice.yields(http)
+      expect(pool).to receive(:with_connection).with(site, anything).twice.and_yield(http)
 
-      ::Kernel.expects(:sleep).with(30)
+      expect(::Kernel).to receive(:sleep).with(30)
 
       subject.get('/foo')
     end
@@ -379,18 +268,44 @@ describe Puppet::Network::HTTP::Connection do
   end
 
   def expect_request_with_basic_auth
-    Net::HTTP.any_instance.expects(:request).with do |request|
+    expect_any_instance_of(Net::HTTP).to receive(:request) do |_, request|
       expect(request['authorization']).to match(/^Basic/)
-    end.returns(httpok)
+    end.and_return(httpok)
   end
 
   it "sets HTTP User-Agent header" do
     puppet_ua = "Puppet/#{Puppet.version} Ruby/#{RUBY_VERSION}-p#{RUBY_PATCHLEVEL} (#{RUBY_PLATFORM})"
 
-    Net::HTTP.any_instance.expects(:request).with do |request|
+    expect_any_instance_of(Net::HTTP).to receive(:request) do |_, request|
       expect(request['User-Agent']).to eq(puppet_ua)
-    end.returns(httpok)
+    end.and_return(httpok)
 
     subject.get('/path')
   end
+
+  describe 'connection request errors' do
+    it "logs and raises generic http errors" do
+      generic_error = Net::HTTPError.new('generic error', double("response"))
+      expect_any_instance_of(Net::HTTP).to receive(:request).and_raise(generic_error)
+
+      expect(Puppet).to receive(:log_exception).with(anything, /^.*failed: generic error$/)
+      expect { subject.get('/foo') }.to raise_error(generic_error)
+    end
+
+    it "logs and raises timeout errors" do
+      timeout_error = Timeout::Error.new
+      expect_any_instance_of(Net::HTTP).to receive(:request).and_raise(timeout_error)
+
+      expect(Puppet).to receive(:log_exception).with(anything, /^.*timed out after .* seconds$/)
+      expect { subject.get('/foo') }.to raise_error(timeout_error)
+    end
+
+    it "logs and raises eof errors" do
+      eof_error = EOFError
+      expect_any_instance_of(Net::HTTP).to receive(:request).and_raise(eof_error)
+
+      expect(Puppet).to receive(:log_exception).with(anything, /^.*interrupted after .* seconds$/)
+      expect { subject.get('/foo') }.to raise_error(eof_error)
+    end
+  end
 end
