@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 require 'puppet/network/http_pool'
 
@@ -51,22 +50,22 @@ describe Puppet::Network::HttpPool do
         ca_cert_file = File.expand_path('/path/to/ssl/certs/ca_cert.pem')
 
         Puppet[:ssl_client_ca_auth] = ca_cert_file
-        Puppet::FileSystem.stubs(:exist?).with(ca_cert_file).returns(true)
+        allow(Puppet::FileSystem).to receive(:exist?).with(ca_cert_file).and_return(true)
       end
 
       def setup_standard_hostcert
         host_cert_file = File.expand_path('/path/to/ssl/certs/host_cert.pem')
-        Puppet::FileSystem.stubs(:exist?).with(host_cert_file).returns(true)
+        allow(Puppet::FileSystem).to receive(:exist?).with(host_cert_file).and_return(true)
 
         Puppet[:hostcert] = host_cert_file
       end
 
       def setup_standard_ssl_host
-        cert = stub('cert', :content => 'real_cert')
-        key  = stub('key',  :content => 'real_key')
-        host = stub('host', :certificate => cert, :key => key, :ssl_store => stub('store'))
+        cert = double('cert', :content => 'real_cert')
+        key  = double('key',  :content => 'real_key')
+        host = double('host', :certificate => cert, :key => key, :ssl_store => double('store'))
 
-        Puppet::SSL::Host.stubs(:localhost).returns(host)
+        allow(Puppet::SSL::Host).to receive(:localhost).and_return(host)
       end
 
       before do
@@ -78,14 +77,24 @@ describe Puppet::Network::HttpPool do
       it 'enables peer verification by default' do
         response = Net::HTTPOK.new('1.1', 200, 'body')
         conn = Puppet::Network::HttpPool.http_instance("me", 54321, true)
-        conn.expects(:execute_request).with { |http, request| expect(http.verify_mode).to eq(OpenSSL::SSL::VERIFY_PEER) }.returns(response)
+        expect(conn).to receive(:execute_request) do |http, _|
+          expect(http.verify_mode).to eq(OpenSSL::SSL::VERIFY_PEER)
+
+          response
+        end
+
         conn.get('/')
       end
 
       it 'can disable peer verification' do
         response = Net::HTTPOK.new('1.1', 200, 'body')
         conn = Puppet::Network::HttpPool.http_instance("me", 54321, true, false)
-        conn.expects(:execute_request).with { |http, request| expect(http.verify_mode).to eq(OpenSSL::SSL::VERIFY_NONE) }.returns(response)
+        expect(conn).to receive(:execute_request) do |http, _|
+          expect(http.verify_mode).to eq(OpenSSL::SSL::VERIFY_NONE)
+
+          response
+        end
+
         conn.get('/')
       end
     end
