@@ -9,6 +9,6 @@ describe "lookup function" do
   let :scope do create_test_scope_for_node('foo') end
 
   it 'should raise an error since this function is converted to 4x API)' do
-    expect { scope.function_lookup(['key']) }.to raise_error(Puppet::ParseError, /converted to 4x API/)
+    expect { scope.function_lookup(['key']) }.to raise_error(Puppet::ParseError, /can only be called using the 4.x function API/)
   end
 end
