@@ -26,7 +26,7 @@ describe Puppet::Parser::Resource::Param do
     it "includes file/line context in errors" do
       expect {
         Puppet::Parser::Resource::Param.new(:file => 'foo.pp', :line => 42)
-      }.to raise_error(Puppet::Error, /foo.pp:42/)
+      }.to raise_error(Puppet::Error, /\(file: foo.pp, line: 42\)/)
     end
   end
 end
