@@ -34,20 +34,18 @@ describe 'Puppet::Pops::MigrationMigrationChecker' do
   describe "when there is no MigrationChecker in the PuppetContext" do
     it "a null implementation of the MigrationChecker gets created (once per impl that needs one)" do
       migration_checker = Puppet::Pops::Migration::MigrationChecker.new()
-      Puppet::Pops::Migration::MigrationChecker.expects(:new).at_least_once.returns(migration_checker)
+      expect(Puppet::Pops::Migration::MigrationChecker).to receive(:new).at_least(:once).and_return(migration_checker)
       expect(Puppet::Pops::Parser::EvaluatingParser.new.evaluate_string(scope, "1", __FILE__)).to eq(1)
-      Puppet::Pops::Migration::MigrationChecker.unstub(:new)
     end
   end
 
   describe "when there is a MigrationChecker in the Puppet Context" do
     it "does not create any MigrationChecker instances when parsing and evaluating" do
-      migration_checker = mock()
-      Puppet::Pops::Migration::MigrationChecker.expects(:new).never
+      migration_checker = double()
+      expect(Puppet::Pops::Migration::MigrationChecker).not_to receive(:new)
       Puppet.override({:migration_checker => migration_checker}, "test-context") do
         Puppet::Pops::Parser::EvaluatingParser.new.evaluate_string(scope, "true", __FILE__)
       end
-      Puppet::Pops::Migration::MigrationChecker.unstub(:new)
     end
   end
 end
