@@ -7,13 +7,13 @@ module EgrammarLexer2Spec
   def tokens_scanned_from(s)
     lexer = Puppet::Pops::Parser::Lexer2.new
     lexer.string = s
-    tokens = lexer.fullscan[0..-2]
+    lexer.fullscan[0..-2]
   end
 
   def epp_tokens_scanned_from(s)
     lexer = Puppet::Pops::Parser::Lexer2.new
     lexer.string = s
-    tokens = lexer.fullscan_epp[0..-2]
+    lexer.fullscan_epp[0..-2]
   end
 end
 
@@ -540,6 +540,15 @@ describe 'Lexer2' do
         expect_issue(code, Puppet::Pops::Issues::HEREDOC_WITHOUT_TEXT)
       end
 
+      it 'detects and reports HEREDOC_EMPTY_ENDTAG' do
+        code = <<-CODE
+        @("")
+        Text
+        |-END
+        CODE
+        expect_issue(code, Puppet::Pops::Issues::HEREDOC_EMPTY_ENDTAG)
+      end
+
       it 'detects and reports HEREDOC_MULTIPLE_AT_ESCAPES' do
         code = <<-CODE
         @(END:syntax/tst)
@@ -867,8 +876,8 @@ describe Puppet::Pops::Parser::Lexer2 do
   # Section 3.2.1.3 of Ruby spec guarantees that \u strings are encoded as UTF-8
   # Runes (may show up as garbage if font is not available): ᚠᛇᚻ᛫ᛒᛦᚦ᛫ᚠᚱᚩᚠᚢᚱ᛫ᚠᛁᚱᚪ᛫ᚷᛖᚻᚹᛦᛚᚳᚢᛗ
   let (:rune_utf8) {
-    "\u16A0\u16C7\u16BB\u16EB\u16D2\u16E6\u16A6\u16EB\u16A0\u16B1\u16A9\u16A0\u16A2"
-    "\u16B1\u16EB\u16A0\u16C1\u16B1\u16AA\u16EB\u16B7\u16D6\u16BB\u16B9\u16E6\u16DA"
+    "\u16A0\u16C7\u16BB\u16EB\u16D2\u16E6\u16A6\u16EB\u16A0\u16B1\u16A9\u16A0\u16A2" +
+    "\u16B1\u16EB\u16A0\u16C1\u16B1\u16AA\u16EB\u16B7\u16D6\u16BB\u16B9\u16E6\u16DA" +
     "\u16B3\u16A2\u16D7"
   }
 
@@ -893,7 +902,7 @@ describe Puppet::Pops::Parser::Lexer2 do
         manifest = file_containing('manifest.pp', manifest_code)
 
         expect {
-          lexed_file = described_class.new.lex_file(manifest)
+          described_class.new.lex_file(manifest)
         }.to raise_error(Puppet::ParseErrorWithIssue,
           'Illegal UTF-8 Byte Order mark at beginning of input: [EF BB BF] - remove these from the puppet source')
     end
