@@ -41,8 +41,8 @@ describe 'The type factory' do
       expect(TypeFactory.scalar().class()).to eq(PScalarType)
     end
 
-    it 'data() returns PDataType' do
-      expect(TypeFactory.data().class()).to eq(PDataType)
+    it 'data() returns Data' do
+      expect(TypeFactory.data.name).to eq('Data')
     end
 
     it 'optional() returns POptionalType' do
@@ -133,21 +133,21 @@ describe 'The type factory' do
       expect(pr.type_name).to eq('X')
     end
 
-    it 'host_class() creates a generic PHostClassType' do
+    it 'host_class() creates a generic PClassType' do
       hc = TypeFactory.host_class()
-      expect(hc.class()).to eq(PHostClassType)
+      expect(hc.class()).to eq(PClassType)
       expect(hc.class_name).to eq(nil)
     end
 
-    it 'host_class(x) creates a PHostClassType[x]' do
+    it 'host_class(x) creates a PClassType[x]' do
       hc = TypeFactory.host_class('x')
-      expect(hc.class()).to eq(PHostClassType)
+      expect(hc.class()).to eq(PClassType)
       expect(hc.class_name).to eq('x')
     end
 
-    it 'host_class(::x) creates a PHostClassType[x]' do
+    it 'host_class(::x) creates a PClassType[x]' do
       hc = TypeFactory.host_class('::x')
-      expect(hc.class()).to eq(PHostClassType)
+      expect(hc.class()).to eq(PClassType)
       expect(hc.class_name).to eq('x')
     end
 
@@ -163,24 +163,24 @@ describe 'The type factory' do
       expect(at.element_type.class).to eq(PIntegerType)
     end
 
-    it 'array_of_data returns PArrayType[PDataType]' do
+    it 'array_of_data returns Array[Data]' do
       at = TypeFactory.array_of_data
       expect(at.class()).to eq(PArrayType)
-      expect(at.element_type.class).to eq(PDataType)
+      expect(at.element_type.name).to eq('Data')
     end
 
-    it 'hash_of_data returns PHashType[PScalarType,PDataType]' do
+    it 'hash_of_data returns Hash[String,Data]' do
       ht = TypeFactory.hash_of_data
       expect(ht.class()).to eq(PHashType)
-      expect(ht.key_type.class).to eq(PScalarType)
-      expect(ht.value_type.class).to eq(PDataType)
+      expect(ht.key_type.class).to eq(PStringType)
+      expect(ht.value_type.name).to eq('Data')
     end
 
-    it 'ruby(1) returns PRuntimeType[ruby, \'Fixnum\']' do
+    it 'ruby(1) returns PRuntimeType[ruby, \'Integer\']' do
       ht = TypeFactory.ruby(1)
       expect(ht.class()).to eq(PRuntimeType)
       expect(ht.runtime).to eq(:ruby)
-      expect(ht.runtime_type_name).to eq('Fixnum')
+      expect(ht.runtime_type_name).to eq(1.class.name)
     end
 
     it 'a size constrained collection can be created from array' do
