@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 require 'puppet/provider/cisco'
@@ -9,7 +8,7 @@ describe Puppet::Provider::Cisco do
   end
 
   it "should create a cisco device instance" do
-    Puppet::Util::NetworkDevice::Cisco::Device.expects(:new).returns :device
+    expect(Puppet::Util::NetworkDevice::Cisco::Device).to receive(:new).and_return(:device)
     expect(Puppet::Provider::Cisco.device(:url)).to eq(:device)
   end
 end
