@@ -1,5 +1,3 @@
-#! /usr/bin/env ruby
-
 require 'spec_helper'
 
 describe Puppet::Type.type(:file).provider(:posix), :if => Puppet.features.posix? do
@@ -41,7 +39,7 @@ describe Puppet::Type.type(:file).provider(:posix), :if => Puppet.features.posix
 
   describe "#uid2name" do
     it "should return the name of the user identified by the id" do
-      Etc.stubs(:getpwuid).with(501).returns(Struct::Passwd.new('jilluser', nil, 501))
+      allow(Etc).to receive(:getpwuid).with(501).and_return(Struct::Passwd.new('jilluser', nil, 501))
 
       expect(provider.uid2name(501)).to eq('jilluser')
     end
@@ -55,7 +53,7 @@ describe Puppet::Type.type(:file).provider(:posix), :if => Puppet.features.posix
     end
 
     it "should return nil if the user doesn't exist" do
-      Etc.expects(:getpwuid).raises(ArgumentError, "can't find user for 999")
+      expect(Etc).to receive(:getpwuid).and_raise(ArgumentError, "can't find user for 999")
 
       expect(provider.uid2name(999)).to eq(nil)
     end
@@ -65,8 +63,8 @@ describe Puppet::Type.type(:file).provider(:posix), :if => Puppet.features.posix
     it "should return the id of the user if it exists" do
       passwd = Struct::Passwd.new('bobbo', nil, 502)
 
-      Etc.stubs(:getpwnam).with('bobbo').returns(passwd)
-      Etc.stubs(:getpwuid).with(502).returns(passwd)
+      allow(Etc).to receive(:getpwnam).with('bobbo').and_return(passwd)
+      allow(Etc).to receive(:getpwuid).with(502).and_return(passwd)
 
       expect(provider.name2uid('bobbo')).to eq(502)
     end
@@ -76,7 +74,7 @@ describe Puppet::Type.type(:file).provider(:posix), :if => Puppet.features.posix
     end
 
     it "should return false if the user doesn't exist" do
-      Etc.stubs(:getpwnam).with('chuck').raises(ArgumentError, "can't find user for chuck")
+      allow(Etc).to receive(:getpwnam).with('chuck').and_raise(ArgumentError, "can't find user for chuck")
 
       expect(provider.name2uid('chuck')).to eq(false)
     end
@@ -95,8 +93,8 @@ describe Puppet::Type.type(:file).provider(:posix), :if => Puppet.features.posix
     end
 
     it "should warn and return :silly if the value is beyond the maximum uid" do
-      stat = stub('stat', :uid => Puppet[:maximum_uid] + 1)
-      resource.stubs(:stat).returns(stat)
+      stat = double('stat', :uid => Puppet[:maximum_uid] + 1)
+      allow(resource).to receive(:stat).and_return(stat)
 
       expect(provider.owner).to eq(:silly)
       expect(@logs).to be_any {|log| log.level == :warning and log.message =~ /Apparently using negative UID/}
@@ -105,27 +103,27 @@ describe Puppet::Type.type(:file).provider(:posix), :if => Puppet.features.posix
 
   describe "#owner=" do
     it "should set the owner but not the group of the file" do
-      File.expects(:lchown).with(15, nil, resource[:path])
+      expect(File).to receive(:lchown).with(15, nil, resource[:path])
 
       provider.owner = 15
     end
 
     it "should chown a link if managing links" do
       resource[:links] = :manage
-      File.expects(:lchown).with(20, nil, resource[:path])
+      expect(File).to receive(:lchown).with(20, nil, resource[:path])
 
       provider.owner = 20
     end
 
     it "should chown a link target if following links" do
       resource[:links] = :follow
-      File.expects(:chown).with(20, nil, resource[:path])
+      expect(File).to receive(:chown).with(20, nil, resource[:path])
 
       provider.owner = 20
     end
 
     it "should pass along any error encountered setting the owner" do
-      File.expects(:lchown).raises(ArgumentError)
+      expect(File).to receive(:lchown).and_raise(ArgumentError)
 
       expect { provider.owner = 25 }.to raise_error(Puppet::Error, /Failed to set owner to '25'/)
     end
@@ -133,7 +131,7 @@ describe Puppet::Type.type(:file).provider(:posix), :if => Puppet.features.posix
 
   describe "#gid2name" do
     it "should return the name of the group identified by the id" do
-      Etc.stubs(:getgrgid).with(501).returns(Struct::Passwd.new('unicorns', nil, nil, 501))
+      allow(Etc).to receive(:getgrgid).with(501).and_return(Struct::Passwd.new('unicorns', nil, nil, 501))
 
       expect(provider.gid2name(501)).to eq('unicorns')
     end
@@ -147,7 +145,7 @@ describe Puppet::Type.type(:file).provider(:posix), :if => Puppet.features.posix
     end
 
     it "should return nil if the group doesn't exist" do
-      Etc.expects(:getgrgid).raises(ArgumentError, "can't find group for 999")
+      expect(Etc).to receive(:getgrgid).and_raise(ArgumentError, "can't find group for 999")
 
       expect(provider.gid2name(999)).to eq(nil)
     end
@@ -157,8 +155,8 @@ describe Puppet::Type.type(:file).provider(:posix), :if => Puppet.features.posix
     it "should return the id of the group if it exists" do
       passwd = Struct::Passwd.new('penguins', nil, nil, 502)
 
-      Etc.stubs(:getgrnam).with('penguins').returns(passwd)
-      Etc.stubs(:getgrgid).with(502).returns(passwd)
+      allow(Etc).to receive(:getgrnam).with('penguins').and_return(passwd)
+      allow(Etc).to receive(:getgrgid).with(502).and_return(passwd)
 
       expect(provider.name2gid('penguins')).to eq(502)
     end
@@ -168,7 +166,7 @@ describe Puppet::Type.type(:file).provider(:posix), :if => Puppet.features.posix
     end
 
     it "should return false if the group doesn't exist" do
-      Etc.stubs(:getgrnam).with('wombats').raises(ArgumentError, "can't find group for wombats")
+      allow(Etc).to receive(:getgrnam).with('wombats').and_raise(ArgumentError, "can't find group for wombats")
 
       expect(provider.name2gid('wombats')).to eq(false)
     end
@@ -188,8 +186,8 @@ describe Puppet::Type.type(:file).provider(:posix), :if => Puppet.features.posix
     end
 
     it "should warn and return :silly if the value is beyond the maximum gid" do
-      stat = stub('stat', :gid => Puppet[:maximum_uid] + 1)
-      resource.stubs(:stat).returns(stat)
+      stat = double('stat', :gid => Puppet[:maximum_uid] + 1)
+      allow(resource).to receive(:stat).and_return(stat)
 
       expect(provider.group).to eq(:silly)
       expect(@logs).to be_any {|log| log.level == :warning and log.message =~ /Apparently using negative GID/}
@@ -198,27 +196,27 @@ describe Puppet::Type.type(:file).provider(:posix), :if => Puppet.features.posix
 
   describe "#group=" do
     it "should set the group but not the owner of the file" do
-      File.expects(:lchown).with(nil, 15, resource[:path])
+      expect(File).to receive(:lchown).with(nil, 15, resource[:path])
 
       provider.group = 15
     end
 
     it "should change the group for a link if managing links" do
       resource[:links] = :manage
-      File.expects(:lchown).with(nil, 20, resource[:path])
+      expect(File).to receive(:lchown).with(nil, 20, resource[:path])
 
       provider.group = 20
     end
 
     it "should change the group for a link target if following links" do
       resource[:links] = :follow
-      File.expects(:chown).with(nil, 20, resource[:path])
+      expect(File).to receive(:chown).with(nil, 20, resource[:path])
 
       provider.group = 20
     end
 
     it "should pass along any error encountered setting the group" do
-      File.expects(:lchown).raises(ArgumentError)
+      expect(File).to receive(:lchown).and_raise(ArgumentError)
 
       expect { provider.group = 25 }.to raise_error(Puppet::Error, /Failed to set group to '25'/)
     end
