@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 require 'puppet/provider/ldap'
@@ -9,10 +8,10 @@ describe Puppet::Provider::Ldap do
   end
 
   it "should be able to define its manager" do
-    manager = mock 'manager'
-    Puppet::Util::Ldap::Manager.expects(:new).returns manager
-    @class.stubs :mk_resource_methods
-    manager.expects(:manages).with(:one)
+    manager = double('manager')
+    expect(Puppet::Util::Ldap::Manager).to receive(:new).and_return(manager)
+    allow(@class).to receive(:mk_resource_methods)
+    expect(manager).to receive(:manages).with(:one)
     expect(@class.manages(:one)).to equal(manager)
     expect(@class.manager).to equal(manager)
   end
@@ -22,10 +21,10 @@ describe Puppet::Provider::Ldap do
   end
 
   it "should create its resource getter/setter methods when the manager is defined" do
-    manager = mock 'manager'
-    Puppet::Util::Ldap::Manager.expects(:new).returns manager
-    @class.expects :mk_resource_methods
-    manager.stubs(:manages)
+    manager = double('manager')
+    expect(Puppet::Util::Ldap::Manager).to receive(:new).and_return(manager)
+    expect(@class).to receive(:mk_resource_methods)
+    allow(manager).to receive(:manages)
     expect(@class.manages(:one)).to equal(manager)
   end
 
@@ -35,14 +34,14 @@ describe Puppet::Provider::Ldap do
 
   describe "when providing a list of instances" do
     it "should convert all results returned from the manager's :search method into provider instances" do
-      manager = mock 'manager'
-      @class.stubs(:manager).returns manager
+      manager = double('manager')
+      allow(@class).to receive(:manager).and_return(manager)
 
-      manager.expects(:search).returns %w{one two three}
+      expect(manager).to receive(:search).and_return(%w{one two three})
 
-      @class.expects(:new).with("one").returns(1)
-      @class.expects(:new).with("two").returns(2)
-      @class.expects(:new).with("three").returns(3)
+      expect(@class).to receive(:new).with("one").and_return(1)
+      expect(@class).to receive(:new).with("two").and_return(2)
+      expect(@class).to receive(:new).with("three").and_return(3)
 
       expect(@class.instances).to eq([1,2,3])
     end
@@ -54,29 +53,29 @@ describe Puppet::Provider::Ldap do
 
   describe "when prefetching" do
     before do
-      @manager = mock 'manager'
-      @class.stubs(:manager).returns @manager
+      @manager = double('manager')
+      allow(@class).to receive(:manager).and_return(@manager)
 
-      @resource = mock 'resource'
+      @resource = double('resource')
 
       @resources = {"one" => @resource}
     end
 
     it "should find an entry for each passed resource" do
-      @manager.expects(:find).with("one").returns nil
+      expect(@manager).to receive(:find).with("one").and_return(nil)
 
-      @class.stubs(:new)
-      @resource.stubs(:provider=)
+      allow(@class).to receive(:new)
+      allow(@resource).to receive(:provider=)
       @class.prefetch(@resources)
     end
 
     describe "resources that do not exist" do
       it "should create a provider with :ensure => :absent" do
-        @manager.expects(:find).with("one").returns nil
+        expect(@manager).to receive(:find).with("one").and_return(nil)
 
-        @class.expects(:new).with(:ensure => :absent).returns "myprovider"
+        expect(@class).to receive(:new).with(:ensure => :absent).and_return("myprovider")
 
-        @resource.expects(:provider=).with("myprovider")
+        expect(@resource).to receive(:provider=).with("myprovider")
 
         @class.prefetch(@resources)
       end
@@ -84,21 +83,21 @@ describe Puppet::Provider::Ldap do
 
     describe "resources that exist" do
       it "should create a provider with the results of the find" do
-        @manager.expects(:find).with("one").returns("one" => "two")
+        expect(@manager).to receive(:find).with("one").and_return("one" => "two")
 
-        @class.expects(:new).with("one" => "two", :ensure => :present).returns "myprovider"
+        expect(@class).to receive(:new).with("one" => "two", :ensure => :present).and_return("myprovider")
 
-        @resource.expects(:provider=).with("myprovider")
+        expect(@resource).to receive(:provider=).with("myprovider")
 
         @class.prefetch(@resources)
       end
 
       it "should set :ensure to :present in the returned values" do
-        @manager.expects(:find).with("one").returns("one" => "two")
+        expect(@manager).to receive(:find).with("one").and_return("one" => "two")
 
-        @class.expects(:new).with("one" => "two", :ensure => :present).returns "myprovider"
+        expect(@class).to receive(:new).with("one" => "two", :ensure => :present).and_return("myprovider")
 
-        @resource.expects(:provider=).with("myprovider")
+        expect(@resource).to receive(:provider=).with("myprovider")
 
         @class.prefetch(@resources)
       end
@@ -111,22 +110,22 @@ describe Puppet::Provider::Ldap do
     end
 
     it "should fail if the manager is invalid" do
-      manager = stub "manager", :valid? => false
-      @class.stubs(:manager).returns manager
+      manager = double("manager", :valid? => false)
+      allow(@class).to receive(:manager).and_return(manager)
       expect { @class.new }.to raise_error(Puppet::DevError)
     end
 
     describe "with a hash" do
       before do
-        @manager = stub "manager", :valid? => true
-        @class.stubs(:manager).returns @manager
+        @manager = double("manager", :valid? => true)
+        allow(@class).to receive(:manager).and_return(@manager)
 
-        @resource_class = mock 'resource_class'
-        @class.stubs(:resource_type).returns @resource_class
+        @resource_class = double('resource_class')
+        allow(@class).to receive(:resource_type).and_return(@resource_class)
 
-        @property_class = stub 'property_class', :array_matching => :all, :superclass => Puppet::Property
-        @resource_class.stubs(:attrclass).with(:one).returns(@property_class)
-        @resource_class.stubs(:valid_parameter?).returns true
+        @property_class = double('property_class', :array_matching => :all, :superclass => Puppet::Property)
+        allow(@resource_class).to receive(:attrclass).with(:one).and_return(@property_class)
+        allow(@resource_class).to receive(:valid_parameter?).and_return(true)
       end
 
       it "should store a copy of the hash as its ldap_properties" do
@@ -135,29 +134,29 @@ describe Puppet::Provider::Ldap do
       end
 
       it "should only store the first value of each value array for those attributes that do not match all values" do
-        @property_class.expects(:array_matching).returns :first
+        expect(@property_class).to receive(:array_matching).and_return(:first)
         instance = @class.new(:one => %w{two three})
         expect(instance.properties).to eq({:one => "two"})
       end
 
       it "should store the whole value array for those attributes that match all values" do
-        @property_class.expects(:array_matching).returns :all
+        expect(@property_class).to receive(:array_matching).and_return(:all)
         instance = @class.new(:one => %w{two three})
         expect(instance.properties).to eq({:one => %w{two three}})
       end
 
       it "should only use the first value for attributes that are not properties" do
         # Yay.  hackish, but easier than mocking everything.
-        @resource_class.expects(:attrclass).with(:a).returns Puppet::Type.type(:user).attrclass(:name)
-        @property_class.stubs(:array_matching).returns :all
+        expect(@resource_class).to receive(:attrclass).with(:a).and_return(Puppet::Type.type(:user).attrclass(:name))
+        allow(@property_class).to receive(:array_matching).and_return(:all)
 
         instance = @class.new(:one => %w{two three}, :a => %w{b c})
         expect(instance.properties).to eq({:one => %w{two three}, :a => "b"})
       end
 
       it "should discard any properties not valid in the resource class" do
-        @resource_class.expects(:valid_parameter?).with(:a).returns false
-        @property_class.stubs(:array_matching).returns :all
+        expect(@resource_class).to receive(:valid_parameter?).with(:a).and_return(false)
+        allow(@property_class).to receive(:array_matching).and_return(:all)
 
         instance = @class.new(:one => %w{two three}, :a => %w{b})
         expect(instance.properties).to eq({:one => %w{two three}})
@@ -167,13 +166,13 @@ describe Puppet::Provider::Ldap do
 
   describe "when an instance" do
     before do
-      @manager = stub "manager", :valid? => true
-      @class.stubs(:manager).returns @manager
+      @manager = double("manager", :valid? => true)
+      allow(@class).to receive(:manager).and_return(@manager)
       @instance = @class.new
 
-      @property_class = stub 'property_class', :array_matching => :all, :superclass => Puppet::Property
-      @resource_class = stub 'resource_class', :attrclass => @property_class, :valid_parameter? => true, :validproperties => [:one, :two]
-      @class.stubs(:resource_type).returns @resource_class
+      @property_class = double('property_class', :array_matching => :all, :superclass => Puppet::Property)
+      @resource_class = double('resource_class', :attrclass => @property_class, :valid_parameter? => true, :validproperties => [:one, :two])
+      allow(@class).to receive(:resource_type).and_return(@resource_class)
     end
 
     it "should have a method for creating the ldap entry" do
@@ -200,22 +199,22 @@ describe Puppet::Provider::Ldap do
 
     describe "is being flushed" do
       it "should call the manager's :update method with its name, current attributes, and desired attributes" do
-        @instance.stubs(:name).returns "myname"
-        @instance.stubs(:ldap_properties).returns(:one => :two)
-        @instance.stubs(:properties).returns(:three => :four)
-        @manager.expects(:update).with(@instance.name, {:one => :two}, {:three => :four})
+        allow(@instance).to receive(:name).and_return("myname")
+        allow(@instance).to receive(:ldap_properties).and_return(:one => :two)
+        allow(@instance).to receive(:properties).and_return(:three => :four)
+        expect(@manager).to receive(:update).with(@instance.name, {:one => :two}, {:three => :four})
         @instance.flush
       end
     end
 
     describe "is being created" do
       before do
-        @rclass = mock 'resource_class'
-        @rclass.stubs(:validproperties).returns([:one, :two])
-        @resource = mock 'resource'
-        @resource.stubs(:class).returns @rclass
-        @resource.stubs(:should).returns nil
-        @instance.stubs(:resource).returns @resource
+        @rclass = double('resource_class')
+        allow(@rclass).to receive(:validproperties).and_return([:one, :two])
+        @resource = double('resource')
+        allow(@resource).to receive(:class).and_return(@rclass)
+        allow(@resource).to receive(:should).and_return(nil)
+        allow(@instance).to receive(:resource).and_return(@resource)
       end
 
       it "should set its :ensure value to :present" do
@@ -224,8 +223,8 @@ describe Puppet::Provider::Ldap do
       end
 
       it "should set all of the other attributes from the resource" do
-        @resource.expects(:should).with(:one).returns "oneval"
-        @resource.expects(:should).with(:two).returns "twoval"
+        expect(@resource).to receive(:should).with(:one).and_return("oneval")
+        expect(@resource).to receive(:should).with(:two).and_return("twoval")
 
         @instance.create
         expect(@instance.properties[:one]).to eq("oneval")
