@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 require 'shared_behaviours/all_parsedfile_providers'
 
@@ -51,9 +50,6 @@ FSTAB
       expect { described_class.to_line(parse[0]) }.to_not raise_error
     end
 
-#   it_should_behave_like "all parsedfile providers",
-#     provider_class, my_fixtures('*.fstab')
-
     describe "on Solaris", :if => Facter.value(:osfamily) == 'Solaris' do
       it "should extract device from the first field" do
         expect(described_class.parse_line(vfstab_sample)[:device]).to eq('/dev/dsk/c0d0s0')
@@ -109,13 +105,12 @@ FSTAB
         expect(described_class.parse_line(fstab_sample)[:pass]).to eq("2")
       end
     end
-
   end
 
   describe "mountinstances" do
     it "should get name from mountoutput found on Solaris" do
-      Facter.stubs(:value).with(:osfamily).returns 'Solaris'
-      described_class.stubs(:mountcmd).returns(File.read(my_fixture('solaris.mount')))
+      allow(Facter).to receive(:value).with(:osfamily).and_return('Solaris')
+      allow(described_class).to receive(:mountcmd).and_return(File.read(my_fixture('solaris.mount')))
       mounts = described_class.mountinstances
       expect(mounts.size).to eq(6)
       expect(mounts[0]).to eq({ :name => '/', :mounted => :yes })
@@ -127,8 +122,8 @@ FSTAB
     end
 
     it "should get name from mountoutput found on HP-UX" do
-      Facter.stubs(:value).with(:osfamily).returns 'HP-UX'
-      described_class.stubs(:mountcmd).returns(File.read(my_fixture('hpux.mount')))
+      allow(Facter).to receive(:value).with(:osfamily).and_return('HP-UX')
+      allow(described_class).to receive(:mountcmd).and_return(File.read(my_fixture('hpux.mount')))
       mounts = described_class.mountinstances
       expect(mounts.size).to eq(17)
       expect(mounts[0]).to eq({ :name => '/', :mounted => :yes })
@@ -151,8 +146,8 @@ FSTAB
     end
 
     it "should get name from mountoutput found on Darwin" do
-      Facter.stubs(:value).with(:osfamily).returns 'Darwin'
-      described_class.stubs(:mountcmd).returns(File.read(my_fixture('darwin.mount')))
+      allow(Facter).to receive(:value).with(:osfamily).and_return('Darwin')
+      allow(described_class).to receive(:mountcmd).and_return(File.read(my_fixture('darwin.mount')))
       mounts = described_class.mountinstances
       expect(mounts.size).to eq(6)
       expect(mounts[0]).to eq({ :name => '/', :mounted => :yes })
@@ -164,19 +159,20 @@ FSTAB
     end
 
     it "should get name from mountoutput found on Linux" do
-      Facter.stubs(:value).with(:osfamily).returns 'Gentoo'
-      described_class.stubs(:mountcmd).returns(File.read(my_fixture('linux.mount')))
+      allow(Facter).to receive(:value).with(:osfamily).and_return('Gentoo')
+      allow(described_class).to receive(:mountcmd).and_return(File.read(my_fixture('linux.mount')))
       mounts = described_class.mountinstances
       expect(mounts[0]).to eq({ :name => '/', :mounted => :yes })
       expect(mounts[1]).to eq({ :name => '/lib64/rc/init.d', :mounted => :yes })
       expect(mounts[2]).to eq({ :name => '/sys', :mounted => :yes })
       expect(mounts[3]).to eq({ :name => '/usr/portage', :mounted => :yes })
       expect(mounts[4]).to eq({ :name => '/ghost', :mounted => :yes })
+      expect(mounts[5]).to eq({ :name => '/run', :mounted => :yes})
     end
 
     it "should get name from mountoutput found on AIX" do
-      Facter.stubs(:value).with(:osfamily).returns 'AIX'
-      described_class.stubs(:mountcmd).returns(File.read(my_fixture('aix.mount')))
+      allow(Facter).to receive(:value).with(:osfamily).and_return('AIX')
+      allow(described_class).to receive(:mountcmd).and_return(File.read(my_fixture('aix.mount')))
       mounts = described_class.mountinstances
       expect(mounts[0]).to eq({ :name => '/', :mounted => :yes })
       expect(mounts[1]).to eq({ :name => '/usr', :mounted => :yes })
@@ -190,17 +186,16 @@ FSTAB
     end
 
     it "should raise an error if a line is not understandable" do
-      described_class.stubs(:mountcmd).returns("bazinga!")
+      allow(described_class).to receive(:mountcmd).and_return("bazinga!")
       expect { described_class.mountinstances }.to raise_error Puppet::Error, 'Could not understand line bazinga! from mount output'
     end
-
   end
 
   it "should support AIX's paragraph based /etc/filesystems" do
     pending "This test only works on AIX" unless Facter.value(:osfamily) == 'AIX'
-    Facter.stubs(:value).with(:osfamily).returns 'AIX'
-    described_class.stubs(:default_target).returns my_fixture('aix.filesystems')
-    described_class.stubs(:mountcmd).returns File.read(my_fixture('aix.mount'))
+    allow(Facter).to receive(:value).with(:osfamily).and_return('AIX')
+    allow(described_class).to receive(:default_target).and_return(my_fixture('aix.filesystems'))
+    allow(described_class).to receive(:mountcmd).and_return(File.read(my_fixture('aix.mount')))
     instances = described_class.instances
     expect(instances[0].name).to eq("/")
     expect(instances[0].device).to eq("/dev/hd4")
@@ -228,7 +223,7 @@ FSTAB
         # Stub the mount output to our fixture.
         begin
           mount = my_fixture(platform + '.mount')
-          described_class.stubs(:mountcmd).returns File.read(mount)
+          allow(described_class).to receive(:mountcmd).and_return(File.read(mount))
         rescue
           skip "is #{platform}.mount missing at this point?"
         end
@@ -236,7 +231,7 @@ FSTAB
         # Note: we have to stub default_target before creating resources
         # because it is used by Puppet::Type::Mount.new to populate the
         # :target property.
-        described_class.stubs(:default_target).returns fstab
+        allow(described_class).to receive(:default_target).and_return(fstab)
         @retrieve = described_class.instances.collect { |prov| {:name => prov.get(:name), :ensure => prov.get(:ensure)}}
       end
 
@@ -269,7 +264,7 @@ FSTAB
         # Stub the mount output to our fixture.
         begin
           mount = my_fixture(platform + '.mount')
-          described_class.stubs(:mountcmd).returns File.read(mount)
+          allow(described_class).to receive(:mountcmd).and_return(File.read(mount))
         rescue
           skip "is #{platform}.mount missing at this point?"
         end
@@ -277,16 +272,17 @@ FSTAB
         # Note: we have to stub default_target before creating resources
         # because it is used by Puppet::Type::Mount.new to populate the
         # :target property.
-        described_class.stubs(:default_target).returns fstab
+        allow(described_class).to receive(:default_target).and_return(fstab)
 
         @res_ghost = Puppet::Type::Mount.new(:name => '/ghost')    # in no fake fstab
         @res_mounted = Puppet::Type::Mount.new(:name => '/')       # in every fake fstab
         @res_unmounted = Puppet::Type::Mount.new(:name => '/boot') # in every fake fstab
         @res_absent = Puppet::Type::Mount.new(:name => '/absent')  # in no fake fstab
+        @res_trailing_slash = Puppet::Type::Mount.new(:name => '/run/') # in every fake fstab
 
         # Simulate transaction.rb:prefetch
         @resource_hash = {}
-        [@res_ghost, @res_mounted, @res_unmounted, @res_absent].each do |resource|
+        [@res_ghost, @res_mounted, @res_unmounted, @res_absent, @res_trailing_slash].each do |resource|
           @resource_hash[resource.name] = resource
         end
       end
@@ -306,6 +302,11 @@ FSTAB
           described_class.prefetch(@resource_hash)
           expect(@res_mounted.provider.get(:ensure)).to eq(:mounted)
         end
+
+        it 'strips trailing slashes from resource titles' do
+          described_class.prefetch(@resource_hash)
+          expect(@res_trailing_slash.provider.get(:ensure)).to eq(:mounted)
+        end
       end
 
       it "should set :ensure to :absent if not found in fstab and not mounted" do
