@@ -6,28 +6,25 @@ describe Puppet::Type.type(:package).provider(:openbsd) do
   let(:provider) { described_class.new(package) }
 
   def expect_read_from_pkgconf(lines)
-    pkgconf = stub(:readlines => lines)
-    Puppet::FileSystem.expects(:exist?).with('/etc/pkg.conf').returns(true)
-    File.expects(:open).with('/etc/pkg.conf', 'rb').returns(pkgconf)
+    pkgconf = double(:readlines => lines)
+    expect(Puppet::FileSystem).to receive(:exist?).with('/etc/pkg.conf').and_return(true)
+    expect(File).to receive(:open).with('/etc/pkg.conf', 'rb').and_return(pkgconf)
   end
 
   def expect_pkgadd_with_source(source)
-    provider.expects(:pkgadd).with do |fullname|
-      expect(ENV).not_to be_key('PKG_PATH')
-      expect(fullname).to eq([source])
+    expect(provider).to receive(:pkgadd).with([source]) do
+      expect(ENV).not_to have_key('PKG_PATH')
     end
   end
 
   def expect_pkgadd_with_env_and_name(source, &block)
-    expect(ENV).not_to be_key('PKG_PATH')
+    expect(ENV).not_to have_key('PKG_PATH')
 
-    provider.expects(:pkgadd).with do |fullname|
-      expect(ENV).to be_key('PKG_PATH')
+    expect(provider).to receive(:pkgadd).with([provider.resource[:name]]) do
+      expect(ENV).to have_key('PKG_PATH')
       expect(ENV['PKG_PATH']).to eq(source)
-
-      expect(fullname).to eq([provider.resource[:name]])
     end
-    provider.expects(:execpipe).with(['/bin/pkg_info', '-I', provider.resource[:name]]).yields('')
+    expect(provider).to receive(:execpipe).with(['/bin/pkg_info', '-I', provider.resource[:name]]).and_yield('')
 
     yield
 
@@ -46,25 +43,25 @@ describe Puppet::Type.type(:package).provider(:openbsd) do
   before :each do
     # Stub some provider methods to avoid needing the actual software
     # installed, so we can test on whatever platform we want.
-    described_class.stubs(:command).with(:pkginfo).returns('/bin/pkg_info')
-    described_class.stubs(:command).with(:pkgadd).returns('/bin/pkg_add')
-    described_class.stubs(:command).with(:pkgdelete).returns('/bin/pkg_delete')
+    allow(described_class).to receive(:command).with(:pkginfo).and_return('/bin/pkg_info')
+    allow(described_class).to receive(:command).with(:pkgadd).and_return('/bin/pkg_add')
+    allow(described_class).to receive(:command).with(:pkgdelete).and_return('/bin/pkg_delete')
   end
 
   context "#instances" do
     it "should return nil if execution failed" do
-      described_class.expects(:execpipe).raises(Puppet::ExecutionFailure, 'wawawa')
+      expect(described_class).to receive(:execpipe).and_raise(Puppet::ExecutionFailure, 'wawawa')
       expect(described_class.instances).to be_nil
     end
 
     it "should return the empty set if no packages are listed" do
-      described_class.expects(:execpipe).with(%w{/bin/pkg_info -a}).yields(StringIO.new(''))
+      expect(described_class).to receive(:execpipe).with(%w{/bin/pkg_info -a}).and_yield(StringIO.new(''))
       expect(described_class.instances).to be_empty
     end
 
     it "should return all packages when invoked" do
       fixture = File.read(my_fixture('pkginfo.list'))
-      described_class.expects(:execpipe).with(%w{/bin/pkg_info -a}).yields(fixture)
+      expect(described_class).to receive(:execpipe).with(%w{/bin/pkg_info -a}).and_yield(fixture)
       expect(described_class.instances.map(&:name).sort).to eq(
         %w{bash bzip2 expat gettext libiconv lzo openvpn python vim wget}.sort
       )
@@ -72,7 +69,7 @@ describe Puppet::Type.type(:package).provider(:openbsd) do
 
     it "should return all flavors if set" do
       fixture = File.read(my_fixture('pkginfo_flavors.list'))
-      described_class.expects(:execpipe).with(%w{/bin/pkg_info -a}).yields(fixture)
+      expect(described_class).to receive(:execpipe).with(%w{/bin/pkg_info -a}).and_yield(fixture)
       instances = described_class.instances.map {|p| {:name => p.get(:name),
         :ensure => p.get(:ensure), :flavor => p.get(:flavor)}}
       expect(instances.size).to eq(2)
@@ -83,7 +80,7 @@ describe Puppet::Type.type(:package).provider(:openbsd) do
 
   context "#install" do
     it "should fail if the resource doesn't have a source" do
-      Puppet::FileSystem.expects(:exist?).with('/etc/pkg.conf').returns(false)
+      expect(Puppet::FileSystem).to receive(:exist?).with('/etc/pkg.conf').and_return(false)
 
       expect {
         provider.install
@@ -91,8 +88,8 @@ describe Puppet::Type.type(:package).provider(:openbsd) do
     end
 
     it "should fail if /etc/pkg.conf exists, but is not readable" do
-      Puppet::FileSystem.expects(:exist?).with('/etc/pkg.conf').returns(true)
-      File.expects(:open).with('/etc/pkg.conf', 'rb').raises(Errno::EACCES)
+      expect(Puppet::FileSystem).to receive(:exist?).with('/etc/pkg.conf').and_return(true)
+      expect(File).to receive(:open).with('/etc/pkg.conf', 'rb').and_raise(Errno::EACCES)
 
       expect {
         provider.install
@@ -235,7 +232,7 @@ describe Puppet::Type.type(:package).provider(:openbsd) do
     it 'should use install_options as Array' do
       provider.resource[:source] = '/tma1/'
       provider.resource[:install_options] = ['-r', '-z']
-      provider.expects(:pkgadd).with(['-r', '-z', 'bash'])
+      expect(provider).to receive(:pkgadd).with(['-r', '-z', 'bash'])
       provider.install
     end
   end
@@ -244,31 +241,31 @@ describe Puppet::Type.type(:package).provider(:openbsd) do
     before do
       provider.resource[:source] = '/tmp/tcsh.tgz'
       provider.resource[:name] = 'tcsh'
-      provider.stubs(:pkginfo).with('tcsh')
+      allow(provider).to receive(:pkginfo).with('tcsh')
     end
 
     it "should return the ensure value if the package is already installed" do
-      provider.stubs(:properties).returns({:ensure => '4.2.45'})
-      provider.stubs(:pkginfo).with('-Q', 'tcsh')
+      allow(provider).to receive(:properties).and_return({:ensure => '4.2.45'})
+      allow(provider).to receive(:pkginfo).with('-Q', 'tcsh')
       expect(provider.latest).to eq('4.2.45')
     end
 
     it "should recognize a new version" do
       pkginfo_query = 'tcsh-6.18.01p1'
-      provider.stubs(:pkginfo).with('-Q', 'tcsh').returns(pkginfo_query)
+      allow(provider).to receive(:pkginfo).with('-Q', 'tcsh').and_return(pkginfo_query)
       expect(provider.latest).to eq('6.18.01p1')
     end
 
     it "should recognize a newer version" do
-      provider.stubs(:properties).returns({:ensure => '1.6.8'})
+      allow(provider).to receive(:properties).and_return({:ensure => '1.6.8'})
       pkginfo_query = 'tcsh-1.6.10'
-      provider.stubs(:pkginfo).with('-Q', 'tcsh').returns(pkginfo_query)
+      allow(provider).to receive(:pkginfo).with('-Q', 'tcsh').and_return(pkginfo_query)
       expect(provider.latest).to eq('1.6.10')
     end
 
     it "should recognize a package that is already the newest" do
       pkginfo_query = 'tcsh-6.18.01p0 (installed)'
-      provider.stubs(:pkginfo).with('-Q', 'tcsh').returns(pkginfo_query)
+      allow(provider).to receive(:pkginfo).with('-Q', 'tcsh').and_return(pkginfo_query)
       expect(provider.latest).to eq('6.18.01p0')
     end
   end
@@ -294,7 +291,7 @@ describe Puppet::Type.type(:package).provider(:openbsd) do
 
     it "should lookup the correct version" do
       output = 'bash-3.1.17         GNU Bourne Again Shell'
-      provider.expects(:execpipe).with(%w{/bin/pkg_info -I bash}).yields(output)
+      expect(provider).to receive(:execpipe).with(%w{/bin/pkg_info -I bash}).and_yield(output)
       expect(provider.get_full_name).to eq('bash-3.1.17')
     end
 
@@ -302,26 +299,26 @@ describe Puppet::Type.type(:package).provider(:openbsd) do
       provider.resource[:name] = 'fossil'
       provider.resource[:flavor] = 'static'
       output = 'fossil-1.29v0-static simple distributed software configuration management'
-      provider.expects(:execpipe).with(%w{/bin/pkg_info -I fossil}).yields(output)
+      expect(provider).to receive(:execpipe).with(%w{/bin/pkg_info -I fossil}).and_yield(output)
       expect(provider.get_full_name).to eq('fossil-1.29v0-static')
     end
   end
 
   context "#get_version" do
     it "should return nil if execution fails" do
-      provider.expects(:execpipe).raises(Puppet::ExecutionFailure, 'wawawa')
+      expect(provider).to receive(:execpipe).and_raise(Puppet::ExecutionFailure, 'wawawa')
       expect(provider.get_version).to be_nil
     end
 
     it "should return the package version if in the output" do
       output = 'bash-3.1.17         GNU Bourne Again Shell'
-      provider.expects(:execpipe).with(%w{/bin/pkg_info -I bash}).yields(output)
+      expect(provider).to receive(:execpipe).with(%w{/bin/pkg_info -I bash}).and_yield(output)
       expect(provider.get_version).to eq('3.1.17')
     end
 
     it "should return the empty string if the package is not present" do
       provider.resource[:name] = 'zsh'
-      provider.expects(:execpipe).with(%w{/bin/pkg_info -I zsh}).yields(StringIO.new(''))
+      expect(provider).to receive(:execpipe).with(%w{/bin/pkg_info -I zsh}).and_yield(StringIO.new(''))
       expect(provider.get_version).to eq('')
     end
   end
@@ -329,13 +326,13 @@ describe Puppet::Type.type(:package).provider(:openbsd) do
   context "#query" do
     it "should return the installed version if present" do
       fixture = File.read(my_fixture('pkginfo.detail'))
-      provider.expects(:pkginfo).with('bash').returns(fixture)
+      expect(provider).to receive(:pkginfo).with('bash').and_return(fixture)
       expect(provider.query).to eq({ :ensure => '3.1.17' })
     end
 
     it "should return nothing if not present" do
       provider.resource[:name] = 'zsh'
-      provider.expects(:pkginfo).with('zsh').returns('')
+      expect(provider).to receive(:pkginfo).with('zsh').and_return('')
       expect(provider.query).to be_nil
     end
   end
@@ -385,7 +382,7 @@ describe Puppet::Type.type(:package).provider(:openbsd) do
   context "#uninstall" do
     describe 'when uninstalling' do
       it 'should use erase to purge' do
-        provider.expects(:pkgdelete).with('-c', '-q', 'bash')
+        expect(provider).to receive(:pkgdelete).with('-c', '-q', 'bash')
         provider.purge
       end
     end
@@ -393,9 +390,26 @@ describe Puppet::Type.type(:package).provider(:openbsd) do
     describe 'with uninstall_options' do
       it 'should use uninstall_options as Array' do
         provider.resource[:uninstall_options] = ['-q', '-c']
-        provider.expects(:pkgdelete).with(['-q', '-c'], 'bash')
+        expect(provider).to receive(:pkgdelete).with(['-q', '-c'], 'bash')
         provider.uninstall
       end
     end
   end
+
+  context "#flavor" do
+    before do
+      provider.instance_variable_get('@property_hash')[:flavor] = 'no_x11-python'
+    end
+
+    it 'should return the existing flavor' do
+      expect(provider.flavor).to eq('no_x11-python')
+    end
+
+    it 'should remove and install the new flavor if different' do
+      provider.resource[:flavor] = 'no_x11-ruby'
+      expect(provider).to receive(:uninstall).ordered
+      expect(provider).to receive(:install).ordered
+      provider.flavor = provider.resource[:flavor]
+    end
+  end
 end
