@@ -13,16 +13,18 @@ describe Puppet::Type.type(:package).provider(:pkgin) do
   describe "#install" do
    describe "a package not installed" do
     before { resource[:ensure] = :absent }
+
     it "uses pkgin install to install" do
-      subject.expects(:pkgin).with("-y", :install, "vim").once()
+      expect(subject).to receive(:pkgin).with("-y", :install, "vim").once()
       subject.install
     end
    end
 
    describe "a package with a fixed version" do
     before { resource[:ensure] = '7.2.446' }
+
     it "uses pkgin install to install a fixed version" do
-      subject.expects(:pkgin).with("-y", :install, "vim-7.2.446").once()
+      expect(subject).to receive(:pkgin).with("-y", :install, "vim-7.2.446").once()
       subject.install
     end
    end
@@ -30,7 +32,7 @@ describe Puppet::Type.type(:package).provider(:pkgin) do
 
   describe "#uninstall" do
     it "uses pkgin remove to uninstall" do
-      subject.expects(:pkgin).with("-y", :remove, "vim").once()
+      expect(subject).to receive(:pkgin).with("-y", :remove, "vim").once()
       subject.uninstall
     end
   end
@@ -41,7 +43,7 @@ describe Puppet::Type.type(:package).provider(:pkgin) do
     end
 
     before do
-      described_class.stubs(:pkgin).with(:list).returns(pkgin_ls_output)
+      allow(described_class).to receive(:pkgin).with(:list).and_return(pkgin_ls_output)
     end
 
     it "returns an array of providers for each package" do
@@ -63,7 +65,7 @@ describe Puppet::Type.type(:package).provider(:pkgin) do
 
   describe "#latest" do
     before do
-      described_class.stubs(:pkgin).with(:search, "vim").returns(pkgin_search_output)
+      allow(described_class).to receive(:pkgin).with(:search, "vim").and_return(pkgin_search_output)
     end
 
     context "when the package is installed" do
@@ -72,7 +74,7 @@ describe Puppet::Type.type(:package).provider(:pkgin) do
       end
 
       it "returns installed version" do
-        subject.expects(:properties).returns( { :ensure => "7.2.446" } )
+        expect(subject).to receive(:properties).and_return({ :ensure => "7.2.446" })
         expect(subject.latest).to eq("7.2.446")
       end
     end
@@ -93,7 +95,7 @@ describe Puppet::Type.type(:package).provider(:pkgin) do
       end
 
       it "returns current version" do
-        subject.expects(:properties).returns( { :ensure => "7.2.446" } )
+        expect(subject).to receive(:properties).and_return({ :ensure => "7.2.446" })
         expect(subject.latest).to eq("7.2.446")
       end
     end
@@ -115,7 +117,7 @@ SEARCH
       end
 
       it "returns the newest available version" do
-        described_class.stubs(:pkgin).with(:search, "vim").returns(pkgin_search_output)
+        allow(described_class).to receive(:pkgin).with(:search, "vim").and_return(pkgin_search_output)
         expect(subject.latest).to eq("7.3")
       end
     end
