@@ -1,9 +1,6 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
-provider_class = Puppet::Type.type(:package).provider(:rpm)
-
-describe provider_class do
+describe Puppet::Type.type(:package).provider(:rpm) do
   let (:packages) do
     <<-RPM_OUTPUT
     'cracklib-dicts 0 2.8.9 3.3 x86_64
@@ -12,6 +9,8 @@ describe provider_class do
     myresource 0 1.2.3.4 5.el4 noarch
     mysummaryless 0 1.2.3.4 5.el4 noarch
     tomcat 1 1.2.3.4 5.el4 x86_64
+    kernel 1 1.2.3.4 5.el4 x86_64
+    kernel 1 1.2.3.6 5.el4 x86_64
     '
     RPM_OUTPUT
   end
@@ -26,7 +25,7 @@ describe provider_class do
   end
 
   let(:provider) do
-    provider = provider_class.new
+    provider = subject()
     provider.resource = resource
     provider
   end
@@ -38,15 +37,15 @@ describe provider_class do
   let(:rpm_version) { "RPM version 5.0.0\n" }
 
   before(:each) do
-    Puppet::Util.stubs(:which).with("rpm").returns("/bin/rpm")
-    provider_class.stubs(:which).with("rpm").returns("/bin/rpm")
-    provider_class.instance_variable_set("@current_version", nil)
-    Puppet::Type::Package::ProviderRpm.expects(:execute)
+    allow(Puppet::Util).to receive(:which).with("rpm").and_return("/bin/rpm")
+    allow(described_class).to receive(:which).with("rpm").and_return("/bin/rpm")
+    described_class.instance_variable_set("@current_version", nil)
+    expect(Puppet::Type::Package::ProviderRpm).to receive(:execute)
       .with(["/bin/rpm", "--version"])
-      .returns(rpm_version).at_most_once
-    Puppet::Util::Execution.expects(:execute)
+      .and_return(rpm_version).at_most(:once)
+    expect(Puppet::Util::Execution).to receive(:execute)
       .with(["/bin/rpm", "--version"], execute_options)
-      .returns(Puppet::Util::Execution::ProcessOutput.new(rpm_version, 0)).at_most_once
+      .and_return(Puppet::Util::Execution::ProcessOutput.new(rpm_version, 0)).at_most(:once)
   end
 
   describe 'provider features' do
@@ -59,34 +58,44 @@ describe provider_class do
   describe "self.instances" do
     describe "with a modern version of RPM" do
       it "includes all the modern flags" do
-        Puppet::Util::Execution.expects(:execpipe).with("/bin/rpm -qa --nosignature --nodigest --qf '#{nevra_format}'").yields(packages)
+        expect(Puppet::Util::Execution).to receive(:execpipe)
+          .with("/bin/rpm -qa --nosignature --nodigest --qf '#{nevra_format}' | sort")
+          .and_yield(packages)
 
-        provider_class.instances
+        described_class.instances
       end
     end
 
     describe "with a version of RPM < 4.1" do
       let(:rpm_version) { "RPM version 4.0.2\n" }
-      it "excludes the --nosignature flag" do
-        Puppet::Util::Execution.expects(:execpipe).with("/bin/rpm -qa  --nodigest --qf '#{nevra_format}'").yields(packages)
 
-        provider_class.instances
+      it "excludes the --nosignature flag" do
+        expect(Puppet::Util::Execution).to receive(:execpipe)
+          .with("/bin/rpm -qa  --nodigest --qf '#{nevra_format}' | sort")
+          .and_yield(packages)
+
+        described_class.instances
       end
     end
 
     describe "with a version of RPM < 4.0.2" do
       let(:rpm_version) { "RPM version 3.0.5\n" }
-      it "excludes the --nodigest flag" do
-        Puppet::Util::Execution.expects(:execpipe).with("/bin/rpm -qa   --qf '#{nevra_format}'").yields(packages)
 
-        provider_class.instances
+      it "excludes the --nodigest flag" do
+        expect(Puppet::Util::Execution).to receive(:execpipe)
+        .with("/bin/rpm -qa   --qf '#{nevra_format}' | sort")
+        .and_yield(packages)
+
+        described_class.instances
       end
     end
 
     it "returns an array of packages" do
-      Puppet::Util::Execution.expects(:execpipe).with("/bin/rpm -qa --nosignature --nodigest --qf '#{nevra_format}'").yields(packages)
+      expect(Puppet::Util::Execution).to receive(:execpipe)
+        .with("/bin/rpm -qa --nosignature --nodigest --qf '#{nevra_format}' | sort")
+        .and_yield(packages)
 
-      installed_packages = provider_class.instances
+      installed_packages = described_class.instances
 
       expect(installed_packages[0].properties).to eq(
         {
@@ -154,6 +163,17 @@ describe provider_class do
           :ensure      => "1:1.2.3.4-5.el4",
         }
       )
+      expect(installed_packages[6].properties).to eq(
+        {
+          :provider    => :rpm,
+          :name        => "kernel",
+          :epoch       => "1",
+          :version     => "1.2.3.4",
+          :release     => "5.el4",
+          :arch        => "x86_64",
+          :ensure      => "1:1.2.3.4-5.el4; 1:1.2.3.6-5.el4",
+        }
+      )
     end
   end
 
@@ -168,7 +188,8 @@ describe provider_class do
 
     describe "when not already installed" do
       it "only includes the '-i' flag" do
-        Puppet::Util::Execution.expects(:execute).with(["/bin/rpm", ["-i"], '/path/to/package'], execute_options)
+        expect(Puppet::Util::Execution).to receive(:execute)
+          .with(["/bin/rpm", ["-i"], '/path/to/package'], execute_options)
         provider.install
       end
     end
@@ -185,7 +206,8 @@ describe provider_class do
       end
 
       it "includes the options" do
-        Puppet::Util::Execution.expects(:execute).with(["/bin/rpm", ["-i", "-D", "--test=value", "-Q"], '/path/to/package'], execute_options)
+        expect(Puppet::Util::Execution).to receive(:execute)
+          .with(["/bin/rpm", ["-i", "-D", "--test=value", "-Q"], '/path/to/package'], execute_options)
         provider.install
       end
     end
@@ -198,7 +220,8 @@ describe provider_class do
       end
 
       it "includes the '-U --oldpackage' flags" do
-         Puppet::Util::Execution.expects(:execute).with(["/bin/rpm", ["-U", "--oldpackage"], '/path/to/package'], execute_options)
+         expect(Puppet::Util::Execution).to receive(:execute)
+           .with(["/bin/rpm", ["-U", "--oldpackage"], '/path/to/package'], execute_options)
          provider.install
       end
     end
@@ -206,16 +229,18 @@ describe provider_class do
 
   describe "#latest" do
     it "retrieves version string after querying rpm for version from source file" do
-      resource.expects(:[]).with(:source).returns('source-string')
-      Puppet::Util::Execution.expects(:execute)
-        .with(["/bin/rpm", "-q", "--qf", "'#{nevra_format}'", "-p", "source-string"])
-        .returns(Puppet::Util::Execution::ProcessOutput.new("myresource 0 1.2.3.4 5.el4 noarch\n", 0))
+      expect(resource).to receive(:[]).with(:source).and_return('source-string')
+      expect(Puppet::Util::Execution).to receive(:execute)
+        .with(["/bin/rpm", "-q", "--qf", "#{nevra_format}", "-p", "source-string"])
+        .and_return(Puppet::Util::Execution::ProcessOutput.new("myresource 0 1.2.3.4 5.el4 noarch\n", 0))
       expect(provider.latest).to eq("1.2.3.4-5.el4")
     end
 
     it "raises an error if the rpm command fails" do
-      resource.expects(:[]).with(:source).returns('source-string')
-      Puppet::Util::Execution.expects(:execute).with(["/bin/rpm", "-q", "--qf", "'#{nevra_format}'", "-p", "source-string"]).raises(Puppet::ExecutionFailure, 'rpm command failed')
+      expect(resource).to receive(:[]).with(:source).and_return('source-string')
+      expect(Puppet::Util::Execution).to receive(:execute)
+        .with(["/bin/rpm", "-q", "--qf", "#{nevra_format}", "-p", "source-string"])
+        .and_raise(Puppet::ExecutionFailure, 'rpm command failed')
 
       expect {
         provider.latest
@@ -226,52 +251,115 @@ describe provider_class do
   describe "#uninstall" do
     let(:resource) do
       Puppet::Type.type(:package).new(
-        :name     => 'myresource',
-        :ensure   => :installed
+        :name   => resource_name,
+        :ensure => :installed
       )
     end
 
-    describe "on a modern RPM" do
+    describe "on an ancient RPM" do
+      let(:rpm_version) { "RPM version 3.0.6\n" }
+
       before(:each) do
-        Puppet::Util::Execution.expects(:execute)
-          .with(["/bin/rpm", "-q", "myresource", '--nosignature', '--nodigest', "--qf", "'#{nevra_format}'"], execute_options)
-          .returns(Puppet::Util::Execution::ProcessOutput.new("myresource 0 1.2.3.4 5.el4 noarch\n", 0))
+        expect(Puppet::Util::Execution).to receive(:execute)
+          .with(["/bin/rpm", "-q", resource_name, '', '', '--qf', "#{nevra_format}"], execute_options)
+          .and_return(Puppet::Util::Execution::ProcessOutput.new("#{resource_name} 0 1.2.3.4 5.el4 noarch\n", 0))
       end
 
-      let(:rpm_version) { "RPM version 4.10.0\n" }
-
-      it "includes the architecture in the package name" do
-        Puppet::Util::Execution.expects(:execute)
-          .with(["/bin/rpm", ["-e"], 'myresource-1.2.3.4-5.el4.noarch'], execute_options)
-          .returns(Puppet::Util::Execution::ProcessOutput.new('', 0)).at_most_once
+      it "excludes the architecture from the package name" do
+        expect(Puppet::Util::Execution).to receive(:execute)
+          .with(["/bin/rpm", ["-e"], resource_name], execute_options)
+          .and_return(Puppet::Util::Execution::ProcessOutput.new('', 0)).at_most(:once)
         provider.uninstall
       end
     end
 
-    describe "on an ancient RPM" do
+    describe "on a modern RPM" do
+      let(:rpm_version) { "RPM version 4.10.0\n" }
+
+
       before(:each) do
-        Puppet::Util::Execution.expects(:execute)
-          .with(["/bin/rpm", "-q", "myresource", '', '', '--qf', "'#{nevra_format}'"], execute_options)
-          .returns(Puppet::Util::Execution::ProcessOutput.new("myresource 0 1.2.3.4 5.el4 noarch\n", 0))
+        expect(Puppet::Util::Execution).to receive(:execute)
+          .with(["/bin/rpm", "-q", resource_name, '--nosignature', '--nodigest', "--qf", "#{nevra_format}"], execute_options)
+          .and_return(Puppet::Util::Execution::ProcessOutput.new("#{resource_name} 0 1.2.3.4 5.el4 noarch\n", 0))
       end
 
-      let(:rpm_version) { "RPM version 3.0.6\n" }
-
       it "excludes the architecture from the package name" do
-        Puppet::Util::Execution.expects(:execute)
-          .with(["/bin/rpm", ["-e"], 'myresource-1.2.3.4-5.el4'], execute_options)
-          .returns(Puppet::Util::Execution::ProcessOutput.new('', 0)).at_most_once
+        expect(Puppet::Util::Execution).to receive(:execute)
+          .with(["/bin/rpm", ["-e"], resource_name], execute_options)
+          .and_return(Puppet::Util::Execution::ProcessOutput.new('', 0)).at_most(:once)
+        provider.uninstall
+      end
+    end
+
+    describe "on a modern RPM when architecture is specified" do
+      let(:rpm_version) { "RPM version 4.10.0\n" }
+
+      let(:resource) do
+        Puppet::Type.type(:package).new(
+          :name   => "#{resource_name}.noarch",
+          :ensure => :absent,
+        )
+      end
+
+      before(:each) do
+        expect(Puppet::Util::Execution).to receive(:execute)
+          .with(["/bin/rpm", "-q", "#{resource_name}.noarch", '--nosignature', '--nodigest', "--qf", "#{nevra_format}"], execute_options)
+          .and_return(Puppet::Util::Execution::ProcessOutput.new("#{resource_name} 0 1.2.3.4 5.el4 noarch\n", 0))
+      end
+
+      it "includes the architecture in the package name" do
+        expect(Puppet::Util::Execution).to receive(:execute)
+          .with(["/bin/rpm", ["-e"], "#{resource_name}.noarch"], execute_options)
+          .and_return(Puppet::Util::Execution::ProcessOutput.new('', 0)).at_most(:once)
+        provider.uninstall
+      end
+    end
+
+    describe "when version and release are specified" do
+      let(:resource) do
+        Puppet::Type.type(:package).new(
+          :name   => "#{resource_name}-1.2.3.4-5.el4",
+          :ensure => :absent,
+        )
+      end
+
+      before(:each) do
+        expect(Puppet::Util::Execution).to receive(:execute)
+          .with(["/bin/rpm", "-q", "#{resource_name}-1.2.3.4-5.el4", '--nosignature', '--nodigest', "--qf", "#{nevra_format}"], execute_options)
+          .and_return(Puppet::Util::Execution::ProcessOutput.new("#{resource_name} 0 1.2.3.4 5.el4 noarch\n", 0))
+      end
+
+      it "includes the version and release in the package name" do
+        expect(Puppet::Util::Execution).to receive(:execute)
+          .with(["/bin/rpm", ["-e"], "#{resource_name}-1.2.3.4-5.el4"], execute_options)
+          .and_return(Puppet::Util::Execution::ProcessOutput.new('', 0)).at_most(:once)
+        provider.uninstall
+      end
+    end
+
+    describe "when only version is specified" do
+      let(:resource) do
+        Puppet::Type.type(:package).new(
+          :name   => "#{resource_name}-1.2.3.4",
+          :ensure => :absent,
+        )
+      end
+
+      before(:each) do
+        expect(Puppet::Util::Execution).to receive(:execute)
+          .with(["/bin/rpm", "-q", "#{resource_name}-1.2.3.4", '--nosignature', '--nodigest', "--qf", "#{nevra_format}"], execute_options)
+          .and_return(Puppet::Util::Execution::ProcessOutput.new("#{resource_name} 0 1.2.3.4 5.el4 noarch\n", 0))
+      end
+
+      it "includes the version in the package name" do
+        expect(Puppet::Util::Execution).to receive(:execute)
+          .with(["/bin/rpm", ["-e"], "#{resource_name}-1.2.3.4"], execute_options)
+          .and_return(Puppet::Util::Execution::ProcessOutput.new('', 0)).at_most(:once)
         provider.uninstall
       end
     end
 
     describe "when uninstalled with options" do
-      before(:each) do
-        Puppet::Util::Execution.expects(:execute)
-          .with(["/bin/rpm", "-q", "myresource", '--nosignature', '--nodigest', "--qf", "'#{nevra_format}'"], execute_options)
-          .returns(Puppet::Util::Execution::ProcessOutput.new("myresource 0 1.2.3.4 5.el4 noarch\n", 0))
-      end
-
       let(:resource) do
         Puppet::Type.type(:package).new(
           :name              => resource_name,
@@ -281,8 +369,15 @@ describe provider_class do
         )
       end
 
+      before(:each) do
+        expect(Puppet::Util::Execution).to receive(:execute)
+          .with(["/bin/rpm", "-q", resource_name, '--nosignature', '--nodigest', "--qf", "#{nevra_format}"], execute_options)
+          .and_return(Puppet::Util::Execution::ProcessOutput.new("#{resource_name} 0 1.2.3.4 5.el4 noarch\n", 0))
+      end
+
       it "includes the options" do
-        Puppet::Util::Execution.expects(:execute).with(["/bin/rpm", ["-e", "--nodeps"], 'myresource-1.2.3.4-5.el4.noarch'], execute_options)
+        expect(Puppet::Util::Execution).to receive(:execute)
+          .with(["/bin/rpm", ["-e", "--nodeps"], resource_name], execute_options)
         provider.uninstall
       end
     end
@@ -290,10 +385,10 @@ describe provider_class do
 
   describe "parsing" do
     def parser_test(rpm_output_string, gold_hash, number_of_debug_logs = 0)
-      Puppet.expects(:debug).times(number_of_debug_logs)
-      Puppet::Util::Execution.expects(:execute)
-        .with(["/bin/rpm", "-q", resource_name, "--nosignature", "--nodigest", "--qf", "'#{nevra_format}'"], execute_options)
-        .returns(Puppet::Util::Execution::ProcessOutput.new(rpm_output_string, 0))
+      expect(Puppet).to receive(:debug).exactly(number_of_debug_logs).times()
+      expect(Puppet::Util::Execution).to receive(:execute)
+        .with(["/bin/rpm", "-q", resource_name, "--nosignature", "--nodigest", "--qf", "#{nevra_format}"], execute_options)
+        .and_return(Puppet::Util::Execution::ProcessOutput.new(rpm_output_string, 0))
       expect(provider.query).to eq(gold_hash)
     end
 
@@ -313,7 +408,6 @@ describe provider_class do
     let(:line) { 'name epoch version release arch' }
 
     ['name', 'epoch', 'version', 'release', 'arch'].each do |field|
-
       it "still parses if #{field} is replaced by delimiter" do
         parser_test(
           line.gsub(field, delimiter),
@@ -323,7 +417,6 @@ describe provider_class do
           )
         )
       end
-
     end
 
     it "does not fail if line is unparseable, but issues a debug log" do
@@ -332,9 +425,11 @@ describe provider_class do
 
     describe "when the package is not found" do
       before do
-        Puppet.expects(:debug).never
-        expected_args = ["/bin/rpm", "-q", resource_name, "--nosignature", "--nodigest", "--qf", "'#{nevra_format}'"]
-        Puppet::Util::Execution.expects(:execute).with(expected_args, execute_options).raises Puppet::ExecutionFailure.new("package #{resource_name} is not installed")
+        expect(Puppet).not_to receive(:debug)
+        expected_args = ["/bin/rpm", "-q", resource_name, "--nosignature", "--nodigest", "--qf", "#{nevra_format}"]
+        expect(Puppet::Util::Execution).to receive(:execute)
+          .with(expected_args, execute_options)
+          .and_raise(Puppet::ExecutionFailure.new("package #{resource_name} is not installed"))
       end
 
       it "does not log or fail if allow_virtual is false" do
@@ -344,19 +439,23 @@ describe provider_class do
 
       it "does not log or fail if allow_virtual is true" do
         resource[:allow_virtual] = true
-        expected_args = ['/bin/rpm', '-q', resource_name, '--nosignature', '--nodigest', '--qf', "'#{nevra_format}'", '--whatprovides']
-        Puppet::Util::Execution.expects(:execute).with(expected_args, execute_options).raises Puppet::ExecutionFailure.new("package #{resource_name} is not provided")
+        expected_args = ['/bin/rpm', '-q', resource_name, '--nosignature', '--nodigest', '--qf', "#{nevra_format}", '--whatprovides']
+        expect(Puppet::Util::Execution).to receive(:execute)
+          .with(expected_args, execute_options)
+          .and_raise(Puppet::ExecutionFailure.new("package #{resource_name} is not provided"))
         expect(provider.query).to be_nil
       end
     end
 
     it "parses virtual package" do
       provider.resource[:allow_virtual] = true
-      expected_args = ["/bin/rpm", "-q", resource_name, "--nosignature", "--nodigest", "--qf", "'#{nevra_format}'"]
-      Puppet::Util::Execution.expects(:execute).with(expected_args, execute_options).raises Puppet::ExecutionFailure.new("package #{resource_name} is not installed")
-      Puppet::Util::Execution.expects(:execute)
+      expected_args = ["/bin/rpm", "-q", resource_name, "--nosignature", "--nodigest", "--qf", "#{nevra_format}"]
+      expect(Puppet::Util::Execution).to receive(:execute)
+        .with(expected_args, execute_options)
+        .and_raise(Puppet::ExecutionFailure.new("package #{resource_name} is not installed"))
+      expect(Puppet::Util::Execution).to receive(:execute)
         .with(expected_args + ["--whatprovides"], execute_options)
-        .returns(Puppet::Util::Execution::ProcessOutput.new("myresource 0 1.2.3.4 5.el4 noarch\n", 0))
+        .and_return(Puppet::Util::Execution::ProcessOutput.new("myresource 0 1.2.3.4 5.el4 noarch\n", 0))
       expect(provider.query).to eq({
         :name     => "myresource",
         :epoch    => "0",
@@ -430,8 +529,8 @@ describe provider_class do
     }.each do |version, expected|
       describe "when current version is #{version}" do
         it "returns #{expected.inspect}" do
-          provider_class.stubs(:current_version).returns(version)
-          expect(provider_class.nodigest).to eq(expected)
+          allow(described_class).to receive(:current_version).and_return(version)
+          expect(described_class.nodigest).to eq(expected)
         end
       end
     end
@@ -446,15 +545,14 @@ describe provider_class do
     }.each do |version, expected|
       describe "when current version is #{version}" do
         it "returns #{expected.inspect}" do
-          provider_class.stubs(:current_version).returns(version)
-          expect(provider_class.nosignature).to eq(expected)
+          allow(described_class).to receive(:current_version).and_return(version)
+          expect(described_class.nosignature).to eq(expected)
         end
       end
     end
   end
 
   describe 'version comparison' do
-
     # test cases munged directly from rpm's own
     # tests/rpmvercmp.at
     it { expect(provider.rpmvercmp("1.0", "1.0")).to eq(0) }
@@ -538,7 +636,6 @@ describe provider_class do
   end
 
   describe 'package evr parsing' do
-
     it 'should parse full simple evr' do
       v = provider.rpm_parse_evr('0:1.2.3-4.el5')
       expect(v[:epoch]).to eq('0')
@@ -595,11 +692,9 @@ describe provider_class do
       expect(v[:version]).to eq('2.2')
       expect(v[:release]).to eq('SNAPSHOT20121119105647')
     end
-
   end
 
   describe 'rpm evr comparison' do
-
     # currently passing tests
     it 'should evaluate identical version-release as equal' do
       v = provider.rpm_compareEVR({:epoch => '0', :version => '1.2.3', :release => '1.el5'},
@@ -643,11 +738,9 @@ describe provider_class do
       expect(provider.rpm_compareEVR({:epoch => '0', :version => '2.2', :release => '405'},
                                {:epoch => '0', :version => '2.2', :release => '406'})).to eq(-1)
     end
-
   end
 
   describe 'version segment comparison' do
-
     it 'should treat two nil values as equal' do
       v = provider.compare_values(nil, nil)
       expect(v).to eq(0)
@@ -664,11 +757,130 @@ describe provider_class do
     end
 
     it 'should pass two non-nil values on to rpmvercmp' do
-      provider.stubs(:rpmvercmp) { 0 }
-      provider.expects(:rpmvercmp).with('s1', 's2')
+      allow(provider).to receive(:rpmvercmp).and_return(0)
+      expect(provider).to receive(:rpmvercmp).with('s1', 's2')
       provider.compare_values('s1', 's2')
     end
-
   end
 
+
+  describe 'insync?' do
+    context 'for multiple versions' do
+      let(:is) { '1:1.2.3.4-5.el4; 1:5.6.7.8-5.el4' }
+      it 'returns true if there is match and feature is enabled' do
+        resource[:install_only] = true
+        resource[:ensure] = '1:1.2.3.4-5.el4'
+        expect(provider).to be_insync(is)
+      end
+      it 'returns false if there is match and feature is not enabled' do
+        resource[:ensure] = '1:1.2.3.4-5.el4'
+        expect(provider).to_not be_insync(is)
+      end
+      it 'returns false if no match and feature is enabled' do
+        resource[:install_only] = true
+        resource[:ensure] = '1:1.2.3.6-5.el4'
+        expect(provider).to_not be_insync(is)
+      end
+      it 'returns false if no match and feature is not enabled' do
+        resource[:ensure] = '1:1.2.3.6-5.el4'
+        expect(provider).to_not be_insync(is)
+      end
+    end
+    context 'for simple versions' do
+      let(:is) { '1:1.2.3.4-5.el4' }
+      it 'returns true if there is match and feature is enabled' do
+        resource[:install_only] = true
+        resource[:ensure] = '1:1.2.3.4-5.el4'
+        expect(provider).to be_insync(is)
+      end
+      it 'returns true if there is match and feature is not enabled' do
+        resource[:ensure] = '1:1.2.3.4-5.el4'
+        expect(provider).to be_insync(is)
+      end
+      it 'returns false if no match and feature is enabled' do
+        resource[:install_only] = true
+        resource[:ensure] = '1:1.2.3.6-5.el4'
+        expect(provider).to_not be_insync(is)
+      end
+      it 'returns false if no match and feature is not enabled' do
+        resource[:ensure] = '1:1.2.3.6-5.el4'
+        expect(provider).to_not be_insync(is)
+      end
+    end
+  end
+
+  describe 'rpm multiversion to hash' do
+    it 'should return empty hash for empty imput' do
+      package_hash = described_class.nevra_to_multiversion_hash('')
+      expect(package_hash).to eq({})
+    end
+
+    it 'should return package hash for one package input' do
+      package_list = <<-RPM_OUTPUT
+kernel-devel 1 1.2.3.4 5.el4 x86_64
+RPM_OUTPUT
+      package_hash = described_class.nevra_to_multiversion_hash(package_list)
+      expect(package_hash).to eq(
+        {
+          :arch => "x86_64",
+          :ensure => "1:1.2.3.4-5.el4",
+          :epoch => "1",
+          :name => "kernel-devel",
+          :provider => :rpm,
+          :release => "5.el4",
+          :version => "1.2.3.4",
+        }
+      )
+    end
+
+    it 'should return package hash with versions concatenated in ensure for two package input' do
+      package_list = <<-RPM_OUTPUT
+kernel-devel 1 1.2.3.4 5.el4 x86_64
+kernel-devel 1 5.6.7.8 5.el4 x86_64
+RPM_OUTPUT
+      package_hash = described_class.nevra_to_multiversion_hash(package_list)
+      expect(package_hash).to eq(
+        {
+          :arch => "x86_64",
+          :ensure => "1:1.2.3.4-5.el4; 1:5.6.7.8-5.el4",
+          :epoch => "1",
+          :name => "kernel-devel",
+          :provider => :rpm,
+          :release => "5.el4",
+          :version => "1.2.3.4",
+        }
+      )
+    end
+
+    it 'should return list of packages for one multiversion and one package input' do
+      package_list = <<-RPM_OUTPUT
+kernel-devel 1 1.2.3.4 5.el4 x86_64
+kernel-devel 1 5.6.7.8 5.el4 x86_64
+basesystem 0 8.0 5.1.1.el5.centos noarch
+RPM_OUTPUT
+      package_hash = described_class.nevra_to_multiversion_hash(package_list)
+      expect(package_hash).to eq(
+        [
+          {
+            :arch => "x86_64",
+            :ensure => "1:1.2.3.4-5.el4; 1:5.6.7.8-5.el4",
+            :epoch => "1",
+            :name => "kernel-devel",
+            :provider => :rpm,
+            :release => "5.el4",
+            :version => "1.2.3.4",
+          },
+          {
+            :provider => :rpm,
+            :name => "basesystem",
+            :epoch => "0",
+            :version => "8.0",
+            :release => "5.1.1.el5.centos",
+            :arch => "noarch",
+            :ensure => "8.0-5.1.1.el5.centos",
+          }
+        ]
+      )
+    end
+  end
 end
