@@ -55,7 +55,7 @@ describe Puppet::Type.type(:package).provider(:yum) do
       end
     end
 
-    describe 'with install_options' do 
+    describe 'with install_options' do
       it 'can parse disable-repo with array of strings' do
           resource[:install_options] = ['--disable-repo=dev*', '--disable-repo=prod*']
           expect(provider).to receive(:execute) do | arr|
@@ -106,6 +106,37 @@ describe Puppet::Type.type(:package).provider(:yum) do
     end
   end
 
+  context "latest" do
+    let(:name) { 'baz' }
+
+    let(:resource) do
+      Puppet::Type.type(:package).new(
+        :name => name,
+        :provider => 'yum',
+      )
+    end
+
+    let(:provider) do
+      provider = described_class.new
+      provider.resource = resource
+      provider
+    end
+
+    before {
+      allow(described_class).to receive(:command).with(:cmd).and_return("/usr/bin/yum")
+      Puppet[:log_level] = 'debug'
+    }
+
+    it "should print a debug message with the current version if newer package is not available" do
+      expect(provider).to receive(:query).and_return({:ensure => "1.2.3"})
+      expect(described_class).to receive(:latest_package_version).and_return(nil)
+      resource[:ensure] = :present
+
+      provider.latest
+      expect(@logs).to include(an_object_having_attributes(level: :debug, message: "Yum didn't find updates, current version (1.2.3) is the latest"))
+    end
+  end
+
   context "parsing the output of check-update" do
     context "with no multiline entries" do
       let(:check_update) { File.read(my_fixture("yum-check-update-simple.txt")) }
@@ -194,5 +225,14 @@ describe Puppet::Type.type(:package).provider(:yum) do
         expect(output).not_to include("Random plugin")
       end
     end
+
+    context "with subscription manager enabled " do
+      let(:check_update) { File.read(my_fixture("yum-check-update-subscription-manager.txt")) }
+      let(:output) { described_class.parse_updates(check_update) }
+
+      it "parses correctly formatted entries" do
+        expect(output['curl.x86_64']).to eq([{:name => 'curl', :epoch => '0', :version => '7.32.0', :release => '10.fc20', :arch => 'x86_64'}])
+      end
+    end
   end
 end
