@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 require 'puppet_spec/files'
 
@@ -31,60 +30,60 @@ describe Puppet::Provider::ParsedFile do
 
   describe "when generating a list of instances" do
     it "should return an instance for each record parsed from all of the registered targets" do
-      provider.expects(:targets).returns %w{/one /two}
-      provider.stubs(:skip_record?).returns false
+      expect(provider).to receive(:targets).and_return(%w{/one /two})
+      allow(provider).to receive(:skip_record?).and_return(false)
       one = [:uno1, :uno2]
       two = [:dos1, :dos2]
-      provider.expects(:prefetch_target).with("/one").returns one
-      provider.expects(:prefetch_target).with("/two").returns two
+      expect(provider).to receive(:prefetch_target).with("/one").and_return(one)
+      expect(provider).to receive(:prefetch_target).with("/two").and_return(two)
 
       results = []
       (one + two).each do |inst|
         results << inst.to_s + "_instance"
-        provider.expects(:new).with(inst).returns(results[-1])
+        expect(provider).to receive(:new).with(inst).and_return(results[-1])
       end
 
       expect(provider.instances).to eq(results)
     end
 
     it "should ignore target when retrieve fails" do
-      provider.expects(:targets).returns %w{/one /two /three}
-      provider.stubs(:skip_record?).returns false
-      provider.expects(:retrieve).with("/one").returns [
+      expect(provider).to receive(:targets).and_return(%w{/one /two /three})
+      allow(provider).to receive(:skip_record?).and_return(false)
+      expect(provider).to receive(:retrieve).with("/one").and_return([
         {:name => 'target1_record1'},
         {:name => 'target1_record2'}
-      ]
-      provider.expects(:retrieve).with("/two").raises Puppet::Util::FileType::FileReadError, "some error"
-      provider.expects(:retrieve).with("/three").returns [
+      ])
+      expect(provider).to receive(:retrieve).with("/two").and_raise(Puppet::Util::FileType::FileReadError, "some error")
+      expect(provider).to receive(:retrieve).with("/three").and_return([
         {:name => 'target3_record1'},
         {:name => 'target3_record2'}
-      ]
-      Puppet.expects(:err).with('Could not prefetch parsedfile_type provider \'parsedfile_provider\' target \'/two\': some error. Treating as empty')
-      provider.expects(:new).with(:name => 'target1_record1', :on_disk => true, :target => '/one', :ensure => :present).returns 'r1'
-      provider.expects(:new).with(:name => 'target1_record2', :on_disk => true, :target => '/one', :ensure => :present).returns 'r2'
-      provider.expects(:new).with(:name => 'target3_record1', :on_disk => true, :target => '/three', :ensure => :present).returns 'r3'
-      provider.expects(:new).with(:name => 'target3_record2', :on_disk => true, :target => '/three', :ensure => :present).returns 'r4'
+      ])
+      expect(Puppet).to receive(:err).with('Could not prefetch parsedfile_type provider \'parsedfile_provider\' target \'/two\': some error. Treating as empty')
+      expect(provider).to receive(:new).with(:name => 'target1_record1', :on_disk => true, :target => '/one', :ensure => :present).and_return('r1')
+      expect(provider).to receive(:new).with(:name => 'target1_record2', :on_disk => true, :target => '/one', :ensure => :present).and_return('r2')
+      expect(provider).to receive(:new).with(:name => 'target3_record1', :on_disk => true, :target => '/three', :ensure => :present).and_return('r3')
+      expect(provider).to receive(:new).with(:name => 'target3_record2', :on_disk => true, :target => '/three', :ensure => :present).and_return('r4')
 
       expect(provider.instances).to eq(%w{r1 r2 r3 r4})
     end
 
     it "should skip specified records" do
-      provider.expects(:targets).returns %w{/one}
-      provider.expects(:skip_record?).with(:uno).returns false
-      provider.expects(:skip_record?).with(:dos).returns true
+      expect(provider).to receive(:targets).and_return(%w{/one})
+      expect(provider).to receive(:skip_record?).with(:uno).and_return(false)
+      expect(provider).to receive(:skip_record?).with(:dos).and_return(true)
       one = [:uno, :dos]
-      provider.expects(:prefetch_target).returns one
+      expect(provider).to receive(:prefetch_target).and_return(one)
 
-      provider.expects(:new).with(:uno).returns "eh"
-      provider.expects(:new).with(:dos).never
+      expect(provider).to receive(:new).with(:uno).and_return("eh")
+      expect(provider).not_to receive(:new).with(:dos)
 
       provider.instances
     end
   end
 
   describe "when matching resources to existing records" do
-    let(:first_resource) { stub(:one, :name => :one) }
-    let(:second_resource) { stub(:two, :name => :two) }
+    let(:first_resource) { double(:one, :name => :one) }
+    let(:second_resource) { double(:two, :name => :two) }
 
     let(:resources) {{:one => first_resource, :two => second_resource}}
 
@@ -102,41 +101,41 @@ describe Puppet::Provider::ParsedFile do
   describe "when flushing a file's records to disk" do
     before do
       # This way we start with some @records, like we would in real life.
-      provider.stubs(:retrieve).returns []
+      allow(provider).to receive(:retrieve).and_return([])
       provider.default_target = "/foo/bar"
       provider.initvars
       provider.prefetch
 
       @filetype = Puppet::Util::FileType.filetype(:flat).new("/my/file")
-      Puppet::Util::FileType.filetype(:flat).stubs(:new).with("/my/file",nil).returns @filetype
+      allow(Puppet::Util::FileType.filetype(:flat)).to receive(:new).with("/my/file").and_return(@filetype)
 
-      @filetype.stubs(:write)
+      allow(@filetype).to receive(:write)
     end
 
     it "should back up the file being written if the filetype can be backed up" do
-      @filetype.expects(:backup)
+      expect(@filetype).to receive(:backup)
 
       provider.flush_target("/my/file")
     end
 
     it "should not try to back up the file if the filetype cannot be backed up" do
       @filetype = Puppet::Util::FileType.filetype(:ram).new("/my/file")
-      Puppet::Util::FileType.filetype(:flat).expects(:new).returns @filetype
+      expect(Puppet::Util::FileType.filetype(:flat)).to receive(:new).and_return(@filetype)
 
-      @filetype.stubs(:write)
+      allow(@filetype).to receive(:write)
 
       provider.flush_target("/my/file")
     end
 
     it "should not back up the file more than once between calls to 'prefetch'" do
-      @filetype.expects(:backup).once
+      expect(@filetype).to receive(:backup).once
 
       provider.flush_target("/my/file")
       provider.flush_target("/my/file")
     end
 
     it "should back the file up again once the file has been reread" do
-      @filetype.expects(:backup).times(2)
+      expect(@filetype).to receive(:backup).twice
 
       provider.flush_target("/my/file")
       provider.prefetch
@@ -147,19 +146,19 @@ describe Puppet::Provider::ParsedFile do
   describe "when flushing multiple files" do
     describe "and an error is encountered" do
       it "the other file does not fail" do
-        provider.stubs(:backup_target)
+        allow(provider).to receive(:backup_target)
 
         bad_file = 'broken'
         good_file = 'writable'
 
-        bad_writer = mock 'bad'
-        bad_writer.expects(:write).raises(Exception, "Failed to write to bad file")
+        bad_writer = double('bad')
+        expect(bad_writer).to receive(:write).and_raise(Exception, "Failed to write to bad file")
 
-        good_writer = mock 'good'
-        good_writer.expects(:write).returns(nil)
+        good_writer = double('good')
+        expect(good_writer).to receive(:write).and_return(nil)
 
-        provider.stubs(:target_object).with(bad_file).returns(bad_writer)
-        provider.stubs(:target_object).with(good_file).returns(good_writer)
+        allow(provider).to receive(:target_object).with(bad_file).and_return(bad_writer)
+        allow(provider).to receive(:target_object).with(good_file).and_return(good_writer)
 
         bad_resource = parsed_type.new(:name => 'one', :target => bad_file)
         good_resource = parsed_type.new(:name => 'two', :target => good_file)
@@ -190,8 +189,8 @@ describe "A very basic provider based on ParsedFile" do
     example_provider_class.initvars
     example_provider_class.prefetch
     # evade a race between multiple invocations of the header method
-    example_provider_class.stubs(:header).
-      returns("# HEADER As added by puppet.\n")
+    allow(example_provider_class).to receive(:header).
+      and_return("# HEADER As added by puppet.\n")
     example_provider_class
   end
 
@@ -208,7 +207,7 @@ describe "A very basic provider based on ParsedFile" do
     let(:input_records) { provider.parse(input_text) }
 
     before :each do
-      provider.stubs(:native_header_regex).returns(regex)
+      allow(provider).to receive(:native_header_regex).and_return(regex)
     end
 
     it "should move the native header to the top" do
@@ -217,7 +216,7 @@ describe "A very basic provider based on ParsedFile" do
 
     context "and dropping native headers found in input" do
       before :each do
-        provider.stubs(:drop_native_header).returns(true)
+        allow(provider).to receive(:drop_native_header).and_return(true)
       end
 
       it "should not include the native header in the output" do
