@@ -8,30 +8,30 @@ describe Puppet::Type.type(:service).provider(:src) do
   end
 
   before :each do
-    @resource = stub 'resource'
-    @resource.stubs(:[]).returns(nil)
-    @resource.stubs(:[]).with(:name).returns "myservice"
+    @resource = double('resource')
+    allow(@resource).to receive(:[]).and_return(nil)
+    allow(@resource).to receive(:[]).with(:name).and_return("myservice")
 
     @provider = subject()
     @provider.resource = @resource
 
-    @provider.stubs(:command).with(:stopsrc).returns "/usr/bin/stopsrc"
-    @provider.stubs(:command).with(:startsrc).returns "/usr/bin/startsrc"
-    @provider.stubs(:command).with(:lssrc).returns "/usr/bin/lssrc"
-    @provider.stubs(:command).with(:refresh).returns "/usr/bin/refresh"
-    @provider.stubs(:command).with(:lsitab).returns "/usr/sbin/lsitab"
-    @provider.stubs(:command).with(:mkitab).returns "/usr/sbin/mkitab"
-    @provider.stubs(:command).with(:rmitab).returns "/usr/sbin/rmitab"
-    @provider.stubs(:command).with(:chitab).returns "/usr/sbin/chitab"
+    allow(@provider).to receive(:command).with(:stopsrc).and_return("/usr/bin/stopsrc")
+    allow(@provider).to receive(:command).with(:startsrc).and_return("/usr/bin/startsrc")
+    allow(@provider).to receive(:command).with(:lssrc).and_return("/usr/bin/lssrc")
+    allow(@provider).to receive(:command).with(:refresh).and_return("/usr/bin/refresh")
+    allow(@provider).to receive(:command).with(:lsitab).and_return("/usr/sbin/lsitab")
+    allow(@provider).to receive(:command).with(:mkitab).and_return("/usr/sbin/mkitab")
+    allow(@provider).to receive(:command).with(:rmitab).and_return("/usr/sbin/rmitab")
+    allow(@provider).to receive(:command).with(:chitab).and_return("/usr/sbin/chitab")
 
-    @provider.stubs(:stopsrc)
-    @provider.stubs(:startsrc)
-    @provider.stubs(:lssrc)
-    @provider.stubs(:refresh)
-    @provider.stubs(:lsitab)
-    @provider.stubs(:mkitab)
-    @provider.stubs(:rmitab)
-    @provider.stubs(:chitab)
+    allow(@provider).to receive(:stopsrc)
+    allow(@provider).to receive(:startsrc)
+    allow(@provider).to receive(:lssrc)
+    allow(@provider).to receive(:refresh)
+    allow(@provider).to receive(:lsitab)
+    allow(@provider).to receive(:mkitab)
+    allow(@provider).to receive(:rmitab)
+    allow(@provider).to receive(:chitab)
   end
 
   context ".instances" do
@@ -47,7 +47,7 @@ myservice.2:::/usr/sbin/inetd:0:0:/dev/console:/dev/console:/dev/console:-O:-Q:-
 myservice.3:::/usr/sbin/inetd:0:0:/dev/console:/dev/console:/dev/console:-O:-Q:-K:0:0:20:0:0:-d:20:tcpip:
 myservice.4:::/usr/sbin/inetd:0:0:/dev/console:/dev/console:/dev/console:-O:-Q:-K:0:0:20:0:0:-d:20:tcpip:
 _EOF_
-      described_class.stubs(:lssrc).returns sample_output
+      allow(described_class).to receive(:lssrc).and_return(sample_output)
       expect(described_class.instances.map(&:name)).to eq([
         'myservice.1',
         'myservice.2',
@@ -55,33 +55,32 @@ _EOF_
         'myservice.4'
       ])
     end
-
   end
 
   context "when starting a service" do
     it "should execute the startsrc command" do
-      @provider.expects(:execute).with(['/usr/bin/startsrc', '-s', "myservice"], {:override_locale => false, :squelch => false, :combine => true, :failonfail => true})
-      @provider.expects(:status).returns :running
+      expect(@provider).to receive(:execute).with(['/usr/bin/startsrc', '-s', "myservice"], {:override_locale => false, :squelch => false, :combine => true, :failonfail => true})
+      expect(@provider).to receive(:status).and_return(:running)
       @provider.start
     end
 
     it "should error if timeout occurs while stopping the service" do
-      @provider.expects(:execute).with(['/usr/bin/startsrc', '-s', "myservice"], {:override_locale => false, :squelch => false, :combine => true, :failonfail => true})
-      Timeout.expects(:timeout).with(60).raises(Timeout::Error)
+      expect(@provider).to receive(:execute).with(['/usr/bin/startsrc', '-s', "myservice"], {:override_locale => false, :squelch => false, :combine => true, :failonfail => true})
+      expect(Timeout).to receive(:timeout).with(60).and_raise(Timeout::Error)
       expect { @provider.start }.to raise_error Puppet::Error, ('Timed out waiting for myservice to transition states')
     end
   end
 
   context "when stopping a service" do
     it "should execute the stopsrc command" do
-      @provider.expects(:execute).with(['/usr/bin/stopsrc', '-s', "myservice"], {:override_locale => false, :squelch => false, :combine => true, :failonfail => true})
-      @provider.expects(:status).returns :stopped
+      expect(@provider).to receive(:execute).with(['/usr/bin/stopsrc', '-s', "myservice"], {:override_locale => false, :squelch => false, :combine => true, :failonfail => true})
+      expect(@provider).to receive(:status).and_return(:stopped)
       @provider.stop
     end
 
     it "should error if timeout occurs while stopping the service" do
-      @provider.expects(:execute).with(['/usr/bin/stopsrc', '-s', "myservice"], {:override_locale => false, :squelch => false, :combine => true, :failonfail => true})
-      Timeout.expects(:timeout).with(60).raises(Timeout::Error)
+      expect(@provider).to receive(:execute).with(['/usr/bin/stopsrc', '-s', "myservice"], {:override_locale => false, :squelch => false, :combine => true, :failonfail => true})
+      expect(Timeout).to receive(:timeout).with(60).and_raise(Timeout::Error)
       expect { @provider.stop }.to raise_error Puppet::Error, ('Timed out waiting for myservice to transition states')
     end
   end
@@ -96,34 +95,34 @@ _EOF_
 
   context "when enabling" do
     it "should execute the mkitab command" do
-      @provider.expects(:mkitab).with("myservice:2:once:/usr/bin/startsrc -s myservice").once
+      expect(@provider).to receive(:mkitab).with("myservice:2:once:/usr/bin/startsrc -s myservice").once
       @provider.enable
     end
   end
 
   context "when disabling" do
     it "should execute the rmitab command" do
-      @provider.expects(:rmitab).with("myservice")
+      expect(@provider).to receive(:rmitab).with("myservice")
       @provider.disable
     end
   end
 
   context "when checking if it is enabled" do
     it "should execute the lsitab command" do
-      @provider.expects(:execute).with(['/usr/sbin/lsitab', 'myservice'], {:combine => true, :failonfail => false})
-      $CHILD_STATUS.stubs(:exitstatus).returns(0)
+      expect(@provider).to receive(:execute).with(['/usr/sbin/lsitab', 'myservice'], {:combine => true, :failonfail => false})
+      allow($CHILD_STATUS).to receive(:exitstatus).and_return(0)
       @provider.enabled?
     end
 
     it "should return false when lsitab returns non-zero" do
-      @provider.stubs(:execute)
-      $CHILD_STATUS.stubs(:exitstatus).returns(1)
+      allow(@provider).to receive(:execute)
+      allow($CHILD_STATUS).to receive(:exitstatus).and_return(1)
       expect(@provider.enabled?).to eq(:false)
     end
 
     it "should return true when lsitab returns zero" do
-      @provider.stubs(:execute)
-      $CHILD_STATUS.stubs(:exitstatus).returns(0)
+      allow(@provider).to receive(:execute)
+      allow($CHILD_STATUS).to receive(:exitstatus).and_return(0)
       expect(@provider.enabled?).to eq(:true)
     end
   end
@@ -135,7 +134,7 @@ _EOF_
   myservice         tcpip            1234         active
 _EOF_
 
-      @provider.expects(:execute).with(['/usr/bin/lssrc', '-s', "myservice"]).returns sample_output
+      expect(@provider).to receive(:execute).with(['/usr/bin/lssrc', '-s', "myservice"]).and_return(sample_output)
       expect(@provider.status).to eq(:running)
     end
 
@@ -145,7 +144,7 @@ _EOF_
   myservice         tcpip                         inoperative
 _EOF_
 
-      @provider.expects(:execute).with(['/usr/bin/lssrc', '-s', "myservice"]).returns sample_output
+      expect(@provider).to receive(:execute).with(['/usr/bin/lssrc', '-s', "myservice"]).and_return(sample_output)
       expect(@provider.status).to eq(:stopped)
     end
 
@@ -155,12 +154,12 @@ _EOF_
   myservice         tcpip                         randomdata
 _EOF_
 
-      @provider.expects(:execute).with(['/usr/bin/lssrc', '-s', "myservice"]).returns sample_output
+      expect(@provider).to receive(:execute).with(['/usr/bin/lssrc', '-s', "myservice"]).and_return(sample_output)
       expect(@provider.status).to eq(nil)
     end
 
     it "should consider a non-existing service to be have a status of :stopped" do
-      @provider.expects(:execute).with(['/usr/bin/lssrc', '-s', 'myservice']).raises(Puppet::ExecutionFailure, "fail")
+      expect(@provider).to receive(:execute).with(['/usr/bin/lssrc', '-s', 'myservice']).and_raise(Puppet::ExecutionFailure, "fail")
       expect(@provider.status).to eq(:stopped)
     end
   end
@@ -171,8 +170,8 @@ _EOF_
 #subsysname:synonym:cmdargs:path:uid:auditid:standin:standout:standerr:action:multi:contact:svrkey:svrmtype:priority:signorm:sigforce:display:waittime:grpname:
 myservice:::/usr/sbin/inetd:0:0:/dev/console:/dev/console:/dev/console:-O:-Q:-K:0:0:20:0:0:-d:20:tcpip:
 _EOF_
-      @provider.expects(:execute).with(['/usr/bin/lssrc', '-Ss', "myservice"]).returns sample_output
-      @provider.expects(:execute).with(['/usr/bin/refresh', '-s', "myservice"])
+      expect(@provider).to receive(:execute).with(['/usr/bin/lssrc', '-Ss', "myservice"]).and_return(sample_output)
+      expect(@provider).to receive(:execute).with(['/usr/bin/refresh', '-s', "myservice"])
       @provider.restart
     end
 
@@ -182,9 +181,9 @@ _EOF_
 myservice::--no-daemonize:/usr/sbin/puppetd:0:0:/dev/null:/var/log/puppet.log:/var/log/puppet.log:-O:-Q:-S:0:0:20:15:9:-d:20::"
 _EOF_
 
-      @provider.expects(:execute).with(['/usr/bin/lssrc', '-Ss', "myservice"]).returns sample_output
-      @provider.expects(:stop)
-      @provider.expects(:start)
+      expect(@provider).to receive(:execute).with(['/usr/bin/lssrc', '-Ss', "myservice"]).and_return(sample_output)
+      expect(@provider).to receive(:stop)
+      expect(@provider).to receive(:start)
       @provider.restart
     end
   end
