@@ -1,10 +1,4 @@
-#! /usr/bin/env ruby
-#
-# Unit testing for the Windows service Provider
-#
-
 require 'spec_helper'
-
 require 'win32/service' if Puppet.features.microsoft_windows?
 
 describe Puppet::Type.type(:service).provider(:windows), :if => Puppet.features.microsoft_windows? do
@@ -14,20 +8,20 @@ describe Puppet::Type.type(:service).provider(:windows), :if => Puppet.features.
   let(:config)   { Struct::ServiceConfigInfo.new }
   let(:status)   { Struct::ServiceStatus.new }
   let(:service_util) { Puppet::Util::Windows::Service }
-  let(:service_handle) { mock() }
+  let(:service_handle) { double() }
 
   before :each do
     # make sure we never actually execute anything (there are two execute methods)
-    provider.class.expects(:execute).never
-    provider.expects(:execute).never
+    allow(provider.class).to receive(:execute)
+    allow(provider).to receive(:execute)
 
-    service_util.stubs(:exists?).with(resource[:name]).returns(true)
+    allow(service_util).to receive(:exists?).with(resource[:name]).and_return(true)
   end
 
   describe ".instances" do
     it "should enumerate all services" do
       list_of_services = {'snmptrap' => {}, 'svchost' => {}, 'sshd' => {}}
-      service_util.expects(:services).returns(list_of_services)
+      expect(service_util).to receive(:services).and_return(list_of_services)
 
       expect(described_class.instances.map(&:name)).to match_array(['snmptrap', 'svchost', 'sshd'])
     end
@@ -35,24 +29,24 @@ describe Puppet::Type.type(:service).provider(:windows), :if => Puppet.features.
 
   describe "#start" do
     before(:each) do
-      provider.stubs(:status).returns(:stopped)
+      allow(provider).to receive(:status).and_return(:stopped)
     end
 
     it "should resume a paused service" do
-      provider.stubs(:status).returns(:paused)
-      service_util.expects(:resume).with(name)
+      allow(provider).to receive(:status).and_return(:paused)
+      expect(service_util).to receive(:resume).with(name)
       provider.start
     end
 
     it "should start the service" do
-      service_util.expects(:service_start_type).with(name).returns(:SERVICE_AUTO_START)
-      service_util.expects(:start).with(name)
+      expect(service_util).to receive(:service_start_type).with(name).and_return(:SERVICE_AUTO_START)
+      expect(service_util).to receive(:start).with(name)
       provider.start
     end
 
     context "when the service is disabled" do
       before :each do
-        service_util.expects(:service_start_type).with(name).returns(:SERVICE_DISABLED)
+        expect(service_util).to receive(:service_start_type).with(name).and_return(:SERVICE_DISABLED)
       end
 
       it "should refuse to start if not managing enable" do
@@ -61,16 +55,16 @@ describe Puppet::Type.type(:service).provider(:windows), :if => Puppet.features.
 
       it "should enable if managing enable and enable is true" do
         resource[:enable] = :true
-        service_util.expects(:start).with(name)
-        service_util.expects(:set_startup_mode).with(name, :SERVICE_AUTO_START)
+        expect(service_util).to receive(:start).with(name)
+        expect(service_util).to receive(:set_startup_mode).with(name, :SERVICE_AUTO_START)
 
         provider.start
       end
 
       it "should manual start if managing enable and enable is false" do
         resource[:enable] = :false
-        service_util.expects(:start).with(name)
-        service_util.expects(:set_startup_mode).with(name, :SERVICE_DEMAND_START)
+        expect(service_util).to receive(:start).with(name)
+        expect(service_util).to receive(:set_startup_mode).with(name, :SERVICE_DEMAND_START)
 
         provider.start
       end
@@ -79,7 +73,7 @@ describe Puppet::Type.type(:service).provider(:windows), :if => Puppet.features.
 
   describe "#stop" do
     it "should stop a running service" do
-      service_util.expects(:stop).with(name)
+      expect(service_util).to receive(:stop).with(name)
 
       provider.stop
     end
@@ -87,7 +81,7 @@ describe Puppet::Type.type(:service).provider(:windows), :if => Puppet.features.
 
   describe "#status" do
     it "should report a nonexistent service as stopped" do
-      service_util.stubs(:exists?).with(resource[:name]).returns(false)
+      allow(service_util).to receive(:exists?).with(resource[:name]).and_return(false)
 
       expect(provider.status).to eql(:stopped)
     end
@@ -97,7 +91,7 @@ describe Puppet::Type.type(:service).provider(:windows), :if => Puppet.features.
       :SERVICE_PAUSE_PENDING
     ].each do |state|
       it "should report a #{state} service as paused" do
-        service_util.expects(:service_state).with(name).returns(state)
+        expect(service_util).to receive(:service_state).with(name).and_return(state)
         expect(provider.status).to eq(:paused)
       end
     end
@@ -107,7 +101,7 @@ describe Puppet::Type.type(:service).provider(:windows), :if => Puppet.features.
       :SERVICE_STOP_PENDING
     ].each do |state|
       it "should report a #{state} service as stopped" do
-        service_util.expects(:service_state).with(name).returns(state)
+        expect(service_util).to receive(:service_state).with(name).and_return(state)
         expect(provider.status).to eq(:stopped)
       end
     end
@@ -118,7 +112,7 @@ describe Puppet::Type.type(:service).provider(:windows), :if => Puppet.features.
       :SERVICE_START_PENDING,
     ].each do |state|
       it "should report a #{state} service as running" do
-        service_util.expects(:service_state).with(name).returns(state)
+        expect(service_util).to receive(:service_state).with(name).and_return(state)
 
         expect(provider.status).to eq(:running)
       end
@@ -129,16 +123,14 @@ describe Puppet::Type.type(:service).provider(:windows), :if => Puppet.features.
     it "should use the supplied restart command if specified" do
       resource[:restart] = 'c:/bin/foo'
 
-      provider.expects(:execute).never
-      provider.expects(:execute).with(['c:/bin/foo'], :failonfail => true, :override_locale => false, :squelch => false, :combine => true)
+      expect(provider).to receive(:execute).with(['c:/bin/foo'], :failonfail => true, :override_locale => false, :squelch => false, :combine => true)
 
       provider.restart
     end
 
     it "should restart the service" do
-      seq = sequence("restarting")
-      provider.expects(:stop).in_sequence(seq)
-      provider.expects(:start).in_sequence(seq)
+      expect(provider).to receive(:stop).ordered
+      expect(provider).to receive(:start).ordered
 
       provider.restart
     end
@@ -146,18 +138,23 @@ describe Puppet::Type.type(:service).provider(:windows), :if => Puppet.features.
 
   describe "#enabled?" do
     it "should report a nonexistent service as false" do
-      service_util.stubs(:exists?).with(resource[:name]).returns(false)
+      allow(service_util).to receive(:exists?).with(resource[:name]).and_return(false)
 
       expect(provider.enabled?).to eql(:false)
     end
 
     it "should report a service with a startup type of manual as manual" do
-      service_util.expects(:service_start_type).with(name).returns(:SERVICE_DEMAND_START)
+      expect(service_util).to receive(:service_start_type).with(name).and_return(:SERVICE_DEMAND_START)
       expect(provider.enabled?).to eq(:manual)
     end
 
+    it "should report a service with a startup type of delayed as delayed" do
+      expect(service_util).to receive(:service_start_type).with(name).and_return(:SERVICE_DELAYED_AUTO_START)
+      expect(provider.enabled?).to eq(:delayed)
+    end
+
     it "should report a service with a startup type of disabled as false" do
-      service_util.expects(:service_start_type).with(name).returns(:SERVICE_DISABLED)
+      expect(service_util).to receive(:service_start_type).with(name).and_return(:SERVICE_DISABLED)
       expect(provider.enabled?).to eq(:false)
     end
 
@@ -170,7 +167,7 @@ describe Puppet::Type.type(:service).provider(:windows), :if => Puppet.features.
         :SERVICE_SYSTEM_START
       ].each do |start_type|
         it "should report a service with a startup type of '#{start_type}' as true" do
-          service_util.expects(:service_start_type).with(name).returns(start_type)
+          expect(service_util).to receive(:service_start_type).with(name).and_return(start_type)
           expect(provider.enabled?).to eq(:true)
         end
       end
@@ -179,12 +176,12 @@ describe Puppet::Type.type(:service).provider(:windows), :if => Puppet.features.
 
   describe "#enable" do
     it "should set service start type to Service_Auto_Start when enabled" do
-      service_util.expects(:set_startup_mode).with(name, :SERVICE_AUTO_START)
+      expect(service_util).to receive(:set_startup_mode).with(name, :SERVICE_AUTO_START)
       provider.enable
     end
 
     it "raises an error if set_startup_mode fails" do
-      service_util.expects(:set_startup_mode).with(name, :SERVICE_AUTO_START).raises(Puppet::Error.new('foobar'))
+      expect(service_util).to receive(:set_startup_mode).with(name, :SERVICE_AUTO_START).and_raise(Puppet::Error.new('foobar'))
 
       expect {
         provider.enable
@@ -194,12 +191,12 @@ describe Puppet::Type.type(:service).provider(:windows), :if => Puppet.features.
 
   describe "#disable" do
     it "should set service start type to Service_Disabled when disabled" do
-      service_util.expects(:set_startup_mode).with(name, :SERVICE_DISABLED)
+      expect(service_util).to receive(:set_startup_mode).with(name, :SERVICE_DISABLED)
       provider.disable
     end
 
     it "raises an error if set_startup_mode fails" do
-      service_util.expects(:set_startup_mode).with(name, :SERVICE_DISABLED).raises(Puppet::Error.new('foobar'))
+      expect(service_util).to receive(:set_startup_mode).with(name, :SERVICE_DISABLED).and_raise(Puppet::Error.new('foobar'))
 
       expect {
         provider.disable
@@ -209,16 +206,31 @@ describe Puppet::Type.type(:service).provider(:windows), :if => Puppet.features.
 
   describe "#manual_start" do
     it "should set service start type to Service_Demand_Start (manual) when manual" do
-      service_util.expects(:set_startup_mode).with(name, :SERVICE_DEMAND_START)
+      expect(service_util).to receive(:set_startup_mode).with(name, :SERVICE_DEMAND_START)
       provider.manual_start
     end
 
     it "raises an error if set_startup_mode fails" do
-      service_util.expects(:set_startup_mode).with(name, :SERVICE_DEMAND_START).raises(Puppet::Error.new('foobar'))
+      expect(service_util).to receive(:set_startup_mode).with(name, :SERVICE_DEMAND_START).and_raise(Puppet::Error.new('foobar'))
 
       expect {
         provider.manual_start
       }.to raise_error(Puppet::Error, /Cannot enable #{name}/)
     end
   end
+
+  describe "#delayed_start" do
+    it "should set service start type to Service_Config_Delayed_Auto_Start (delayed) when delayed" do
+      expect(service_util).to receive(:set_startup_mode).with(name, :SERVICE_AUTO_START, true)
+      provider.delayed_start
+    end
+
+    it "raises an error if set_startup_mode fails" do
+      expect(service_util).to receive(:set_startup_mode).with(name, :SERVICE_AUTO_START, true).and_raise(Puppet::Error.new('foobar'))
+
+      expect {
+        provider.delayed_start
+      }.to raise_error(Puppet::Error, /Cannot enable #{name}/)
+    end
+  end
 end
