@@ -1,4 +1,7 @@
 require 'spec_helper'
+require 'open3'
+
+RSpec::Matchers.define_negated_matcher :excluding, :include
 
 describe Puppet::Type.type(:user).provider(:pw) do
   let :resource do
@@ -8,86 +11,103 @@ describe Puppet::Type.type(:user).provider(:pw) do
   context "when creating users" do
     let :provider do
       prov = resource.provider
-      prov.expects(:exists?).returns nil
+      expect(prov).to receive(:exists?).and_return(nil)
       prov
     end
 
     it "should run pw with no additional flags when no properties are given" do
       expect(provider.addcmd).to eq([described_class.command(:pw), "useradd", "testuser"])
-      provider.expects(:execute).with([described_class.command(:pw), "useradd", "testuser"], kind_of(Hash))
+      expect(provider).to receive(:execute).with([described_class.command(:pw), "useradd", "testuser"], kind_of(Hash))
       provider.create
     end
 
     it "should use -o when allowdupe is enabled" do
       resource[:allowdupe] = true
-      provider.expects(:execute).with(includes("-o"), kind_of(Hash))
+      expect(provider).to receive(:execute).with(include("-o"), kind_of(Hash))
       provider.create
     end
 
     it "should use -c with the correct argument when the comment property is set" do
       resource[:comment] = "Testuser Name"
-      provider.expects(:execute).with(all_of(includes("-c"), includes("Testuser Name")), kind_of(Hash))
+      expect(provider).to receive(:execute).with(include("-c").and(include("Testuser Name")), kind_of(Hash))
       provider.create
     end
 
     it "should use -e with the correct argument when the expiry property is set" do
       resource[:expiry] = "2010-02-19"
-      provider.expects(:execute).with(all_of(includes("-e"), includes("19-02-2010")), kind_of(Hash))
+      expect(provider).to receive(:execute).with(include("-e").and(include("19-02-2010")), kind_of(Hash))
       provider.create
     end
 
     it "should use -e 00-00-0000 if the expiry property has to be removed" do
       resource[:expiry] = :absent
-      provider.expects(:execute).with(all_of(includes("-e"), includes("00-00-0000")), kind_of(Hash))
+      expect(provider).to receive(:execute).with(include("-e").and(include("00-00-0000")), kind_of(Hash))
       provider.create
     end
 
     it "should use -g with the correct argument when the gid property is set" do
       resource[:gid] = 12345
-      provider.expects(:execute).with(all_of(includes("-g"), includes(12345)), kind_of(Hash))
+      expect(provider).to receive(:execute).with(include("-g").and(include(12345)), kind_of(Hash))
       provider.create
     end
 
     it "should use -G with the correct argument when the groups property is set" do
       resource[:groups] = "group1"
-      provider.expects(:execute).with(all_of(includes("-G"), includes("group1")), kind_of(Hash))
+      expect(provider).to receive(:execute).with(include("-G").and(include("group1")), kind_of(Hash))
       provider.create
     end
 
     it "should use -G with all the given groups when the groups property is set to an array" do
       resource[:groups] = ["group1", "group2"]
-      provider.expects(:execute).with(all_of(includes("-G"), includes("group1,group2")), kind_of(Hash))
+      expect(provider).to receive(:execute).with(include("-G").and(include("group1,group2")), kind_of(Hash))
       provider.create
     end
 
     it "should use -d with the correct argument when the home property is set" do
       resource[:home] = "/home/testuser"
-      provider.expects(:execute).with(all_of(includes("-d"), includes("/home/testuser")), kind_of(Hash))
+      expect(provider).to receive(:execute).with(include("-d").and(include("/home/testuser")), kind_of(Hash))
       provider.create
     end
 
     it "should use -m when the managehome property is enabled" do
       resource[:managehome] = true
-      provider.expects(:execute).with(includes("-m"), kind_of(Hash))
+      expect(provider).to receive(:execute).with(include("-m"), kind_of(Hash))
       provider.create
     end
 
     it "should call the password set function with the correct argument when the password property is set" do
       resource[:password] = "*"
-      provider.expects(:execute)
-      provider.expects(:password=).with("*")
+      expect(provider).to receive(:execute)
+      expect(provider).to receive(:password=).with("*")
+      provider.create
+    end
+
+    it "should call execute with sensitive true when the password property is set" do
+      Puppet::Util::Log.level = :debug
+      resource[:password] = "abc123"
+      expect(provider).to receive(:execute).with(kind_of(Array), hash_including(sensitive: true))
+      popen = double("popen", :puts => nil, :close => nil)
+      expect(Open3).to receive(:popen3).and_return(popen)
+      expect(popen).to receive(:puts).with("abc123")
+      provider.create
+      expect(@logs).not_to be_any {|log| log.level == :debug and log.message =~ /abc123/}
+    end
+
+    it "should call execute with sensitive false when a non-sensitive property is set" do
+      resource[:managehome] = true
+      expect(provider).to receive(:execute).with(kind_of(Array), hash_including(sensitive: false))
       provider.create
     end
 
     it "should use -s with the correct argument when the shell property is set" do
       resource[:shell] = "/bin/sh"
-      provider.expects(:execute).with(all_of(includes("-s"), includes("/bin/sh")), kind_of(Hash))
+      expect(provider).to receive(:execute).with(include("-s").and(include("/bin/sh")), kind_of(Hash))
       provider.create
     end
 
     it "should use -u with the correct argument when the uid property is set" do
       resource[:uid] = 12345
-      provider.expects(:execute).with(all_of(includes("-u"), includes(12345)), kind_of(Hash))
+      expect(provider).to receive(:execute).with(include("-u").and(include(12345)), kind_of(Hash))
       provider.create
     end
 
@@ -95,8 +115,8 @@ describe Puppet::Type.type(:user).provider(:pw) do
     it "should not use -p when a password is given" do
       resource[:password] = "*"
       expect(provider.addcmd).not_to include("-p")
-      provider.expects(:password=)
-      provider.expects(:execute).with(Not(includes("-p")), kind_of(Hash))
+      expect(provider).to receive(:password=)
+      expect(provider).to receive(:execute).with(excluding("-p"), kind_of(Hash))
       provider.create
     end
   end
@@ -104,9 +124,9 @@ describe Puppet::Type.type(:user).provider(:pw) do
   context "when deleting users" do
     it "should run pw with no additional flags" do
       provider = resource.provider
-      provider.expects(:exists?).returns true
+      expect(provider).to receive(:exists?).and_return(true)
       expect(provider.deletecmd).to eq([described_class.command(:pw), "userdel", "testuser"])
-      provider.expects(:execute).with([described_class.command(:pw), "userdel", "testuser"], has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with([described_class.command(:pw), "userdel", "testuser"], hash_including(custom_environment: {}))
       provider.delete
     end
 
@@ -115,17 +135,17 @@ describe Puppet::Type.type(:user).provider(:pw) do
     # have an explicit test.
     it "should not use -r when managehome is not set" do
       provider = resource.provider
-      provider.expects(:exists?).returns true
+      expect(provider).to receive(:exists?).and_return(true)
       resource[:managehome] = false
-      provider.expects(:execute).with(Not(includes("-r")), has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(excluding("-r"), hash_including(custom_environment: {}))
       provider.delete
     end
 
     it "should use -r when managehome is set" do
       provider = resource.provider
-      provider.expects(:exists?).returns true
+      expect(provider).to receive(:exists?).and_return(true)
       resource[:managehome] = true
-      provider.expects(:execute).with(includes("-r"), has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(include("-r"), hash_including(custom_environment: {}))
       provider.delete
     end
   end
@@ -137,75 +157,94 @@ describe Puppet::Type.type(:user).provider(:pw) do
 
     it "should run pw with the correct arguments" do
       expect(provider.modifycmd("uid", 12345)).to eq([described_class.command(:pw), "usermod", "testuser", "-u", 12345])
-      provider.expects(:execute).with([described_class.command(:pw), "usermod", "testuser", "-u", 12345], has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with([described_class.command(:pw), "usermod", "testuser", "-u", 12345], hash_including(custom_environment: {}))
       provider.uid = 12345
     end
 
     it "should use -c with the correct argument when the comment property is changed" do
       resource[:comment] = "Testuser Name"
-      provider.expects(:execute).with(all_of(includes("-c"), includes("Testuser New Name")), has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(include("-c").and(include("Testuser New Name")), hash_including(custom_environment: {}))
       provider.comment = "Testuser New Name"
     end
 
     it "should use -e with the correct argument when the expiry property is changed" do
       resource[:expiry] = "2010-02-19"
-      provider.expects(:execute).with(all_of(includes("-e"), includes("19-02-2011")), has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(include("-e").and(include("19-02-2011")), hash_including(custom_environment: {}))
       provider.expiry = "2011-02-19"
     end
 
     it "should use -e with the correct argument when the expiry property is removed" do
       resource[:expiry] = :absent
-      provider.expects(:execute).with(all_of(includes("-e"), includes("00-00-0000")), has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(include("-e").and(include("00-00-0000")), hash_including(custom_environment: {}))
       provider.expiry = :absent
     end
 
     it "should use -g with the correct argument when the gid property is changed" do
       resource[:gid] = 12345
-      provider.expects(:execute).with(all_of(includes("-g"), includes(54321)), has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(include("-g").and(include(54321)), hash_including(custom_environment: {}))
       provider.gid = 54321
     end
 
     it "should use -G with the correct argument when the groups property is changed" do
       resource[:groups] = "group1"
-      provider.expects(:execute).with(all_of(includes("-G"), includes("group2")), has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(include("-G").and(include("group2")), hash_including(custom_environment: {}))
       provider.groups = "group2"
     end
 
     it "should use -G with all the given groups when the groups property is changed with an array" do
       resource[:groups] = ["group1", "group2"]
-      provider.expects(:execute).with(all_of(includes("-G"), includes("group3,group4")), has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(include("-G").and(include("group3,group4")), hash_including(custom_environment: {}))
       provider.groups = "group3,group4"
     end
 
     it "should use -d with the correct argument when the home property is changed" do
       resource[:home] = "/home/testuser"
-      provider.expects(:execute).with(all_of(includes("-d"), includes("/newhome/testuser")), has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(include("-d").and(include("/newhome/testuser")), hash_including(custom_environment: {}))
       provider.home = "/newhome/testuser"
     end
 
     it "should use -m and -d with the correct argument when the home property is changed and managehome is enabled" do
       resource[:home] = "/home/testuser"
       resource[:managehome] = true
-      provider.expects(:execute).with(all_of(includes("-d"), includes("/newhome/testuser"), includes("-m")), has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(include("-d").and(include("/newhome/testuser")).and(include("-m")), hash_including(custom_environment: {}))
       provider.home = "/newhome/testuser"
     end
 
     it "should call the password set function with the correct argument when the password property is changed" do
       resource[:password] = "*"
-      provider.expects(:password=).with("!")
+      expect(provider).to receive(:password=).with("!")
       provider.password = "!"
     end
 
     it "should use -s with the correct argument when the shell property is changed" do
       resource[:shell] = "/bin/sh"
-      provider.expects(:execute).with(all_of(includes("-s"), includes("/bin/tcsh")), has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(include("-s").and(include("/bin/tcsh")), hash_including(custom_environment: {}))
       provider.shell = "/bin/tcsh"
     end
 
     it "should use -u with the correct argument when the uid property is changed" do
       resource[:uid] = 12345
-      provider.expects(:execute).with(all_of(includes("-u"), includes(54321)), has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(include("-u").and(include(54321)), hash_including(custom_environment: {}))
       provider.uid = 54321
     end
+
+    it "should print a debug message with sensitive data redacted when the password property is set" do
+      Puppet::Util::Log.level = :debug
+      resource[:password] = "*"
+      popen = double("popen", :puts => nil, :close => nil)
+      expect(Open3).to receive(:popen3).and_return(popen)
+      expect(popen).to receive(:puts).with("abc123")
+      provider.password = "abc123"
+
+      expect(@logs).not_to be_any {|log| log.level == :debug and log.message =~ /abc123/}
+     end
+
+    it "should call execute with sensitive false when a non-sensitive property is set" do
+      Puppet::Util::Log.level = :debug
+      resource[:home] = "/home/testuser"
+      resource[:managehome] = true
+      expect(provider).to receive(:execute).with(kind_of(Array), hash_including(sensitive: false))
+      provider.home = "/newhome/testuser"
+    end
   end
 end
