@@ -8,123 +8,123 @@ describe Puppet::Type.type(:user).provider(:user_role_add), :unless => Puppet.fe
   let(:provider) { described_class.new(resource) }
 
   before do
-    resource.stubs(:should).returns "fakeval"
-    resource.stubs(:should).with(:keys).returns Hash.new
-    resource.stubs(:[]).returns "fakeval"
+    allow(resource).to receive(:should).and_return("fakeval")
+    allow(resource).to receive(:should).with(:keys).and_return(Hash.new)
+    allow(resource).to receive(:[]).and_return("fakeval")
   end
 
-
   describe "#command" do
     before do
-      klass = stub("provider")
-      klass.stubs(:command).with(:foo).returns("userfoo")
-      klass.stubs(:command).with(:role_foo).returns("rolefoo")
-      provider.stubs(:class).returns(klass)
+      klass = double("provider")
+      allow(klass).to receive(:superclass)
+      allow(klass).to receive(:command).with(:foo).and_return("userfoo")
+      allow(klass).to receive(:command).with(:role_foo).and_return("rolefoo")
+      allow(provider).to receive(:class).and_return(klass)
     end
 
     it "should use the command if not a role and ensure!=role" do
-      provider.stubs(:is_role?).returns(false)
-      provider.stubs(:exists?).returns(false)
-      resource.stubs(:[]).with(:ensure).returns(:present)
-      provider.class.stubs(:foo)
+      allow(provider).to receive(:is_role?).and_return(false)
+      allow(provider).to receive(:exists?).and_return(false)
+      allow(resource).to receive(:[]).with(:ensure).and_return(:present)
+      allow(provider.class).to receive(:foo)
       expect(provider.command(:foo)).to eq("userfoo")
     end
 
     it "should use the role command when a role" do
-      provider.stubs(:is_role?).returns(true)
+      allow(provider).to receive(:is_role?).and_return(true)
       expect(provider.command(:foo)).to eq("rolefoo")
     end
 
     it "should use the role command when !exists and ensure=role" do
-      provider.stubs(:is_role?).returns(false)
-      provider.stubs(:exists?).returns(false)
-      resource.stubs(:[]).with(:ensure).returns(:role)
+      allow(provider).to receive(:is_role?).and_return(false)
+      allow(provider).to receive(:exists?).and_return(false)
+      allow(resource).to receive(:[]).with(:ensure).and_return(:role)
       expect(provider.command(:foo)).to eq("rolefoo")
     end
   end
 
   describe "#transition" do
     it "should return the type set to whatever is passed in" do
-      provider.expects(:command).with(:modify).returns("foomod")
+      expect(provider).to receive(:command).with(:modify).and_return("foomod")
       provider.transition("bar").include?("type=bar")
     end
   end
 
   describe "#create" do
     before do
-      provider.stubs(:password=)
+      allow(provider).to receive(:password=)
     end
 
     it "should use the add command when the user is not a role" do
-      provider.stubs(:is_role?).returns(false)
-      provider.expects(:addcmd).returns("useradd")
-      provider.expects(:run).at_least_once
+      allow(provider).to receive(:is_role?).and_return(false)
+      expect(provider).to receive(:addcmd).and_return("useradd")
+      expect(provider).to receive(:run).at_least(:once)
       provider.create
     end
 
     it "should use transition(normal) when the user is a role" do
-      provider.stubs(:is_role?).returns(true)
-      provider.expects(:transition).with("normal")
-      provider.expects(:run)
+      allow(provider).to receive(:is_role?).and_return(true)
+      expect(provider).to receive(:transition).with("normal")
+      expect(provider).to receive(:run)
       provider.create
     end
 
     it "should set password age rules" do
       resource = Puppet::Type.type(:user).new :name => "myuser", :password_min_age => 5, :password_max_age => 10, :password_warn_days => 15, :provider => :user_role_add
       provider = described_class.new(resource)
-      provider.stubs(:user_attributes)
-      provider.stubs(:execute)
-      provider.expects(:execute).with { |cmd, *args| args == ["-n", 5, "-x", 10, '-w', 15, "myuser"] }
+      allow(provider).to receive(:user_attributes)
+      allow(provider).to receive(:execute)
+      expect(provider).to receive(:execute).with([anything, "-n", 5, "-x", 10, '-w', 15, "myuser"])
       provider.create
     end
   end
 
   describe "#destroy" do
     it "should use the delete command if the user exists and is not a role" do
-      provider.stubs(:exists?).returns(true)
-      provider.stubs(:is_role?).returns(false)
-      provider.expects(:deletecmd)
-      provider.expects(:run)
+      allow(provider).to receive(:exists?).and_return(true)
+      allow(provider).to receive(:is_role?).and_return(false)
+      expect(provider).to receive(:deletecmd)
+      expect(provider).to receive(:run)
       provider.destroy
     end
 
     it "should use the delete command if the user is a role" do
-      provider.stubs(:exists?).returns(true)
-      provider.stubs(:is_role?).returns(true)
-      provider.expects(:deletecmd)
-      provider.expects(:run)
+      allow(provider).to receive(:exists?).and_return(true)
+      allow(provider).to receive(:is_role?).and_return(true)
+      expect(provider).to receive(:deletecmd)
+      expect(provider).to receive(:run)
       provider.destroy
     end
   end
 
   describe "#create_role" do
     it "should use the transition(role) if the user exists" do
-      provider.stubs(:exists?).returns(true)
-      provider.stubs(:is_role?).returns(false)
-      provider.expects(:transition).with("role")
-      provider.expects(:run)
+      allow(provider).to receive(:exists?).and_return(true)
+      allow(provider).to receive(:is_role?).and_return(false)
+      expect(provider).to receive(:transition).with("role")
+      expect(provider).to receive(:run)
       provider.create_role
     end
 
     it "should use the add command when role doesn't exists" do
-      provider.stubs(:exists?).returns(false)
-      provider.expects(:addcmd)
-      provider.expects(:run)
+      allow(provider).to receive(:exists?).and_return(false)
+      expect(provider).to receive(:addcmd)
+      expect(provider).to receive(:run)
       provider.create_role
     end
   end
 
   describe "with :allow_duplicates" do
     before do
-      resource.stubs(:allowdupe?).returns true
-      provider.stubs(:is_role?).returns(false)
-      provider.stubs(:execute)
-      resource.stubs(:system?).returns false
-      provider.expects(:execute).with { |args| args.include?("-o") }
+      allow(resource).to receive(:allowdupe?).and_return(true)
+      allow(provider).to receive(:is_role?).and_return(false)
+      allow(provider).to receive(:execute)
+      allow(resource).to receive(:system?).and_return(false)
+      expect(provider).to receive(:execute).with(include("-o"), any_args)
     end
 
     it "should add -o when the user is being created" do
-      provider.stubs(:password=)
+      allow(provider).to receive(:password=)
       provider.create
     end
 
@@ -137,14 +137,14 @@ describe Puppet::Type.type(:user).provider(:user_role_add), :unless => Puppet.fe
     context "#send" do
       describe "when getting #{val}" do
         it "should get the user_attributes" do
-          provider.expects(:user_attributes)
+          expect(provider).to receive(:user_attributes)
           provider.send(val)
         end
 
         it "should get the #{val} attribute" do
-          attributes = mock("attributes")
-          attributes.expects(:[]).with(val)
-          provider.stubs(:user_attributes).returns(attributes)
+          attributes = double("attributes")
+          expect(attributes).to receive(:[]).with(val)
+          allow(provider).to receive(:user_attributes).and_return(attributes)
           provider.send(val)
         end
       end
@@ -153,33 +153,33 @@ describe Puppet::Type.type(:user).provider(:user_role_add), :unless => Puppet.fe
 
   describe "#keys" do
     it "should get the user_attributes" do
-      provider.expects(:user_attributes)
+      expect(provider).to receive(:user_attributes)
       provider.keys
     end
 
     it "should call removed_managed_attributes" do
-      provider.stubs(:user_attributes).returns({ :type => "normal", :foo => "something" })
-      provider.expects(:remove_managed_attributes)
+      allow(provider).to receive(:user_attributes).and_return({ :type => "normal", :foo => "something" })
+      expect(provider).to receive(:remove_managed_attributes)
       provider.keys
     end
 
     it "should removed managed attribute (type, auths, roles, etc)" do
-      provider.stubs(:user_attributes).returns({ :type => "normal", :foo => "something" })
+      allow(provider).to receive(:user_attributes).and_return({ :type => "normal", :foo => "something" })
       expect(provider.keys).to eq({ :foo => "something" })
     end
   end
 
   describe "#add_properties" do
     it "should call build_keys_cmd" do
-      resource.stubs(:should).returns ""
-      resource.expects(:should).with(:keys).returns({ :foo => "bar" })
-      provider.expects(:build_keys_cmd).returns([])
+      allow(resource).to receive(:should).and_return("")
+      expect(resource).to receive(:should).with(:keys).and_return({ :foo => "bar" })
+      expect(provider).to receive(:build_keys_cmd).and_return([])
       provider.add_properties
     end
 
     it "should add the elements of the keys hash to an array" do
-      resource.stubs(:should).returns ""
-      resource.expects(:should).with(:keys).returns({ :foo => "bar"})
+      allow(resource).to receive(:should).and_return("")
+      expect(resource).to receive(:should).with(:keys).and_return({ :foo => "bar"})
       expect(provider.add_properties).to eq(["-K", "foo=bar"])
     end
   end
@@ -192,57 +192,57 @@ describe Puppet::Type.type(:user).provider(:user_role_add), :unless => Puppet.fe
 
   describe "#keys=" do
     before do
-      provider.stubs(:is_role?).returns(false)
+      allow(provider).to receive(:is_role?).and_return(false)
     end
 
     it "should run a command" do
-      provider.expects(:run)
+      expect(provider).to receive(:run)
       provider.keys=({})
     end
 
     it "should build the command" do
-      resource.stubs(:[]).with(:name).returns("someuser")
-      provider.stubs(:command).returns("usermod")
-      provider.expects(:build_keys_cmd).returns(["-K", "foo=bar"])
-      provider.expects(:run).with(["usermod", "-K", "foo=bar", "someuser"], "modify attribute key pairs")
+      allow(resource).to receive(:[]).with(:name).and_return("someuser")
+      allow(provider).to receive(:command).and_return("usermod")
+      expect(provider).to receive(:build_keys_cmd).and_return(["-K", "foo=bar"])
+      expect(provider).to receive(:run).with(["usermod", "-K", "foo=bar", "someuser"], "modify attribute key pairs")
       provider.keys=({})
     end
   end
 
   describe "#password" do
     before do
-      @array = mock "array"
+      @array = double("array")
     end
 
     it "should readlines of /etc/shadow" do
-      File.expects(:readlines).with("/etc/shadow").returns([])
+      expect(File).to receive(:readlines).with("/etc/shadow").and_return([])
       provider.password
     end
 
     it "should reject anything that doesn't start with alpha numerics" do
-      @array.expects(:reject).returns([])
-      File.stubs(:readlines).with("/etc/shadow").returns(@array)
+      expect(@array).to receive(:reject).and_return([])
+      allow(File).to receive(:readlines).with("/etc/shadow").and_return(@array)
       provider.password
     end
 
     it "should collect splitting on ':'" do
-      @array.stubs(:reject).returns(@array)
-      @array.expects(:collect).returns([])
-      File.stubs(:readlines).with("/etc/shadow").returns(@array)
+      allow(@array).to receive(:reject).and_return(@array)
+      expect(@array).to receive(:collect).and_return([])
+      allow(File).to receive(:readlines).with("/etc/shadow").and_return(@array)
       provider.password
     end
 
     it "should find the matching user" do
-      resource.stubs(:[]).with(:name).returns("username")
-      @array.stubs(:reject).returns(@array)
-      @array.stubs(:collect).returns([["username", "hashedpassword"], ["someoneelse", "theirpassword"]])
-      File.stubs(:readlines).with("/etc/shadow").returns(@array)
+      allow(resource).to receive(:[]).with(:name).and_return("username")
+      allow(@array).to receive(:reject).and_return(@array)
+      allow(@array).to receive(:collect).and_return([["username", "hashedpassword"], ["someoneelse", "theirpassword"]])
+      allow(File).to receive(:readlines).with("/etc/shadow").and_return(@array)
       expect(provider.password).to eq("hashedpassword")
     end
 
     it "should get the right password" do
-      resource.stubs(:[]).with(:name).returns("username")
-      File.stubs(:readlines).with("/etc/shadow").returns(["#comment", "   nonsense", "  ", "username:hashedpassword:stuff:foo:bar:::", "other:pword:yay:::"])
+      allow(resource).to receive(:[]).with(:name).and_return("username")
+      allow(File).to receive(:readlines).with("/etc/shadow").and_return(["#comment", "   nonsense", "  ", "username:hashedpassword:stuff:foo:bar:::", "other:pword:yay:::"])
       expect(provider.password).to eq("hashedpassword")
     end
   end
@@ -251,7 +251,7 @@ describe Puppet::Type.type(:user).provider(:user_role_add), :unless => Puppet.fe
     let(:path) { tmpfile('etc-shadow') }
 
     before :each do
-      provider.stubs(:target_file_path).returns(path)
+      allow(provider).to receive(:target_file_path).and_return(path)
     end
 
     def write_fixture(content)
@@ -267,7 +267,7 @@ FIXTURE
     end
 
     it "should only update the target user" do
-      Date.expects(:today).returns Date.new(2011,12,07)
+      expect(Date).to receive(:today).and_return(Date.new(2011,12,07))
       write_fixture <<FIXTURE
 before:seriously:15315:0:99999:7:::
 fakeval:seriously:15315:0:99999:7:::
@@ -297,7 +297,7 @@ FIXTURE
     end
 
     it "should update the lastchg field" do
-      Date.expects(:today).returns Date.new(2013,5,12) # 15837 days after 1970-01-01
+      expect(Date).to receive(:today).and_return(Date.new(2013,5,12)) # 15837 days after 1970-01-01
       write_fixture <<FIXTURE
 before:seriously:15315:0:99999:7:::
 fakeval:seriously:15629:0:99999:7:::
@@ -316,58 +316,58 @@ EOT
 
   describe "#shadow_entry" do
     it "should return the line for the right user" do
-      File.stubs(:readlines).returns(["someuser:!:10:5:20:7:1::\n", "fakeval:*:20:10:30:7:2::\n", "testuser:*:30:15:40:7:3::\n"])
+      allow(File).to receive(:readlines).and_return(["someuser:!:10:5:20:7:1::\n", "fakeval:*:20:10:30:7:2::\n", "testuser:*:30:15:40:7:3::\n"])
       expect(provider.shadow_entry).to eq(["fakeval", "*", "20", "10", "30", "7", "2", "", ""])
     end
   end
 
   describe "#password_max_age" do
     it "should return a maximum age number" do
-      File.stubs(:readlines).returns(["fakeval:NP:12345:0:50::::\n"])
+      allow(File).to receive(:readlines).and_return(["fakeval:NP:12345:0:50::::\n"])
       expect(provider.password_max_age).to eq("50")
     end
 
     it "should return -1 for no maximum" do
-      File.stubs(:readlines).returns(["fakeval:NP:12345::::::\n"])
+      allow(File).to receive(:readlines).and_return(["fakeval:NP:12345::::::\n"])
       expect(provider.password_max_age).to eq(-1)
     end
 
     it "should return -1 for no maximum when failed attempts are present" do
-      File.stubs(:readlines).returns(["fakeval:NP:12345::::::3\n"])
+      allow(File).to receive(:readlines).and_return(["fakeval:NP:12345::::::3\n"])
       expect(provider.password_max_age).to eq(-1)
     end
   end
 
   describe "#password_min_age" do
     it "should return a minimum age number" do
-      File.stubs(:readlines).returns(["fakeval:NP:12345:10:50::::\n"])
+      allow(File).to receive(:readlines).and_return(["fakeval:NP:12345:10:50::::\n"])
       expect(provider.password_min_age).to eq("10")
     end
 
     it "should return -1 for no minimum" do
-      File.stubs(:readlines).returns(["fakeval:NP:12345::::::\n"])
+      allow(File).to receive(:readlines).and_return(["fakeval:NP:12345::::::\n"])
       expect(provider.password_min_age).to eq(-1)
     end
 
     it "should return -1 for no minimum when failed attempts are present" do
-      File.stubs(:readlines).returns(["fakeval:NP:12345::::::3\n"])
+      allow(File).to receive(:readlines).and_return(["fakeval:NP:12345::::::3\n"])
       expect(provider.password_min_age).to eq(-1)
     end
   end
 
   describe "#password_warn_days" do
     it "should return a warn days number" do
-      File.stubs(:readlines).returns(["fakeval:NP:12345:10:50:30:::\n"])
+      allow(File).to receive(:readlines).and_return(["fakeval:NP:12345:10:50:30:::\n"])
       expect(provider.password_warn_days).to eq("30")
     end
 
     it "should return -1 for no warn days" do
-      File.stubs(:readlines).returns(["fakeval:NP:12345::::::\n"])
+      allow(File).to receive(:readlines).and_return(["fakeval:NP:12345::::::\n"])
       expect(provider.password_warn_days).to eq(-1)
     end
 
     it "should return -1 for no warn days when failed attempts are present" do
-      File.stubs(:readlines).returns(["fakeval:NP:12345::::::3\n"])
+      allow(File).to receive(:readlines).and_return(["fakeval:NP:12345::::::3\n"])
       expect(provider.password_warn_days).to eq(-1)
     end
   end
