@@ -2,7 +2,6 @@ require 'spec_helper'
 require 'puppet_spec/files'
 
 describe Puppet::Type.type(:yumrepo).provider(:inifile) do
-
   include PuppetSpec::Files
 
   after(:each) do
@@ -11,9 +10,9 @@ describe Puppet::Type.type(:yumrepo).provider(:inifile) do
 
   describe "enumerating all yum repo files" do
     it "reads all files in the directories specified by reposdir" do
-      described_class.expects(:reposdir).returns ['/etc/yum.repos.d']
+      expect(described_class).to receive(:reposdir).and_return(['/etc/yum.repos.d'])
 
-      Dir.expects(:glob).with("/etc/yum.repos.d/*.repo").returns(['/etc/yum.repos.d/first.repo', '/etc/yum.repos.d/second.repo'])
+      expect(Dir).to receive(:glob).with("/etc/yum.repos.d/*.repo").and_return(['/etc/yum.repos.d/first.repo', '/etc/yum.repos.d/second.repo'])
 
       actual = described_class.repofiles
       expect(actual).to include("/etc/yum.repos.d/first.repo")
@@ -21,7 +20,7 @@ describe Puppet::Type.type(:yumrepo).provider(:inifile) do
     end
 
     it "includes '/etc/yum.conf' as the first element" do
-      described_class.expects(:reposdir).returns []
+      expect(described_class).to receive(:reposdir).and_return([])
 
       actual = described_class.repofiles
       expect(actual[0]).to eq "/etc/yum.conf"
@@ -30,42 +29,42 @@ describe Puppet::Type.type(:yumrepo).provider(:inifile) do
 
   describe "generating the virtual inifile" do
     let(:files) { ['/etc/yum.repos.d/first.repo', '/etc/yum.repos.d/second.repo', '/etc/yum.conf'] }
-    let(:collection) { mock('virtual inifile') }
+    let(:collection) { double('virtual inifile') }
 
     before do
       described_class.clear
-      Puppet::Util::IniConfig::FileCollection.expects(:new).returns collection
+      expect(Puppet::Util::IniConfig::FileCollection).to receive(:new).and_return(collection)
     end
 
     it "reads all files in the directories specified by self.repofiles" do
-      described_class.expects(:repofiles).returns(files)
+      expect(described_class).to receive(:repofiles).and_return(files)
 
       files.each do |file|
-        Puppet::FileSystem.stubs(:file?).with(file).returns true
-        collection.expects(:read).with(file)
+        allow(Puppet::FileSystem).to receive(:file?).with(file).and_return(true)
+        expect(collection).to receive(:read).with(file)
       end
       described_class.virtual_inifile
     end
 
     it "ignores repofile entries that are not files" do
-      described_class.expects(:repofiles).returns(files)
+      expect(described_class).to receive(:repofiles).and_return(files)
 
-      Puppet::FileSystem.stubs(:file?).with('/etc/yum.repos.d/first.repo').returns true
-      Puppet::FileSystem.stubs(:file?).with('/etc/yum.repos.d/second.repo').returns false
-      Puppet::FileSystem.stubs(:file?).with('/etc/yum.conf').returns true
+      allow(Puppet::FileSystem).to receive(:file?).with('/etc/yum.repos.d/first.repo').and_return(true)
+      allow(Puppet::FileSystem).to receive(:file?).with('/etc/yum.repos.d/second.repo').and_return(false)
+      allow(Puppet::FileSystem).to receive(:file?).with('/etc/yum.conf').and_return(true)
 
-      collection.expects(:read).with('/etc/yum.repos.d/first.repo').once
-      collection.expects(:read).with('/etc/yum.repos.d/second.repo').never
-      collection.expects(:read).with('/etc/yum.conf').once
+      expect(collection).to receive(:read).with('/etc/yum.repos.d/first.repo').once
+      expect(collection).not_to receive(:read).with('/etc/yum.repos.d/second.repo')
+      expect(collection).to receive(:read).with('/etc/yum.conf').once
       described_class.virtual_inifile
     end
   end
 
   describe 'creating provider instances' do
-    let(:virtual_inifile) { stub('virtual inifile') }
+    let(:virtual_inifile) { double('virtual inifile') }
 
     before :each do
-      described_class.stubs(:virtual_inifile).returns(virtual_inifile)
+      allow(described_class).to receive(:virtual_inifile).and_return(virtual_inifile)
     end
 
     let(:main_section) do
@@ -85,7 +84,7 @@ describe Puppet::Type.type(:yumrepo).provider(:inifile) do
     end
 
     it "ignores the main section" do
-      virtual_inifile.expects(:each_section).multiple_yields(main_section, updates_section)
+      expect(virtual_inifile).to receive(:each_section).and_yield(main_section).and_yield(updates_section)
 
       instances = described_class.instances
       expect(instances).to have(1).items
@@ -93,7 +92,7 @@ describe Puppet::Type.type(:yumrepo).provider(:inifile) do
     end
 
     it "creates provider instances for every non-main section that was found" do
-      virtual_inifile.expects(:each_section).multiple_yields(main_section, updates_section)
+      expect(virtual_inifile).to receive(:each_section).and_yield(main_section).and_yield(updates_section)
 
       sect = described_class.instances.first
       expect(sect.name).to eq 'updates'
@@ -103,18 +102,16 @@ describe Puppet::Type.type(:yumrepo).provider(:inifile) do
   end
 
   describe "retrieving a section from the inifile" do
-
-    let(:collection) { stub('ini file collection') }
-
-    let(:ini_section) { stub('ini file section') }
+    let(:collection) { double('ini file collection') }
+    let(:ini_section) { double('ini file section') }
 
     before do
-      described_class.stubs(:virtual_inifile).returns(collection)
+      allow(described_class).to receive(:virtual_inifile).and_return(collection)
     end
 
     describe "and the requested section exists" do
       before do
-        collection.stubs(:[]).with('updates').returns ini_section
+        allow(collection).to receive(:[]).with('updates').and_return(ini_section)
       end
 
       it "returns the existing section" do
@@ -122,24 +119,24 @@ describe Puppet::Type.type(:yumrepo).provider(:inifile) do
       end
 
       it "doesn't create a new section" do
-        collection.expects(:add_section).never
+        expect(collection).not_to receive(:add_section)
         described_class.section('updates')
       end
     end
 
     describe "and the requested section doesn't exist" do
       it "creates a section in the preferred repodir" do
-        described_class.stubs(:reposdir).returns ['/etc/yum.repos.d', '/etc/alternate.repos.d']
-        collection.expects(:[]).with('updates')
-        collection.expects(:add_section).with('updates', '/etc/alternate.repos.d/updates.repo')
+        allow(described_class).to receive(:reposdir).and_return(['/etc/yum.repos.d', '/etc/alternate.repos.d'])
+        expect(collection).to receive(:[]).with('updates')
+        expect(collection).to receive(:add_section).with('updates', '/etc/alternate.repos.d/updates.repo')
 
         described_class.section('updates')
       end
 
       it "creates a section in yum.conf if no repodirs exist" do
-        described_class.stubs(:reposdir).returns []
-        collection.expects(:[]).with('updates')
-        collection.expects(:add_section).with('updates', '/etc/yum.conf')
+        allow(described_class).to receive(:reposdir).and_return([])
+        expect(collection).to receive(:[]).with('updates')
+        expect(collection).to receive(:add_section).with('updates', '/etc/yum.conf')
 
         described_class.section('updates')
       end
@@ -147,7 +144,6 @@ describe Puppet::Type.type(:yumrepo).provider(:inifile) do
   end
 
   describe "setting and getting properties" do
-
     let(:type_instance) do
       Puppet::Type.type(:yumrepo).new(
         :name     => 'puppetlabs-products',
@@ -165,68 +161,68 @@ describe Puppet::Type.type(:yumrepo).provider(:inifile) do
     end
 
     let(:section) do
-      stub('inifile puppetlabs section', :name => 'puppetlabs-products')
+      double('inifile puppetlabs section', :name => 'puppetlabs-products')
     end
 
     before do
       type_instance.provider = provider
-      described_class.stubs(:section).with('puppetlabs-products').returns(section)
+      allow(described_class).to receive(:section).with('puppetlabs-products').and_return(section)
     end
 
     describe "methods used by ensurable" do
       it "#create sets the yumrepo properties on the according section" do
-        section.expects(:[]=).with('baseurl', 'http://yum.puppetlabs.com/el/6/products/$basearch')
-        section.expects(:[]=).with('name', 'Puppet Labs Products El 6 - $basearch')
-        section.expects(:[]=).with('enabled', '1')
-        section.expects(:[]=).with('gpgcheck', '1')
-        section.expects(:[]=).with('gpgkey', 'file:///etc/pki/rpm-gpg/RPM-GPG-KEY-puppetlabs')
+        expect(section).to receive(:[]=).with('baseurl', 'http://yum.puppetlabs.com/el/6/products/$basearch')
+        expect(section).to receive(:[]=).with('name', 'Puppet Labs Products El 6 - $basearch')
+        expect(section).to receive(:[]=).with('enabled', '1')
+        expect(section).to receive(:[]=).with('gpgcheck', '1')
+        expect(section).to receive(:[]=).with('gpgkey', 'file:///etc/pki/rpm-gpg/RPM-GPG-KEY-puppetlabs')
 
         provider.create
       end
 
       it "#exists? checks if the repo has been marked as present" do
-        described_class.stubs(:section).returns(stub(:[]= => nil))
+        allow(described_class).to receive(:section).and_return(double(:[]= => nil))
         provider.create
         expect(provider).to be_exist
       end
 
       it "#destroy deletes the associated ini file section" do
-        described_class.expects(:section).returns(section)
-        section.expects(:destroy=).with(true)
+        expect(described_class).to receive(:section).and_return(section)
+        expect(section).to receive(:destroy=).with(true)
         provider.destroy
       end
     end
 
     describe "getting properties" do
       it "maps the 'descr' property to the 'name' INI property" do
-        section.expects(:[]).with('name').returns 'Some rather long description of the repository'
+        expect(section).to receive(:[]).with('name').and_return('Some rather long description of the repository')
         expect(provider.descr).to eq 'Some rather long description of the repository'
       end
 
       it "gets the property from the INI section" do
-        section.expects(:[]).with('enabled').returns '1'
+        expect(section).to receive(:[]).with('enabled').and_return('1')
         expect(provider.enabled).to eq '1'
       end
 
       it "sets the property as :absent if the INI property is nil" do
-        section.expects(:[]).with('exclude').returns nil
+        expect(section).to receive(:[]).with('exclude').and_return(nil)
         expect(provider.exclude).to eq :absent
       end
     end
 
     describe "setting properties" do
       it "maps the 'descr' property to the 'name' INI property" do
-        section.expects(:[]=).with('name', 'Some rather long description of the repository')
+        expect(section).to receive(:[]=).with('name', 'Some rather long description of the repository')
         provider.descr = 'Some rather long description of the repository'
       end
 
       it "sets the property on the INI section" do
-        section.expects(:[]=).with('enabled', '0')
+        expect(section).to receive(:[]=).with('enabled', '0')
         provider.enabled = '0'
       end
 
       it "sets the section field to nil when the specified value is absent" do
-        section.expects(:[]=).with('exclude', nil)
+        expect(section).to receive(:[]=).with('exclude', nil)
         provider.exclude = :absent
       end
     end
@@ -236,51 +232,50 @@ describe Puppet::Type.type(:yumrepo).provider(:inifile) do
     let(:defaults) { ['/etc/yum.repos.d', '/etc/yum/repos.d'] }
 
     before do
-      Puppet::FileSystem.stubs(:exist?).with('/etc/yum.repos.d').returns(true)
-      Puppet::FileSystem.stubs(:exist?).with('/etc/yum/repos.d').returns(true)
+      allow(Puppet::FileSystem).to receive(:exist?).with('/etc/yum.repos.d').and_return(true)
+      allow(Puppet::FileSystem).to receive(:exist?).with('/etc/yum/repos.d').and_return(true)
     end
 
     it "returns the default directories if yum.conf doesn't contain a `reposdir` entry" do
-      described_class.stubs(:find_conf_value).with('reposdir', '/etc/yum.conf')
+      allow(described_class).to receive(:find_conf_value).with('reposdir', '/etc/yum.conf')
       expect(described_class.reposdir('/etc/yum.conf')).to eq(defaults)
     end
 
     it "includes the directory specified by the yum.conf 'reposdir' entry when the directory is present" do
-      Puppet::FileSystem.expects(:exist?).with("/etc/yum/extra.repos.d").returns(true)
+      expect(Puppet::FileSystem).to receive(:exist?).with("/etc/yum/extra.repos.d").and_return(true)
 
-      described_class.expects(:find_conf_value).with('reposdir', '/etc/yum.conf').returns "/etc/yum/extra.repos.d"
+      expect(described_class).to receive(:find_conf_value).with('reposdir', '/etc/yum.conf').and_return("/etc/yum/extra.repos.d")
       expect(described_class.reposdir('/etc/yum.conf')).to include("/etc/yum/extra.repos.d")
     end
 
     it "includes the directory if the value is split by whitespace" do
-      Puppet::FileSystem.expects(:exist?).with("/etc/yum/extra.repos.d").returns(true)
-      Puppet::FileSystem.expects(:exist?).with("/etc/yum/misc.repos.d").returns(true)
+      expect(Puppet::FileSystem).to receive(:exist?).with("/etc/yum/extra.repos.d").and_return(true)
+      expect(Puppet::FileSystem).to receive(:exist?).with("/etc/yum/misc.repos.d").and_return(true)
 
-      described_class.expects(:find_conf_value).with('reposdir', '/etc/yum.conf').returns "/etc/yum/extra.repos.d /etc/yum/misc.repos.d"
+      expect(described_class).to receive(:find_conf_value).with('reposdir', '/etc/yum.conf').and_return("/etc/yum/extra.repos.d /etc/yum/misc.repos.d")
       expect(described_class.reposdir('/etc/yum.conf')).to include("/etc/yum/extra.repos.d", "/etc/yum/misc.repos.d")
     end
 
     it "includes the directory if the value is split by new lines" do
-      Puppet::FileSystem.expects(:exist?).with("/etc/yum/extra.repos.d").returns(true)
-      Puppet::FileSystem.expects(:exist?).with("/etc/yum/misc.repos.d").returns(true)
+      expect(Puppet::FileSystem).to receive(:exist?).with("/etc/yum/extra.repos.d").and_return(true)
+      expect(Puppet::FileSystem).to receive(:exist?).with("/etc/yum/misc.repos.d").and_return(true)
 
-      described_class.expects(:find_conf_value).with('reposdir', '/etc/yum.conf').returns "/etc/yum/extra.repos.d\n/etc/yum/misc.repos.d"
+      expect(described_class).to receive(:find_conf_value).with('reposdir', '/etc/yum.conf').and_return("/etc/yum/extra.repos.d\n/etc/yum/misc.repos.d")
       expect(described_class.reposdir('/etc/yum.conf')).to include("/etc/yum/extra.repos.d", "/etc/yum/misc.repos.d")
     end
 
     it "doesn't include the directory specified by the yum.conf 'reposdir' entry when the directory is absent" do
-      Puppet::FileSystem.expects(:exist?).with("/etc/yum/extra.repos.d").returns(false)
+      expect(Puppet::FileSystem).to receive(:exist?).with("/etc/yum/extra.repos.d").and_return(false)
 
-      described_class.expects(:find_conf_value).with('reposdir', '/etc/yum.conf').returns "/etc/yum/extra.repos.d"
+      expect(described_class).to receive(:find_conf_value).with('reposdir', '/etc/yum.conf').and_return("/etc/yum/extra.repos.d")
       expect(described_class.reposdir('/etc/yum.conf')).not_to include("/etc/yum/extra.repos.d")
     end
 
     it "logs a warning and returns an empty array if none of the specified repo directories exist" do
-      Puppet::FileSystem.unstub(:exist?)
-      Puppet::FileSystem.stubs(:exist?).returns false
+      allow(Puppet::FileSystem).to receive(:exist?).and_return(false)
 
-      described_class.stubs(:find_conf_value).with('reposdir', '/etc/yum.conf')
-      Puppet.expects(:debug).with('No yum directories were found on the local filesystem')
+      allow(described_class).to receive(:find_conf_value).with('reposdir', '/etc/yum.conf')
+      expect(Puppet).to receive(:debug).with('No yum directories were found on the local filesystem')
       expect(described_class.reposdir('/etc/yum.conf')).to be_empty
     end
   end
@@ -288,40 +283,40 @@ describe Puppet::Type.type(:yumrepo).provider(:inifile) do
   describe "looking up a conf value" do
     describe "and the file doesn't exist" do
       it "returns nil" do
-        Puppet::FileSystem.stubs(:exist?).returns false
+        allow(Puppet::FileSystem).to receive(:exist?).and_return(false)
         expect(described_class.find_conf_value('reposdir')).to be_nil
       end
     end
 
     describe "and the file exists" do
-      let(:pfile) { stub('yum.conf physical file') }
-      let(:sect) { stub('ini section') }
+      let(:pfile) { double('yum.conf physical file') }
+      let(:sect ) { double('ini section') }
 
       before do
-        Puppet::FileSystem.stubs(:exist?).with('/etc/yum.conf').returns true
-        Puppet::Util::IniConfig::PhysicalFile.stubs(:new).with('/etc/yum.conf').returns pfile
-        pfile.expects(:read)
+        allow(Puppet::FileSystem).to receive(:exist?).with('/etc/yum.conf').and_return(true)
+        allow(Puppet::Util::IniConfig::PhysicalFile).to receive(:new).with('/etc/yum.conf').and_return(pfile)
+        expect(pfile).to receive(:read)
       end
 
       it "creates a PhysicalFile to parse the given file" do
-        pfile.expects(:get_section)
+        expect(pfile).to receive(:get_section)
         described_class.find_conf_value('reposdir')
       end
 
       it "returns nil if the file exists but the 'main' section doesn't exist" do
-        pfile.expects(:get_section).with('main')
+        expect(pfile).to receive(:get_section).with('main')
         expect(described_class.find_conf_value('reposdir')).to be_nil
       end
 
       it "returns nil if the file exists but the INI property doesn't exist" do
-        pfile.expects(:get_section).with('main').returns sect
-        sect.expects(:[]).with('reposdir')
+        expect(pfile).to receive(:get_section).with('main').and_return(sect)
+        expect(sect).to receive(:[]).with('reposdir')
         expect(described_class.find_conf_value('reposdir')).to be_nil
       end
 
       it "returns the value if the value is defined in the PhysicalFile" do
-        pfile.expects(:get_section).with('main').returns sect
-        sect.expects(:[]).with('reposdir').returns '/etc/alternate.repos.d'
+        expect(pfile).to receive(:get_section).with('main').and_return(sect)
+        expect(sect).to receive(:[]).with('reposdir').and_return('/etc/alternate.repos.d')
         expect(described_class.find_conf_value('reposdir')).to eq '/etc/alternate.repos.d'
       end
     end
@@ -347,7 +342,7 @@ describe Puppet::Type.type(:yumrepo).provider(:inifile) do
     before :each do
       @yumrepo_dir = tmpdir('yumrepo_integration_specs')
       @yumrepo_conf_file = tmpfile('yumrepo_conf_file', @yumrepo_dir)
-      described_class.stubs(:reposdir).returns [@yumrepo_dir]
+      allow(described_class).to receive(:reposdir).and_return([@yumrepo_dir])
       type_instance.provider = provider
     end
 
