@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 require 'puppet_spec/files'
 
@@ -390,8 +389,8 @@ describe 'Puppet Pal' do
       end
 
       {  nil      => Puppet::Error,
-        '0xWAT'   => Puppet::ParseErrorWithIssue, 
-        '$0 = 1'  => Puppet::ParseErrorWithIssue, 
+        '0xWAT'   => Puppet::ParseErrorWithIssue,
+        '$0 = 1'  => Puppet::ParseErrorWithIssue,
         'else 32' => Puppet::ParseErrorWithIssue,
       }.each_pair do |input, error_class|
         it "'parse_string' raises an error for invalid input: '#{input}'" do
@@ -517,7 +516,7 @@ describe 'Puppet Pal' do
 
     # TODO: there is something amiss with the metadata wrt dependencies - when metadata is present there is an error
     #       that dependencies could not be resolved. Metadata is therefore commented out.
-    #       Dependency based visibility is probably something that we should remove... 
+    #       Dependency based visibility is probably something that we should remove...
     let(:modules) {
       {
         'a' => {
@@ -715,6 +714,9 @@ describe 'Puppet Pal' do
 
       context 'facts are supported such that' do
         it 'they are obtained if they are not given' do
+          facts = Puppet::Node::Facts.new(Puppet[:certname], 'puppetversion' => Puppet.version)
+          Puppet::Node::Facts.indirection.save(facts)
+
           testing_env_dir # creates the structure
           result = Puppet::Pal.in_tmp_environment('pal_env', modulepath: modulepath ) do |ctx|
             ctx.with_script_compiler {|c| c.evaluate_string("$facts =~ Hash and $facts[puppetversion] == '#{Puppet.version}'") }
@@ -927,7 +929,7 @@ describe 'Puppet Pal' do
         testing_env_dir # creates the structure
         other_modules1 = File.join(environments_dir, 'other_env1/modules')
         other_modules2 = File.join(environments_dir, 'other_env2/modules')
-        result = Puppet::Pal.in_environment('pal_env', envpath: environments_dir, 
+        result = Puppet::Pal.in_environment('pal_env', envpath: environments_dir,
           pre_modulepath: [other_modules1],
           post_modulepath: [other_modules2],
           facts: node_facts
