@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 require 'puppet'
 require 'puppet_spec/files'
@@ -39,8 +38,8 @@ describe Puppet do
   end
 
   it 'should propagate --modulepath to base environment' do
-    Puppet::Node::Environment.expects(:create).with(
-      is_a(Symbol), ['/my/modules'], Puppet::Node::Environment::NO_MANIFEST)
+    expect(Puppet::Node::Environment).to receive(:create).with(
+      be_a(Symbol), ['/my/modules'], Puppet::Node::Environment::NO_MANIFEST)
 
     Puppet.base_context({
       :environmentpath => '/envs',
@@ -50,8 +49,8 @@ describe Puppet do
   end
 
   it 'empty modulepath does not override basemodulepath' do
-    Puppet::Node::Environment.expects(:create).with(
-      is_a(Symbol), ['/base/modules'], Puppet::Node::Environment::NO_MANIFEST)
+    expect(Puppet::Node::Environment).to receive(:create).with(
+      be_a(Symbol), ['/base/modules'], Puppet::Node::Environment::NO_MANIFEST)
 
     Puppet.base_context({
       :environmentpath => '/envs',
@@ -61,8 +60,8 @@ describe Puppet do
   end
 
   it 'nil modulepath does not override basemodulepath' do
-    Puppet::Node::Environment.expects(:create).with(
-      is_a(Symbol), ['/base/modules'], Puppet::Node::Environment::NO_MANIFEST)
+    expect(Puppet::Node::Environment).to receive(:create).with(
+      be_a(Symbol), ['/base/modules'], Puppet::Node::Environment::NO_MANIFEST)
 
     Puppet.base_context({
       :environmentpath => '/envs',
@@ -87,7 +86,7 @@ describe Puppet do
 
   context "newtype" do
     it "should issue a deprecation warning" do
-      subject.expects(:deprecation_warning).with("Creating sometype via Puppet.newtype is deprecated and will be removed in a future release. Use Puppet::Type.newtype instead.")
+      expect(subject).to receive(:deprecation_warning).with("Creating sometype via Puppet.newtype is deprecated and will be removed in a future release. Use Puppet::Type.newtype instead.")
       subject.newtype("sometype")
     end
   end
