@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 require 'matchers/include_in_order'
 require 'puppet_spec/compiler'
@@ -90,7 +89,7 @@ describe Puppet::Transaction do
       report = Puppet::Transaction::Report.new
       catalog.retrieval_duration = 5
 
-      report.expects(:add_times).with(:config_retrieval, 5)
+      expect(report).to receive(:add_times).with(:config_retrieval, 5)
 
       Puppet::Transaction.new(catalog, report, nil)
     end
@@ -102,8 +101,8 @@ describe Puppet::Transaction do
     it "should process events" do
       transaction = transaction_with_resource(resource)
 
-      transaction.expects(:skip?).with(resource).returns false
-      transaction.event_manager.expects(:process_events).with(resource)
+      expect(transaction).to receive(:skip?).with(resource).and_return(false)
+      expect(transaction.event_manager).to receive(:process_events).with(resource)
 
       transaction.evaluate
     end
@@ -112,7 +111,7 @@ describe Puppet::Transaction do
       it "should mark the resource's status as skipped" do
         transaction = transaction_with_resource(resource)
 
-        transaction.expects(:skip?).with(resource).returns true
+        expect(transaction).to receive(:skip?).with(resource).and_return(true)
 
         transaction.evaluate
         expect(transaction.resource_status(resource)).to be_skipped
@@ -120,15 +119,15 @@ describe Puppet::Transaction do
 
       it "does not process any scheduled events" do
         transaction = transaction_with_resource(resource)
-        transaction.expects(:skip?).with(resource).returns true
-        transaction.event_manager.expects(:process_events).with(resource).never
+        expect(transaction).to receive(:skip?).with(resource).and_return(true)
+        expect(transaction.event_manager).not_to receive(:process_events).with(resource)
         transaction.evaluate
       end
 
       it "dequeues all events scheduled on that resource" do
         transaction = transaction_with_resource(resource)
-        transaction.expects(:skip?).with(resource).returns true
-        transaction.event_manager.expects(:dequeue_all_events_for_resource).with(resource)
+        expect(transaction).to receive(:skip?).with(resource).and_return(true)
+        expect(transaction.event_manager).to receive(:dequeue_all_events_for_resource).with(resource)
         transaction.evaluate
       end
     end
@@ -137,7 +136,7 @@ describe Puppet::Transaction do
   describe "when evaluating a skipped resource for corrective change it" do
     before :each do
       # Enable persistence during tests
-      Puppet::Transaction::Persistence.any_instance.stubs(:enabled?).returns(true)
+      allow_any_instance_of(Puppet::Transaction::Persistence).to receive(:enabled?).and_return(true)
     end
 
     it "should persist in the transactionstore" do
@@ -149,8 +148,8 @@ describe Puppet::Transaction do
       expect(transaction.resource_status(resource)).to be_changed
 
       transaction = transaction_with_resource(resource)
-      transaction.expects(:skip?).with(resource).returns true
-      transaction.event_manager.expects(:process_events).with(resource).never
+      expect(transaction).to receive(:skip?).with(resource).and_return(true)
+      expect(transaction.event_manager).not_to receive(:process_events).with(resource)
       transaction.evaluate
       expect(transaction.resource_status(resource)).to be_skipped
 
@@ -168,35 +167,35 @@ describe Puppet::Transaction do
       @status = Puppet::Resource::Status.new(@resource)
 
       @transaction = Puppet::Transaction.new(@catalog, nil, Puppet::Graph::RandomPrioritizer.new)
-      @transaction.event_manager.stubs(:queue_events)
+      allow(@transaction.event_manager).to receive(:queue_events)
     end
 
     it "should use its resource harness to apply the resource" do
-      @transaction.resource_harness.expects(:evaluate).with(@resource)
+      expect(@transaction.resource_harness).to receive(:evaluate).with(@resource)
       @transaction.evaluate
     end
 
     it "should add the resulting resource status to its status list" do
-      @transaction.resource_harness.stubs(:evaluate).returns(@status)
+      allow(@transaction.resource_harness).to receive(:evaluate).and_return(@status)
       @transaction.evaluate
       expect(@transaction.resource_status(@resource)).to be_instance_of(Puppet::Resource::Status)
     end
 
     it "should queue any events added to the resource status" do
-      @transaction.resource_harness.stubs(:evaluate).returns(@status)
-      @status.expects(:events).returns %w{a b}
-      @transaction.event_manager.expects(:queue_events).with(@resource, ["a", "b"])
+      allow(@transaction.resource_harness).to receive(:evaluate).and_return(@status)
+      expect(@status).to receive(:events).and_return(%w{a b})
+      expect(@transaction.event_manager).to receive(:queue_events).with(@resource, ["a", "b"])
       @transaction.evaluate
     end
 
     it "should log and skip any resources that cannot be applied" do
-      @resource.expects(:properties).raises ArgumentError
+      expect(@resource).to receive(:properties).and_raise(ArgumentError)
       @transaction.evaluate
       expect(@transaction.report.resource_statuses[@resource.to_s]).to be_failed
     end
 
     it "should report any_failed if any resources failed" do
-      @resource.expects(:properties).raises ArgumentError
+      expect(@resource).to receive(:properties).and_raise(ArgumentError)
       @transaction.evaluate
 
       expect(@transaction).to be_any_failed
@@ -236,8 +235,8 @@ describe Puppet::Transaction do
     end
 
     it "should warn if there are no blockers" do
-      vertex = stub('vertex')
-      vertex.expects(:warning).with "appears to have a negative number of dependencies"
+      vertex = double('vertex')
+      expect(vertex).to receive(:warning).with("appears to have a negative number of dependencies")
       graph.blockers[vertex] = 0
 
       graph.unblock(vertex)
@@ -265,7 +264,7 @@ describe Puppet::Transaction do
     end
 
     it "should yield the resource even if eval_generate is called" do
-      Puppet::Transaction::AdditionalResourceGenerator.any_instance.expects(:eval_generate).with(resource).returns true
+      expect_any_instance_of(Puppet::Transaction::AdditionalResourceGenerator).to receive(:eval_generate).with(resource).and_return(true)
 
       yielded = false
       @transaction.evaluate do |res|
@@ -276,7 +275,7 @@ describe Puppet::Transaction do
     end
 
     it "should prefetch the provider if necessary" do
-      @transaction.expects(:prefetch_if_necessary).with(resource)
+      expect(@transaction).to receive(:prefetch_if_necessary).with(resource)
 
       @transaction.evaluate {}
     end
@@ -309,7 +308,7 @@ describe Puppet::Transaction do
       dependent = Puppet::Type.type(:notify).new(:name => "hello", :require => resource)
       @transaction.catalog.add_resource(dependent)
 
-      resource.stubs(:suitable?).returns false
+      allow(resource).to receive(:suitable?).and_return(false)
 
       evaluated = []
       @transaction.evaluate do |res|
@@ -332,20 +331,20 @@ describe Puppet::Transaction do
 
     before :each do
       catalog.add_resource generator
-      generator.stubs(:generate).returns generated
+      allow(generator).to receive(:generate).and_return(generated)
       # avoid crude failures because of nil resources that result
       # from implicit containment and lacking containers
-      catalog.stubs(:container_of).returns generator
+      allow(catalog).to receive(:container_of).and_return(generator)
     end
 
     it "should call 'generate' on all created resources" do
-      generated.each { |res| res.expects(:generate) }
+      generated.each { |res| expect(res).to receive(:generate) }
 
       transaction.evaluate
     end
 
     it "should finish all resources" do
-      generated.each { |res| res.expects(:finish) }
+      generated.each { |res| expect(res).to receive(:finish) }
 
       transaction.evaluate
     end
@@ -370,30 +369,29 @@ describe Puppet::Transaction do
 
     before :each do
       generator = Puppet::Transaction::AdditionalResourceGenerator.new(catalog, nil, prioritizer)
-      Puppet::Transaction::AdditionalResourceGenerator.stubs(:new).returns(generator)
+      allow(Puppet::Transaction::AdditionalResourceGenerator).to receive(:new).and_return(generator)
     end
 
     it "should should query the generator for whether resources failed to generate" do
       relationship_graph = Puppet::Graph::RelationshipGraph.new(prioritizer)
-      catalog.stubs(:relationship_graph).returns(relationship_graph)
+      allow(catalog).to receive(:relationship_graph).and_return(relationship_graph)
 
-      sequence = sequence(:traverse_first)
-      relationship_graph.expects(:traverse).in_sequence(sequence)
-      generator.expects(:resources_failed_to_generate).in_sequence(sequence)
+      expect(relationship_graph).to receive(:traverse).ordered
+      expect(generator).to receive(:resources_failed_to_generate).ordered
 
       transaction.evaluate
     end
 
     it "should report that resources failed to generate" do
-      generator.expects(:resources_failed_to_generate).returns(true)
-      report.expects(:resources_failed_to_generate=).with(true)
+      expect(generator).to receive(:resources_failed_to_generate).and_return(true)
+      expect(report).to receive(:resources_failed_to_generate=).with(true)
 
       transaction.evaluate
     end
 
     it "should not report that resources failed to generate if none did" do
-      generator.expects(:resources_failed_to_generate).returns(false)
-      report.expects(:resources_failed_to_generate=).never
+      expect(generator).to receive(:resources_failed_to_generate).and_return(false)
+      expect(report).not_to receive(:resources_failed_to_generate=)
 
       transaction.evaluate
     end
@@ -405,20 +403,20 @@ describe Puppet::Transaction do
     let(:spec_exception) { 'spec-exception' }
 
     it "should invoke each resource's hook and apply the catalog after no failures" do
-      resource.expects(:pre_run_check)
+      expect(resource).to receive(:pre_run_check)
 
       transaction.evaluate
     end
 
     it "should abort the transaction on failure" do
-      resource.expects(:pre_run_check).raises(Puppet::Error, spec_exception)
+      expect(resource).to receive(:pre_run_check).and_raise(Puppet::Error, spec_exception)
 
       expect { transaction.evaluate }.to raise_error(Puppet::Error, /Some pre-run checks failed/)
     end
 
     it "should log the resource-specific exception" do
-      resource.expects(:pre_run_check).raises(Puppet::Error, spec_exception)
-      resource.expects(:log_exception).with(responds_with(:message, spec_exception))
+      expect(resource).to receive(:pre_run_check).and_raise(Puppet::Error, spec_exception)
+      expect(resource).to receive(:log_exception).with(have_attributes(message: match(/#{spec_exception}/)))
 
       expect { transaction.evaluate }.to raise_error(Puppet::Error)
     end
@@ -433,61 +431,61 @@ describe Puppet::Transaction do
     end
 
     it "should skip resource with missing tags" do
-      @transaction.stubs(:missing_tags?).returns(true)
+      allow(@transaction).to receive(:missing_tags?).and_return(true)
       expect(@transaction).to be_skip(@resource)
     end
 
     it "should skip resources tagged with the skip tags" do
-      @transaction.stubs(:skip_tags?).returns(true)
+      allow(@transaction).to receive(:skip_tags?).and_return(true)
       expect(@transaction).to be_skip(@resource)
     end
 
     it "should skip unscheduled resources" do
-      @transaction.stubs(:scheduled?).returns(false)
+      allow(@transaction).to receive(:scheduled?).and_return(false)
       expect(@transaction).to be_skip(@resource)
     end
 
     it "should skip resources with failed dependencies" do
-      @transaction.stubs(:failed_dependencies?).returns(true)
+      allow(@transaction).to receive(:failed_dependencies?).and_return(true)
       expect(@transaction).to be_skip(@resource)
     end
 
     it "should skip virtual resource" do
-      @resource.stubs(:virtual?).returns true
+      allow(@resource).to receive(:virtual?).and_return(true)
       expect(@transaction).to be_skip(@resource)
     end
 
     it "should skip device only resouce on normal host" do
-      @resource.stubs(:appliable_to_host?).returns false
-      @resource.stubs(:appliable_to_device?).returns true
+      allow(@resource).to receive(:appliable_to_host?).and_return(false)
+      allow(@resource).to receive(:appliable_to_device?).and_return(true)
       @transaction.for_network_device = false
       expect(@transaction).to be_skip(@resource)
     end
 
     it "should not skip device only resouce on remote device" do
-      @resource.stubs(:appliable_to_host?).returns false
-      @resource.stubs(:appliable_to_device?).returns true
+      allow(@resource).to receive(:appliable_to_host?).and_return(false)
+      allow(@resource).to receive(:appliable_to_device?).and_return(true)
       @transaction.for_network_device = true
       expect(@transaction).not_to be_skip(@resource)
     end
 
     it "should skip host resouce on device" do
-      @resource.stubs(:appliable_to_host?).returns true
-      @resource.stubs(:appliable_to_device?).returns false
+      allow(@resource).to receive(:appliable_to_host?).and_return(true)
+      allow(@resource).to receive(:appliable_to_device?).and_return(false)
       @transaction.for_network_device = true
       expect(@transaction).to be_skip(@resource)
     end
 
     it "should not skip resouce available on both device and host when on device" do
-      @resource.stubs(:appliable_to_host?).returns true
-      @resource.stubs(:appliable_to_device?).returns true
+      allow(@resource).to receive(:appliable_to_host?).and_return(true)
+      allow(@resource).to receive(:appliable_to_device?).and_return(true)
       @transaction.for_network_device = true
       expect(@transaction).not_to be_skip(@resource)
     end
 
     it "should not skip resouce available on both device and host when on host" do
-      @resource.stubs(:appliable_to_host?).returns true
-      @resource.stubs(:appliable_to_device?).returns true
+      allow(@resource).to receive(:appliable_to_host?).and_return(true)
+      allow(@resource).to receive(:appliable_to_device?).and_return(true)
       @transaction.for_network_device = false
       expect(@transaction).not_to be_skip(@resource)
     end
@@ -500,20 +498,20 @@ describe Puppet::Transaction do
       @resource.catalog = @catalog
       @transaction = Puppet::Transaction.new(@catalog, nil, nil)
 
-      @transaction.stubs(:ignore_tags?).returns false
+      allow(@transaction).to receive(:ignore_tags?).and_return(false)
     end
 
     it "should not be missing tags if tags are being ignored" do
-      @transaction.expects(:ignore_tags?).returns true
+      expect(@transaction).to receive(:ignore_tags?).and_return(true)
 
-      @resource.expects(:tagged?).never
+      expect(@resource).not_to receive(:tagged?)
 
       expect(@transaction).not_to be_missing_tags(@resource)
     end
 
     it "should not be missing tags if the transaction tags are empty" do
       @transaction.tags = []
-      @resource.expects(:tagged?).never
+      expect(@resource).not_to receive(:tagged?)
       expect(@transaction).not_to be_missing_tags(@resource)
     end
 
@@ -534,14 +532,14 @@ describe Puppet::Transaction do
 
     it "should always schedule resources if 'ignoreschedules' is set" do
       @transaction.ignoreschedules = true
-      @transaction.resource_harness.expects(:scheduled?).never
+      expect(@transaction.resource_harness).not_to receive(:scheduled?)
 
       @transaction.evaluate
       expect(@transaction.resource_status(@resource)).to be_changed
     end
 
     it "should let the resource harness determine whether the resource should be scheduled" do
-      @transaction.resource_harness.expects(:scheduled?).with(@resource).returns "feh"
+      expect(@transaction.resource_harness).to receive(:scheduled?).with(@resource).and_return("feh")
 
       @transaction.evaluate
     end
@@ -559,7 +557,7 @@ describe Puppet::Transaction do
     end
 
     it "should match resources by name, not title" do
-      resource.provider.class.expects(:prefetch).with("bar" => resource)
+      expect(resource.provider.class).to receive(:prefetch).with("bar" => resource)
 
       transaction.prefetch_if_necessary(resource)
     end
@@ -567,13 +565,13 @@ describe Puppet::Transaction do
     it "should not prefetch a provider which has already been prefetched" do
       transaction.prefetched_providers[:sshkey][:parsed] = true
 
-      resource.provider.class.expects(:prefetch).never
+      expect(resource.provider.class).not_to receive(:prefetch)
 
       transaction.prefetch_if_necessary(resource)
     end
 
     it "should mark the provider prefetched" do
-      resource.provider.class.stubs(:prefetch)
+      allow(resource.provider.class).to receive(:prefetch)
 
       transaction.prefetch_if_necessary(resource)
 
@@ -587,7 +585,7 @@ describe Puppet::Transaction do
 
       catalog.add_resource other
 
-      resource.provider.class.expects(:prefetch).with('bar' => resource, 'other' => other)
+      expect(resource.provider.class).to receive(:prefetch).with('bar' => resource, 'other' => other)
 
       transaction.prefetch_if_necessary(resource)
     end
@@ -595,14 +593,38 @@ describe Puppet::Transaction do
     it "should not prefetch a provider which has failed" do
       transaction.prefetch_failed_providers[:sshkey][:parsed] = true
 
-      resource.provider.class.expects(:prefetch).never
+      expect(resource.provider.class).not_to receive(:prefetch)
 
       transaction.prefetch_if_necessary(resource)
     end
 
+    it "should not rescue SystemExit without future_features flag" do
+      Puppet.settings[:future_features] = false
+      expect(resource.provider.class).to receive(:prefetch).and_raise(SystemExit, "SystemMessage")
+      expect { transaction.prefetch_if_necessary(resource) }.to raise_error(SystemExit, "SystemMessage")
+    end
+
+    it "should not rescue SystemExit with future_features flag" do
+      Puppet.settings[:future_features] = true
+      expect(resource.provider.class).to receive(:prefetch).and_raise(SystemExit, "SystemMessage")
+      expect { transaction.prefetch_if_necessary(resource) }.to raise_error(SystemExit, "SystemMessage")
+    end
+
+    it "should rescue LoadError without future_features flag" do
+      Puppet.settings[:future_features] = false
+      expect(resource.provider.class).to receive(:prefetch).and_raise(LoadError, "LoadMessage")
+      expect { transaction.prefetch_if_necessary(resource) }.not_to raise_error
+    end
+
+    it "should rescue LoadError with future_features flag" do
+      Puppet.settings[:future_features] = true
+      expect(resource.provider.class).to receive(:prefetch).and_raise(LoadError, "LoadMessage")
+      expect { transaction.prefetch_if_necessary(resource) }.not_to raise_error
+    end
+
     describe "and prefetching fails" do
       before :each do
-        resource.provider.class.expects(:prefetch).raises(Puppet::Error, "message")
+        expect(resource.provider.class).to receive(:prefetch).and_raise(Puppet::Error, "message")
       end
 
       context "without future_features flag" do
@@ -613,6 +635,11 @@ describe Puppet::Transaction do
         it "should not rescue prefetch executions" do
           expect { transaction.prefetch_if_necessary(resource) }.to raise_error(Puppet::Error)
         end
+
+        it "should log the exception during prefetch" do
+          expect(Puppet).to receive(:log_exception).with(anything, "Could not prefetch sshkey provider 'parsed': message")
+          expect { transaction.prefetch_if_necessary(resource) }.to raise_error(Puppet::Error, "message")
+        end
       end
 
       context "with future_features flag" do
@@ -646,14 +673,14 @@ describe Puppet::Transaction do
 
           before :each do
             catalog.add_resource generator
-            generator.stubs(:generate).returns generated
-            catalog.stubs(:container_of).returns generator
+            allow(generator).to receive(:generate).and_return(generated)
+            allow(catalog).to receive(:container_of).and_return(generator)
           end
 
           it "should not evaluate resources with a failed provider, even if the prefetch is rescued" do
             #Only the generator resource should be applied, all the other resources are failed, and skipped.
             catalog.remove_resource resource2
-            transaction.expects(:apply).once
+            expect(transaction).to receive(:apply).once
 
             transaction.evaluate
           end
@@ -672,7 +699,7 @@ describe Puppet::Transaction do
             catalog.add_resource(new_resource)
 
             catalog.remove_resource resource2
-            transaction.expects(:apply).once
+            expect(transaction).to receive(:apply).once
 
             transaction.evaluate
 
@@ -744,10 +771,28 @@ describe Puppet::Transaction do
 
     it "should call ::post_resource_eval even if one of the resources fails" do
       resource = teardown_type.new(:title => "foo", :provider => :teardown_provider)
-      resource.stubs(:retrieve_resource).raises
+      allow(resource).to receive(:retrieve_resource).and_raise
       catalog.add_resource resource
 
-      resource.provider.class.expects(:post_resource_eval)
+      expect(resource.provider.class).to receive(:post_resource_eval)
+
+      transaction.evaluate
+    end
+
+    it "should call Selinux.matchpathcon_fini in case Selinux is enabled ", :if => Puppet.features.posix? do
+      unless defined?(Selinux)
+        module Selinux
+          def self.is_selinux_enabled
+            true
+          end
+        end
+      end
+
+      resource = Puppet::Type.type(:file).new(:path => make_absolute("/tmp/foo"))
+      transaction = transaction_with_resource(resource)
+
+      expect(Selinux).to receive(:matchpathcon_fini)
+      expect(Puppet::Util::SELinux).to receive(:selinux_support?).and_return(true)
 
       transaction.evaluate
     end
@@ -761,7 +806,7 @@ describe Puppet::Transaction do
 
     context "when stop is requested" do
       before :each do
-        Puppet::Application.stubs(:stop_requested?).returns(true)
+        allow(Puppet::Application).to receive(:stop_requested?).and_return(true)
       end
 
       it 'should return true for :stop_processing?' do
@@ -775,7 +820,7 @@ describe Puppet::Transaction do
     end
 
     it 'should return false for :stop_processing? if Puppet::Application.stop_requested? is false' do
-      Puppet::Application.stubs(:stop_requested?).returns(false)
+      allow(Puppet::Application).to receive(:stop_requested?).and_return(false)
       expect(@transaction.stop_processing?).to be_falsey
     end
 
@@ -783,25 +828,25 @@ describe Puppet::Transaction do
       before do
         @resource = Puppet::Type.type(:notify).new :title => "foobar"
         @catalog.add_resource @resource
-        @transaction.stubs(:add_dynamically_generated_resources)
+        allow(@transaction).to receive(:add_dynamically_generated_resources)
       end
 
       it 'should stop processing if :stop_processing? is true' do
-        @transaction.stubs(:stop_processing?).returns(true)
-        @transaction.expects(:eval_resource).never
+        allow(@transaction).to receive(:stop_processing?).and_return(true)
+        expect(@transaction).not_to receive(:eval_resource)
         @transaction.evaluate
       end
 
       it 'should continue processing if :stop_processing? is false' do
-        @transaction.stubs(:stop_processing?).returns(false)
-        @transaction.expects(:eval_resource).returns(nil)
+        allow(@transaction).to receive(:stop_processing?).and_return(false)
+        expect(@transaction).to receive(:eval_resource).and_return(nil)
         @transaction.evaluate
       end
     end
   end
 
   it "errors with a dependency cycle for a resource that requires itself" do
-    Puppet.expects(:err).with(regexp_matches(/Found 1 dependency cycle:.*\(Notify\[cycle\] => Notify\[cycle\]\)/m))
+    expect(Puppet).to receive(:err).with(/Found 1 dependency cycle:.*\(Notify\[cycle\] => Notify\[cycle\]\)/m)
     expect do
       apply_compiled_manifest(<<-MANIFEST)
         notify { cycle: require => Notify[cycle] }
@@ -810,7 +855,7 @@ describe Puppet::Transaction do
   end
 
   it "errors with a dependency cycle for a self-requiring resource also required by another resource" do
-    Puppet.expects(:err).with(regexp_matches(/Found 1 dependency cycle:.*\(Notify\[cycle\] => Notify\[cycle\]\)/m))
+    expect(Puppet).to receive(:err).with(/Found 1 dependency cycle:.*\(Notify\[cycle\] => Notify\[cycle\]\)/m)
     expect do
       apply_compiled_manifest(<<-MANIFEST)
         notify { cycle: require => Notify[cycle] }
@@ -820,7 +865,7 @@ describe Puppet::Transaction do
   end
 
   it "errors with a dependency cycle for a resource that requires itself and another resource" do
-    Puppet.expects(:err).with(regexp_matches(/Found 1 dependency cycle:.*\(Notify\[cycle\] => Notify\[cycle\]\)/m))
+    expect(Puppet).to receive(:err).with(/Found 1 dependency cycle:.*\(Notify\[cycle\] => Notify\[cycle\]\)/m)
     expect do
       apply_compiled_manifest(<<-MANIFEST)
         notify { cycle:
@@ -832,7 +877,7 @@ describe Puppet::Transaction do
   end
 
   it "errors with a dependency cycle for a resource that is later modified to require itself" do
-    Puppet.expects(:err).with(regexp_matches(/Found 1 dependency cycle:.*\(Notify\[cycle\] => Notify\[cycle\]\)/m))
+    expect(Puppet).to receive(:err).with(/Found 1 dependency cycle:.*\(Notify\[cycle\] => Notify\[cycle\]\)/m)
     expect do
       apply_compiled_manifest(<<-MANIFEST)
         notify { cycle: }
@@ -901,15 +946,16 @@ describe Puppet::Transaction do
   describe "failed dependency is depended on multiple times" do
     it "notifies the failed dependency once" do
       command_string = File.expand_path('/my/command')
-      Puppet::Util::Execution.stubs(:execute).with([command_string]).raises(Puppet::ExecutionFailure, "Failed")
+      allow(Puppet::Util::Execution).to receive(:execute).with([command_string]).and_raise(Puppet::ExecutionFailure, "Failed")
 
-      Puppet::Type::Notify.any_instance.expects(:send_log).with(:notice, "Dependency Exec[exec1] has failures: true")
-      Puppet::Type::Notify.any_instance.expects(:send_log).with(:notice, "Dependency Exec[exec2] has failures: true")
-      Puppet::Type::Notify.any_instance.expects(:send_log).with(:notice, "Dependency Exec[exec3] has failures: true")
-      Puppet::Type::Notify.any_instance.expects(:send_log).with(:notice, "Dependency Exec[exec4] has failures: true")
-      Puppet::Type::Notify.any_instance.expects(:send_log).with(:notice, "Dependency Exec[exec5] has failures: true")
+      allow_any_instance_of(Puppet::Type::Notify).to receive(:send_log).with(:notice, "Dependency Exec[exec1] has failures: true")
+      allow_any_instance_of(Puppet::Type::Notify).to receive(:send_log).with(:notice, "Dependency Exec[exec2] has failures: true")
+      allow_any_instance_of(Puppet::Type::Notify).to receive(:send_log).with(:notice, "Dependency Exec[exec3] has failures: true")
+      allow_any_instance_of(Puppet::Type::Notify).to receive(:send_log).with(:notice, "Dependency Exec[exec4] has failures: true")
+      allow_any_instance_of(Puppet::Type::Notify).to receive(:send_log).with(:notice, "Dependency Exec[exec5] has failures: true")
 
-      Puppet::Type::Notify.any_instance.expects(:send_log).with(:warning, "Skipping because of failed dependencies").times(3)
+      times_send_log_with_skipping_called = 0
+      allow_any_instance_of(Puppet::Type::Notify).to receive(:send_log) {times_send_log_with_skipping_called += 1; nil}.with(:warning, "Skipping because of failed dependencies")
 
       apply_compiled_manifest(<<-MANIFEST)
         exec { ['exec1', 'exec2', 'exec3', 'exec4', 'exec5']:
@@ -917,10 +963,9 @@ describe Puppet::Transaction do
         } ->
         notify { ['notify1', 'notify2', 'notify3']: }
       MANIFEST
-
+      expect(times_send_log_with_skipping_called).to eq(3)
     end
   end
-
 end
 
 describe Puppet::Transaction, " when determining tags" do
