@@ -1,5 +1,3 @@
-#! /usr/bin/env ruby
-
 require 'spec_helper'
 
 describe Puppet::Type.type(:file).attrclass(:group) do
@@ -19,12 +17,12 @@ describe Puppet::Type.type(:file).attrclass(:group) do
     before :each do
       resource[:group] = ['foos', 'bars']
 
-      resource.provider.stubs(:name2gid).with('foos').returns 1001
-      resource.provider.stubs(:name2gid).with('bars').returns 1002
+      allow(resource.provider).to receive(:name2gid).with('foos').and_return(1001)
+      allow(resource.provider).to receive(:name2gid).with('bars').and_return(1002)
     end
 
     it "should fail if a group's id can't be found by name" do
-      resource.provider.stubs(:name2gid).returns nil
+      allow(resource.provider).to receive(:name2gid).and_return(nil)
 
       expect { group.insync?(5) }.to raise_error(/Could not find group foos/)
     end
@@ -45,13 +43,13 @@ describe Puppet::Type.type(:file).attrclass(:group) do
   %w[is_to_s should_to_s].each do |prop_to_s|
     describe "##{prop_to_s}" do
       it "should use the name of the user if it can find it" do
-        resource.provider.stubs(:gid2name).with(1001).returns 'foos'
+        allow(resource.provider).to receive(:gid2name).with(1001).and_return('foos')
 
         expect(group.send(prop_to_s, 1001)).to eq("'foos'")
       end
 
       it "should use the id of the user if it can't" do
-        resource.provider.stubs(:gid2name).with(1001).returns nil
+        allow(resource.provider).to receive(:gid2name).with(1001).and_return(nil)
 
         expect(group.send(prop_to_s, 1001)).to eq('1001')
       end
