@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 describe Puppet::Type.type(:interface) do
@@ -27,8 +26,8 @@ describe Puppet::Type.type(:interface) do
 
   describe "when validating attribute values" do
     before do
-      @provider = stub 'provider', :class => Puppet::Type.type(:interface).defaultprovider, :clear => nil
-      Puppet::Type.type(:interface).defaultprovider.stubs(:new).returns(@provider)
+      @provider = double('provider', :class => Puppet::Type.type(:interface).defaultprovider, :clear => nil)
+      allow(Puppet::Type.type(:interface).defaultprovider).to receive(:new).and_return(@provider)
     end
 
     it "should support :present as a value to :ensure" do
