@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 require 'puppet/type/mcx'
@@ -6,7 +5,6 @@ require 'puppet/type/mcx'
 mcx_type = Puppet::Type.type(:mcx)
 
 describe mcx_type, "when validating attributes" do
-
   properties = [:ensure, :content]
   parameters = [:name, :ds_type, :ds_name]
 
@@ -14,6 +12,7 @@ describe mcx_type, "when validating attributes" do
     it "should have a #{p} parameter" do
       expect(mcx_type.attrclass(p).ancestors).to be_include(Puppet::Parameter)
     end
+
     it "should have documentation for its #{p} parameter" do
       expect(mcx_type.attrclass(p).doc).to be_instance_of(String)
     end
@@ -23,6 +22,7 @@ describe mcx_type, "when validating attributes" do
     it "should have a #{p} property" do
       expect(mcx_type.attrclass(p).ancestors).to be_include(Puppet::Property)
     end
+
     it "should have documentation for its #{p} property" do
       expect(mcx_type.attrclass(p).doc).to be_instance_of(String)
     end
@@ -31,10 +31,9 @@ describe mcx_type, "when validating attributes" do
 end
 
 describe mcx_type, "default values" do
-
   before :each do
     provider_class = mcx_type.provider(mcx_type.providers[0])
-    mcx_type.stubs(:defaultprovider).returns provider_class
+    allow(mcx_type).to receive(:defaultprovider).and_return(provider_class)
   end
 
   it "should be nil for :ds_type" do
@@ -48,14 +47,12 @@ describe mcx_type, "default values" do
   it "should be nil for :content" do
     expect(mcx_type.new(:name => '/Foo/bar')[:content]).to be_nil
   end
-
 end
 
 describe mcx_type, "when validating properties" do
-
   before :each do
     provider_class = mcx_type.provider(mcx_type.providers[0])
-    mcx_type.stubs(:defaultprovider).returns provider_class
+    allow(mcx_type).to receive(:defaultprovider).and_return(provider_class)
   end
 
   it "should be able to create an instance" do
@@ -75,5 +72,4 @@ describe mcx_type, "when validating properties" do
       mcx_type.new(:name => "/Foo/bar", :ensure => :absent)
     }.not_to raise_error
   end
-
 end
