@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 require 'puppet/util/backups'
@@ -6,10 +5,10 @@ require 'puppet/util/backups'
 describe Puppet::Util::Backups do
   include PuppetSpec::Files
 
-  let(:bucket) { stub('bucket', :name => "foo") }
+  let(:bucket) { double('bucket', :name => "foo") }
   let!(:file) do
     f = Puppet::Type.type(:file).new(:name => path, :backup => 'foo')
-    f.stubs(:bucket).returns(bucket)
+    allow(f).to receive(:bucket).and_return(bucket)
     f
   end
 
@@ -19,8 +18,8 @@ describe Puppet::Util::Backups do
     it "should noop if the file does not exist" do
       file = Puppet::Type.type(:file).new(:name => path)
 
-      file.expects(:bucket).never
-      Puppet::FileSystem.expects(:exist?).with(path).returns false
+      expect(file).not_to receive(:bucket)
+      expect(Puppet::FileSystem).to receive(:exist?).with(path).and_return(false)
 
       file.perform_backup
     end
@@ -28,24 +27,24 @@ describe Puppet::Util::Backups do
     it "should succeed silently if self[:backup] is false" do
       file = Puppet::Type.type(:file).new(:name => path, :backup => false)
 
-      file.expects(:bucket).never
-      Puppet::FileSystem.expects(:exist?).never
+      expect(file).not_to receive(:bucket)
+      expect(Puppet::FileSystem).not_to receive(:exist?)
 
       file.perform_backup
     end
 
     it "a bucket should be used when provided" do
       lstat_path_as(path, 'file')
-      bucket.expects(:backup).with(path).returns("mysum")
-      Puppet::FileSystem.expects(:exist?).with(path).returns(true)
+      expect(bucket).to receive(:backup).with(path).and_return("mysum")
+      expect(Puppet::FileSystem).to receive(:exist?).with(path).and_return(true)
 
       file.perform_backup
     end
 
     it "should propagate any exceptions encountered when backing up to a filebucket" do
       lstat_path_as(path, 'file')
-      bucket.expects(:backup).raises ArgumentError
-      Puppet::FileSystem.expects(:exist?).with(path).returns(true)
+      expect(bucket).to receive(:backup).and_raise(ArgumentError)
+      expect(Puppet::FileSystem).to receive(:exist?).with(path).and_return(true)
 
       expect { file.perform_backup }.to raise_error(ArgumentError)
     end
@@ -57,42 +56,42 @@ describe Puppet::Util::Backups do
 
       it "should remove any local backup if one exists" do
         lstat_path_as(backup, 'file')
-        Puppet::FileSystem.expects(:unlink).with(backup)
-        FileUtils.stubs(:cp_r)
-        Puppet::FileSystem.expects(:exist?).with(path).returns(true)
+        expect(Puppet::FileSystem).to receive(:unlink).with(backup)
+        allow(FileUtils).to receive(:cp_r)
+        expect(Puppet::FileSystem).to receive(:exist?).with(path).and_return(true)
 
         file.perform_backup
       end
 
       it "should fail when the old backup can't be removed" do
         lstat_path_as(backup, 'file')
-        Puppet::FileSystem.expects(:unlink).with(backup).raises ArgumentError
-        FileUtils.expects(:cp_r).never
-        Puppet::FileSystem.expects(:exist?).with(path).returns(true)
+        expect(Puppet::FileSystem).to receive(:unlink).with(backup).and_raise(ArgumentError)
+        expect(FileUtils).not_to receive(:cp_r)
+        expect(Puppet::FileSystem).to receive(:exist?).with(path).and_return(true)
 
         expect { file.perform_backup }.to raise_error(Puppet::Error)
       end
 
       it "should not try to remove backups that don't exist" do
-        Puppet::FileSystem.expects(:lstat).with(backup).raises(Errno::ENOENT)
-        Puppet::FileSystem.expects(:unlink).with(backup).never
-        FileUtils.stubs(:cp_r)
-        Puppet::FileSystem.expects(:exist?).with(path).returns(true)
+        expect(Puppet::FileSystem).to receive(:lstat).with(backup).and_raise(Errno::ENOENT)
+        expect(Puppet::FileSystem).not_to receive(:unlink).with(backup)
+        allow(FileUtils).to receive(:cp_r)
+        expect(Puppet::FileSystem).to receive(:exist?).with(path).and_return(true)
 
         file.perform_backup
       end
 
       it "a copy should be created in the local directory" do
-        FileUtils.expects(:cp_r).with(path, backup, :preserve => true)
-        Puppet::FileSystem.stubs(:exist?).with(path).returns(true)
+        expect(FileUtils).to receive(:cp_r).with(path, backup, :preserve => true)
+        allow(Puppet::FileSystem).to receive(:exist?).with(path).and_return(true)
 
         expect(file.perform_backup).to be_truthy
       end
 
       it "should propagate exceptions if no backup can be created" do
-        FileUtils.expects(:cp_r).raises ArgumentError
+        expect(FileUtils).to receive(:cp_r).and_raise(ArgumentError)
 
-        Puppet::FileSystem.stubs(:exist?).with(path).returns(true)
+        allow(Puppet::FileSystem).to receive(:exist?).with(path).and_return(true)
         expect { file.perform_backup }.to raise_error(Puppet::Error)
       end
     end
@@ -103,15 +102,15 @@ describe Puppet::Util::Backups do
     let(:filename) { File.join(path, 'file') }
 
     it "a bucket should work when provided" do
-      File.stubs(:file?).with(filename).returns true
-      Find.expects(:find).with(path).yields(filename)
+      allow(File).to receive(:file?).with(filename).and_return(true)
+      expect(Find).to receive(:find).with(path).and_yield(filename)
 
-      bucket.expects(:backup).with(filename).returns true
+      expect(bucket).to receive(:backup).with(filename).and_return(true)
 
       lstat_path_as(path, 'directory')
 
-      Puppet::FileSystem.stubs(:exist?).with(path).returns(true)
-      Puppet::FileSystem.stubs(:exist?).with(filename).returns(true)
+      allow(Puppet::FileSystem).to receive(:exist?).with(path).and_return(true)
+      allow(Puppet::FileSystem).to receive(:exist?).with(filename).and_return(true)
 
       file.perform_backup
     end
@@ -119,16 +118,16 @@ describe Puppet::Util::Backups do
     it "should do nothing when recursing" do
       file = Puppet::Type.type(:file).new(:name => path, :backup => 'foo', :recurse => true)
 
-      bucket.expects(:backup).never
-      stub_file = stub('file', :stat => stub('stat', :ftype => 'directory'))
-      Puppet::FileSystem.stubs(:new).with(path).returns stub_file
-      Find.expects(:find).never
+      expect(bucket).not_to receive(:backup)
+      stub_file = double('file', :stat => double('stat', :ftype => 'directory'))
+      allow(Puppet::FileSystem).to receive(:new).with(path).and_return(stub_file)
+      expect(Find).not_to receive(:find)
 
       file.perform_backup
     end
   end
 
   def lstat_path_as(path, ftype)
-    Puppet::FileSystem.expects(:lstat).with(path).returns(stub('File::Stat', :ftype => ftype))
+    expect(Puppet::FileSystem).to receive(:lstat).with(path).and_return(double('File::Stat', :ftype => ftype))
   end
 end
