@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 require 'puppet/face'
@@ -67,16 +66,37 @@ describe Puppet::Util::CommandLine do
       end
     end
 
-    %w{--help -h}.each do|arg|
-      it "should print help" do
+    %w{--help -h help}.each do|arg|
+      it "should print help and exit if #{arg} is given" do
         commandline = Puppet::Util::CommandLine.new("puppet", [arg])
-        commandline.expects(:exec).never
+        expect(commandline).not_to receive(:exec)
 
         expect {
           commandline.execute
         }.to have_printed(/Usage: puppet <subcommand> \[options\] <action> \[options\]/).and_exit_with(0)
       end
     end
+
+    it "should fail if the config file isn't readable and we're running a subcommand that requires a readable config file" do
+      allow(Puppet::FileSystem).to receive(:exist?).with(Puppet[:config]).and_return(true)
+      allow_any_instance_of(Puppet::Settings).to receive(:read_file).and_return('')
+      expect_any_instance_of(Puppet::Settings).to receive(:read_file).with(Puppet[:config]).and_raise('Permission denied')
+
+      expect{ described_class.new("puppet", ['config']).execute }.to raise_error(SystemExit)
+    end
+
+    it "should not fail if the config file isn't readable and we're running a subcommand that does not require a readable config file" do
+      allow(Puppet::FileSystem).to receive(:exist?)
+      allow(Puppet::FileSystem).to receive(:exist?).with(Puppet[:config]).and_return(true)
+      allow_any_instance_of(Puppet::Settings).to receive(:read_file).and_return('')
+      expect_any_instance_of(Puppet::Settings).to receive(:read_file).with(Puppet[:config]).and_raise('Permission denied')
+
+      commandline = described_class.new("puppet", ['help'])
+
+      expect {
+        commandline.execute
+      }.to have_printed(/Usage: puppet <subcommand> \[options\] <action> \[options\]/).and_exit_with(0)
+    end
   end
 
   describe "when dealing with puppet commands" do
@@ -88,19 +108,19 @@ describe Puppet::Util::CommandLine do
     describe "when the subcommand is not implemented" do
       it "should find and invoke an executable with a hyphenated name" do
         commandline = Puppet::Util::CommandLine.new("puppet", ['whatever', 'argument'])
-        Puppet::Util.expects(:which).with('puppet-whatever').
-          returns('/dev/null/puppet-whatever')
+        expect(Puppet::Util).to receive(:which).with('puppet-whatever').
+          and_return('/dev/null/puppet-whatever')
 
-        Kernel.expects(:exec).with('/dev/null/puppet-whatever', 'argument')
+        expect(Kernel).to receive(:exec).with('/dev/null/puppet-whatever', 'argument')
 
         commandline.execute
       end
 
       describe "and an external implementation cannot be found" do
         it "should abort and show the usage message" do
-          Puppet::Util.expects(:which).with('puppet-whatever').returns(nil)
+          expect(Puppet::Util).to receive(:which).with('puppet-whatever').and_return(nil)
           commandline = Puppet::Util::CommandLine.new("puppet", ['whatever', 'argument'])
-          commandline.expects(:exec).never
+          expect(commandline).not_to receive(:exec)
 
           expect {
             commandline.execute
@@ -108,9 +128,9 @@ describe Puppet::Util::CommandLine do
         end
 
         it "should abort and show the help message" do
-          Puppet::Util.expects(:which).with('puppet-whatever').returns(nil)
+          expect(Puppet::Util).to receive(:which).with('puppet-whatever').and_return(nil)
           commandline = Puppet::Util::CommandLine.new("puppet", ['whatever', 'argument'])
-          commandline.expects(:exec).never
+          expect(commandline).not_to receive(:exec)
 
           expect {
             commandline.execute
@@ -119,9 +139,9 @@ describe Puppet::Util::CommandLine do
 
         %w{--version -V}.each do |arg|
           it "should abort and display #{arg} information" do
-            Puppet::Util.expects(:which).with('puppet-whatever').returns(nil)
+            expect(Puppet::Util).to receive(:which).with('puppet-whatever').and_return(nil)
             commandline = Puppet::Util::CommandLine.new("puppet", ['whatever', arg])
-            commandline.expects(:exec).never
+            expect(commandline).not_to receive(:exec)
 
             expect {
               commandline.execute
@@ -137,11 +157,11 @@ describe Puppet::Util::CommandLine do
       end
 
       before :each do
-        Puppet::Util::CommandLine::ApplicationSubcommand.any_instance.stubs(:run)
+        allow_any_instance_of(Puppet::Util::CommandLine::ApplicationSubcommand).to receive(:run)
       end
 
       it 'should never set priority by default' do
-        Process.expects(:setpriority).never
+        expect(Process).not_to receive(:setpriority)
 
         command_line.execute
       end
@@ -149,15 +169,15 @@ describe Puppet::Util::CommandLine do
       it 'should lower the process priority if one has been specified' do
         Puppet[:priority] = 10
 
-        Process.expects(:setpriority).with(0, Process.pid, 10)
+        expect(Process).to receive(:setpriority).with(0, Process.pid, 10)
         command_line.execute
       end
 
       it 'should warn if trying to raise priority, but not privileged user' do
         Puppet[:priority] = -10
 
-        Process.expects(:setpriority).raises(Errno::EACCES, 'Permission denied')
-        Puppet.expects(:warning).with("Failed to set process priority to '-10'")
+        expect(Process).to receive(:setpriority).and_raise(Errno::EACCES, 'Permission denied')
+        expect(Puppet).to receive(:warning).with("Failed to set process priority to '-10'")
 
         command_line.execute
       end
@@ -165,8 +185,8 @@ describe Puppet::Util::CommandLine do
       it "should warn if the platform doesn't support `Process.setpriority`" do
         Puppet[:priority] = 15
 
-        Process.expects(:setpriority).raises(NotImplementedError, 'NotImplementedError: setpriority() function is unimplemented on this machine')
-        Puppet.expects(:warning).with("Failed to set process priority to '15'")
+        expect(Process).to receive(:setpriority).and_raise(NotImplementedError, 'NotImplementedError: setpriority() function is unimplemented on this machine')
+        expect(Puppet).to receive(:warning).with("Failed to set process priority to '15'")
 
         command_line.execute
       end
