@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 require 'puppet/util/ldap/manager'
@@ -61,13 +60,13 @@ describe Puppet::Util::Ldap::Manager do
 
   describe "when generating attributes" do
     before do
-      @generator = stub 'generator', :source => "one", :name => "myparam"
+      @generator = double('generator', :source => "one", :name => "myparam")
 
-      Puppet::Util::Ldap::Generator.stubs(:new).with(:myparam).returns @generator
+      allow(Puppet::Util::Ldap::Generator).to receive(:new).with(:myparam).and_return(@generator)
     end
 
     it "should create a generator to do the parameter generation" do
-      Puppet::Util::Ldap::Generator.expects(:new).with(:myparam).returns @generator
+      expect(Puppet::Util::Ldap::Generator).to receive(:new).with(:myparam).and_return(@generator)
       @manager.generates(:myparam)
     end
 
@@ -79,7 +78,7 @@ describe Puppet::Util::Ldap::Manager do
       @manager.generates(:myparam)
 
       attrs = {"myparam" => "testing"}
-      @generator.expects(:generate).never
+      expect(@generator).not_to receive(:generate)
 
       @manager.generate attrs
 
@@ -88,7 +87,7 @@ describe Puppet::Util::Ldap::Manager do
 
     it "should look for the parameter as a string, not a symbol" do
       @manager.generates(:myparam)
-      @generator.expects(:generate).with("yay").returns %w{double yay}
+      expect(@generator).to receive(:generate).with("yay").and_return(%w{double yay})
       attrs = {"one" => "yay"}
       @manager.generate attrs
 
@@ -102,19 +101,19 @@ describe Puppet::Util::Ldap::Manager do
 
     it "should use the source value to generate the new value if a source attribute is specified" do
       @manager.generates(:myparam)
-      @generator.expects(:generate).with("yay").returns %w{double yay}
+      expect(@generator).to receive(:generate).with("yay").and_return(%w{double yay})
       @manager.generate "one" => "yay"
     end
 
     it "should not pass in any value if no source attribute is specified" do
-      @generator.stubs(:source).returns nil
+      allow(@generator).to receive(:source).and_return(nil)
       @manager.generates(:myparam)
-      @generator.expects(:generate).with.returns %w{double yay}
+      expect(@generator).to receive(:generate).and_return(%w{double yay})
       @manager.generate "one" => "yay"
     end
 
     it "should convert any results to arrays of strings if necessary" do
-      @generator.expects(:generate).returns :test
+      expect(@generator).to receive(:generate).and_return(:test)
       @manager.generates(:myparam)
 
       attrs = {"one" => "two"}
@@ -123,7 +122,7 @@ describe Puppet::Util::Ldap::Manager do
     end
 
     it "should add the result to the passed-in attribute hash" do
-      @generator.expects(:generate).returns %w{test}
+      expect(@generator).to receive(:generate).and_return(%w{test})
       @manager.generates(:myparam)
 
       attrs = {"one" => "two"}
@@ -244,9 +243,9 @@ describe Puppet::Util::Ldap::Manager do
 
   describe "when using an ldap connection" do
     before do
-      @ldapconn = mock 'ldapconn'
-      @conn = stub 'connection', :connection => @ldapconn, :start => nil, :close => nil
-      Puppet::Util::Ldap::Connection.stubs(:new).returns(@conn)
+      @ldapconn = double('ldapconn')
+      @conn = double('connection', :connection => @ldapconn, :start => nil, :close => nil)
+      allow(Puppet::Util::Ldap::Connection).to receive(:new).and_return(@conn)
     end
 
     it "should fail unless a block is given" do
@@ -255,144 +254,148 @@ describe Puppet::Util::Ldap::Manager do
 
     it "should open the connection with its server set to :ldapserver" do
       Puppet[:ldapserver] = "myserver"
-      Puppet::Util::Ldap::Connection.expects(:new).with { |*args| args[0] == "myserver" }.returns @conn
+      expect(Puppet::Util::Ldap::Connection).to receive(:new).with("myserver", anything, anything).and_return(@conn)
 
       @manager.connect { |c| }
     end
 
     it "should open the connection with its port set to the :ldapport" do
       Puppet[:ldapport] = "28"
-      Puppet::Util::Ldap::Connection.expects(:new).with { |*args| args[1] == "28" }.returns @conn
+      expect(Puppet::Util::Ldap::Connection).to receive(:new).with(anything, "28", anything).and_return(@conn)
 
       @manager.connect { |c| }
     end
 
     it "should open the connection with no user if :ldapuser is not set" do
       Puppet[:ldapuser] = ""
-      Puppet::Util::Ldap::Connection.expects(:new).with { |*args| args[2][:user].nil? }.returns @conn
+      expect(Puppet::Util::Ldap::Connection).to receive(:new).with(anything, anything, hash_excluding(:user)).and_return(@conn)
 
       @manager.connect { |c| }
     end
 
     it "should open the connection with its user set to the :ldapuser if it is set" do
       Puppet[:ldapuser] = "mypass"
-      Puppet::Util::Ldap::Connection.expects(:new).with { |*args| args[2][:user] == "mypass" }.returns @conn
+      expect(Puppet::Util::Ldap::Connection).to receive(:new).with(anything, anything, hash_including(user: "mypass")).and_return(@conn)
 
       @manager.connect { |c| }
     end
 
     it "should open the connection with no password if :ldappassword is not set" do
       Puppet[:ldappassword] = ""
-      Puppet::Util::Ldap::Connection.expects(:new).with { |*args| args[2][:password].nil? }.returns @conn
+      expect(Puppet::Util::Ldap::Connection).to receive(:new).with(anything, anything, hash_excluding(:password)).and_return(@conn)
 
       @manager.connect { |c| }
     end
 
     it "should open the connection with its password set to the :ldappassword if it is set" do
       Puppet[:ldappassword] = "mypass"
-      Puppet::Util::Ldap::Connection.expects(:new).with { |*args| args[2][:password] == "mypass" }.returns @conn
+      expect(Puppet::Util::Ldap::Connection).to receive(:new).with(anything, anything, hash_including(password: "mypass")).and_return(@conn)
 
       @manager.connect { |c| }
     end
 
     it "should set ssl to :tls if ldaptls is enabled" do
       Puppet[:ldaptls] = true
-      Puppet::Util::Ldap::Connection.expects(:new).with { |*args| args[2][:ssl] == :tls }.returns @conn
+      expect(Puppet::Util::Ldap::Connection).to receive(:new).with(anything, anything, hash_including(ssl: :tls)).and_return(@conn)
 
       @manager.connect { |c| }
     end
 
     it "should set ssl to true if ldapssl is enabled" do
       Puppet[:ldapssl] = true
-      Puppet::Util::Ldap::Connection.expects(:new).with { |*args| args[2][:ssl] == true }.returns @conn
+      expect(Puppet::Util::Ldap::Connection).to receive(:new).with(anything, anything, hash_including(ssl: true)).and_return(@conn)
 
       @manager.connect { |c| }
     end
 
     it "should set ssl to false if neither ldaptls nor ldapssl is enabled" do
       Puppet[:ldapssl] = false
-      Puppet::Util::Ldap::Connection.expects(:new).with { |*args| args[2][:ssl] == false }.returns @conn
+      expect(Puppet::Util::Ldap::Connection).to receive(:new).with(anything, anything, hash_including(ssl: false)).and_return(@conn)
 
       @manager.connect { |c| }
     end
 
     it "should open, yield, and then close the connection" do
-      @conn.expects(:start)
-      @conn.expects(:close)
-      Puppet::Util::Ldap::Connection.expects(:new).returns(@conn)
-      @ldapconn.expects(:test)
+      expect(@conn).to receive(:start)
+      expect(@conn).to receive(:close)
+      expect(Puppet::Util::Ldap::Connection).to receive(:new).and_return(@conn)
+      expect(@ldapconn).to receive(:test)
       @manager.connect { |c| c.test }
     end
 
     it "should close the connection even if there's an exception in the passed block" do
-      @conn.expects(:close)
+      expect(@conn).to receive(:close)
       expect { @manager.connect { |c| raise ArgumentError } }.to raise_error(ArgumentError)
     end
   end
 
   describe "when using ldap" do
     before do
-      @conn = mock 'connection'
-      @manager.stubs(:connect).yields @conn
-      @manager.stubs(:objectclasses).returns [:oc1, :oc2]
+      @conn = double('connection')
+      allow(@manager).to receive(:connect).and_yield(@conn)
+      allow(@manager).to receive(:objectclasses).and_return([:oc1, :oc2])
       @manager.maps :one => :uno, :two => :dos, :three => :tres, :four => :quatro
     end
 
     describe "to create entries" do
       it "should convert the first argument to its :create method to a full dn and pass the resulting argument list to its connection" do
-        @manager.expects(:dn).with("myname").returns "mydn"
-        @conn.expects(:add).with { |name, attrs| name == "mydn" }
+        expect(@manager).to receive(:dn).with("myname").and_return("mydn")
+        expect(@conn).to receive(:add).with("mydn", anything)
 
         @manager.create("myname", {"attr" => "myattrs"})
       end
 
       it "should add the objectclasses to the attributes" do
-        @manager.expects(:dn).with("myname").returns "mydn"
-        @conn.expects(:add).with { |name, attrs| attrs["objectClass"].include?("oc1") and attrs["objectClass"].include?("oc2") }
+        expect(@manager).to receive(:dn).with("myname").and_return("mydn")
+        expect(@conn).to receive(:add) do |_, attrs|
+          expect(attrs["objectClass"]).to include("oc1", "oc2")
+        end
 
         @manager.create("myname", {:one => :testing})
       end
 
       it "should add the rdn to the attributes" do
-        @manager.expects(:dn).with("myname").returns "mydn"
-        @conn.expects(:add).with { |name, attrs| attrs["cn"] == %w{myname} }
+        expect(@manager).to receive(:dn).with("myname").and_return("mydn")
+        expect(@conn).to receive(:add).with(anything, hash_including("cn" => %w{myname}))
 
         @manager.create("myname", {:one => :testing})
       end
 
       it "should add 'top' to the objectclasses if it is not listed" do
-        @manager.expects(:dn).with("myname").returns "mydn"
-        @conn.expects(:add).with { |name, attrs| attrs["objectClass"].include?("top") }
+        expect(@manager).to receive(:dn).with("myname").and_return("mydn")
+        expect(@conn).to receive(:add) do |_, attrs|
+          expect(attrs["objectClass"]).to include("top")
+        end
 
         @manager.create("myname", {:one => :testing})
       end
 
       it "should add any generated values that are defined" do
-        generator = stub 'generator', :source => :one, :name => "myparam"
+        generator = double('generator', :source => :one, :name => "myparam")
 
-        Puppet::Util::Ldap::Generator.expects(:new).with(:myparam).returns generator
+        expect(Puppet::Util::Ldap::Generator).to receive(:new).with(:myparam).and_return(generator)
 
         @manager.generates(:myparam)
 
-        @manager.stubs(:dn).with("myname").returns "mydn"
+        allow(@manager).to receive(:dn).with("myname").and_return("mydn")
 
-        generator.expects(:generate).with(:testing).returns ["generated value"]
-        @conn.expects(:add).with { |name, attrs| attrs["myparam"] == ["generated value"] }
+        expect(generator).to receive(:generate).with(:testing).and_return(["generated value"])
+        expect(@conn).to receive(:add).with(anything, hash_including("myparam" => ["generated value"]))
 
         @manager.create("myname", {:one => :testing})
       end
 
       it "should convert any generated values to arrays of strings if necessary" do
-        generator = stub 'generator', :source => :one, :name => "myparam"
+        generator = double('generator', :source => :one, :name => "myparam")
 
-        Puppet::Util::Ldap::Generator.expects(:new).with(:myparam).returns generator
+        expect(Puppet::Util::Ldap::Generator).to receive(:new).with(:myparam).and_return(generator)
 
         @manager.generates(:myparam)
 
-        @manager.stubs(:dn).returns "mydn"
+        allow(@manager).to receive(:dn).and_return("mydn")
 
-        generator.expects(:generate).returns :generated
-        @conn.expects(:add).with { |name, attrs| attrs["myparam"] == ["generated"] }
+        expect(generator).to receive(:generate).and_return(:generated)
+        expect(@conn).to receive(:add).with(anything, hash_including("myparam" => ["generated"]))
 
         @manager.create("myname", {:one => :testing})
       end
@@ -400,8 +403,8 @@ describe Puppet::Util::Ldap::Manager do
 
     describe "do delete entries" do
       it "should convert the first argument to its :delete method to a full dn and pass the resulting argument list to its connection" do
-        @manager.expects(:dn).with("myname").returns "mydn"
-        @conn.expects(:delete).with("mydn")
+        expect(@manager).to receive(:dn).with("myname").and_return("mydn")
+        expect(@conn).to receive(:delete).with("mydn")
 
         @manager.delete("myname")
       end
@@ -409,8 +412,8 @@ describe Puppet::Util::Ldap::Manager do
 
     describe "to modify entries" do
       it "should convert the first argument to its :modify method to a full dn and pass the resulting argument list to its connection" do
-        @manager.expects(:dn).with("myname").returns "mydn"
-        @conn.expects(:modify).with("mydn", :mymods)
+        expect(@manager).to receive(:dn).with("myname").and_return("mydn")
+        expect(@conn).to receive(:modify).with("mydn", :mymods)
 
         @manager.modify("myname", :mymods)
       end
@@ -418,25 +421,25 @@ describe Puppet::Util::Ldap::Manager do
 
     describe "to find a single entry" do
       it "should use the dn of the provided name as the search base, a scope of 0, and 'objectclass=*' as the filter for a search2 call" do
-        @manager.expects(:dn).with("myname").returns "mydn"
-        @conn.expects(:search2).with("mydn", 0, "objectclass=*")
+        expect(@manager).to receive(:dn).with("myname").and_return("mydn")
+        expect(@conn).to receive(:search2).with("mydn", 0, "objectclass=*")
 
         @manager.find("myname")
       end
 
       it "should return nil if an exception is thrown because no result is found" do
-        @manager.expects(:dn).with("myname").returns "mydn"
-        @conn.expects(:search2).raises LDAP::ResultError
+        expect(@manager).to receive(:dn).with("myname").and_return("mydn")
+        expect(@conn).to receive(:search2).and_raise(LDAP::ResultError)
 
         expect(@manager.find("myname")).to be_nil
       end
 
       it "should return a converted provider hash if the result is found" do
-        @manager.expects(:dn).with("myname").returns "mydn"
+        expect(@manager).to receive(:dn).with("myname").and_return("mydn")
         result = {"one" => "two"}
-        @conn.expects(:search2).yields result
+        expect(@conn).to receive(:search2).and_yield(result)
 
-        @manager.expects(:entry2provider).with(result).returns "myprovider"
+        expect(@manager).to receive(:entry2provider).with(result).and_return("myprovider")
 
         expect(@manager.find("myname")).to eq("myprovider")
       end
@@ -444,38 +447,38 @@ describe Puppet::Util::Ldap::Manager do
 
     describe "to search for multiple entries" do
       before do
-        @manager.stubs(:filter).returns "myfilter"
+        allow(@manager).to receive(:filter).and_return("myfilter")
       end
 
       it "should use the manager's search base as the dn of the provided name as the search base" do
-        @manager.expects(:base).returns "mybase"
-        @conn.expects(:search2).with { |base, scope, filter| base == "mybase" }
+        expect(@manager).to receive(:base).and_return("mybase")
+        expect(@conn).to receive(:search2).with("mybase", anything, anything)
 
         @manager.search
       end
 
       it "should use a scope of 1" do
-        @conn.expects(:search2).with { |base, scope, filter| scope == 1 }
+        expect(@conn).to receive(:search2).with(anything, 1, anything)
 
         @manager.search
       end
 
       it "should use any specified search filter" do
-        @manager.expects(:filter).never
-        @conn.expects(:search2).with { |base, scope, filter| filter == "boo" }
+        expect(@manager).not_to receive(:filter)
+        expect(@conn).to receive(:search2).with(anything, anything, "boo")
 
         @manager.search("boo")
       end
 
       it "should turn its objectclass list into its search filter if one is not specified" do
-        @manager.expects(:filter).returns "yay"
-        @conn.expects(:search2).with { |base, scope, filter| filter == "yay" }
+        expect(@manager).to receive(:filter).and_return("yay")
+        expect(@conn).to receive(:search2).with(anything, anything, "yay")
 
         @manager.search
       end
 
       it "should return nil if no result is found" do
-        @conn.expects(:search2)
+        expect(@conn).to receive(:search2)
 
         expect(@manager.search).to be_nil
       end
@@ -483,9 +486,9 @@ describe Puppet::Util::Ldap::Manager do
       it "should return an array of the found results converted to provider hashes" do
         # LAK: AFAICT, it's impossible to yield multiple times in an expectation.
         one = {"dn" => "cn=one,dc=madstop,dc=com", "one" => "two"}
-        @conn.expects(:search2).yields(one)
+        expect(@conn).to receive(:search2).and_yield(one)
 
-        @manager.expects(:entry2provider).with(one).returns "myprov"
+        expect(@manager).to receive(:entry2provider).with(one).and_return("myprov")
 
         expect(@manager.search).to eq(["myprov"])
       end
@@ -500,29 +503,29 @@ describe Puppet::Util::Ldap::Manager do
 
     describe "is being updated" do
       it "should get created if the current attribute list is empty and the desired attribute list has :ensure == :present" do
-        @manager.expects(:create)
+        expect(@manager).to receive(:create)
         @manager.update(@name, {}, {:ensure => :present})
       end
 
       it "should get created if the current attribute list has :ensure == :absent and the desired attribute list has :ensure == :present" do
-        @manager.expects(:create)
+        expect(@manager).to receive(:create)
         @manager.update(@name, {:ensure => :absent}, {:ensure => :present})
       end
 
       it "should get deleted if the current attribute list has :ensure == :present and the desired attribute list has :ensure == :absent" do
-        @manager.expects(:delete)
+        expect(@manager).to receive(:delete)
         @manager.update(@name, {:ensure => :present}, {:ensure => :absent})
       end
 
       it "should get modified if both attribute lists have :ensure == :present" do
-        @manager.expects(:modify)
+        expect(@manager).to receive(:modify)
         @manager.update(@name, {:ensure => :present, :one => :two}, {:ensure => :present, :one => :three})
       end
     end
 
     describe "is being deleted" do
       it "should call the :delete method with its name and manager" do
-        @manager.expects(:delete).with(@name)
+        expect(@manager).to receive(:delete).with(@name)
 
         @manager.update(@name, {}, {:ensure => :absent})
       end
@@ -535,59 +538,59 @@ describe Puppet::Util::Ldap::Manager do
       end
 
       it "should call the :create method with its name" do
-        @manager.expects(:create).with { |name, attrs| name == @name }
+        expect(@manager).to receive(:create).with(@name, anything)
         @manager.update(@name, @is, @should)
       end
 
       it "should call the :create method with its property hash converted to ldap attribute names" do
-        @manager.expects(:create).with { |name, attrs| attrs["uno"] == ["yay"] }
+        expect(@manager).to receive(:create).with(anything, hash_including("uno" => ["yay"]))
         @manager.update(@name, @is, @should)
       end
 
       it "should convert the property names to strings" do
-        @manager.expects(:create).with { |name, attrs| attrs["uno"] == ["yay"] }
+        expect(@manager).to receive(:create).with(anything, hash_including("uno" => ["yay"]))
         @manager.update(@name, @is, @should)
       end
 
       it "should convert the property values to arrays if necessary" do
-        @manager.expects(:create).with { |name, attrs| attrs["uno"] == ["yay"] }
+        expect(@manager).to receive(:create).with(anything, hash_including("uno" => ["yay"]))
         @manager.update(@name, @is, @should)
       end
 
       it "should convert the property values to strings if necessary" do
-        @manager.expects(:create).with { |name, attrs| attrs["uno"] == ["yay"] }
+        expect(@manager).to receive(:create).with(anything, hash_including("uno" => ["yay"]))
         @manager.update(@name, @is, @should)
       end
 
       it "should not include :ensure in the properties sent" do
-        @manager.expects(:create).with { |*args| args[1][:ensure].nil? }
+        expect(@manager).to receive(:create).with(anything, hash_excluding(:ensure))
         @manager.update(@name, @is, @should)
       end
 
       it "should not include attributes set to :absent in the properties sent" do
-        @manager.expects(:create).with { |*args| args[1][:dos].nil? }
+        expect(@manager).to receive(:create).with(anything, hash_excluding(:dos))
         @manager.update(@name, @is, @should)
       end
     end
 
     describe "is being modified" do
       it "should call the :modify method with its name and an array of LDAP::Mod instances" do
-        LDAP::Mod.stubs(:new).returns "whatever"
+        allow(LDAP::Mod).to receive(:new).and_return("whatever")
 
         @is = {:one => :yay}
         @should = {:one => :yay, :two => :foo}
 
-        @manager.expects(:modify).with { |name, mods| name == @name }
+        expect(@manager).to receive(:modify).with(@name, anything)
         @manager.update(@name, @is, @should)
       end
 
       it "should create the LDAP::Mod with the property name converted to the ldap name as a string" do
         @is = {:one => :yay}
         @should = {:one => :yay, :two => :foo}
-        mod = mock 'module'
-        LDAP::Mod.expects(:new).with { |form, name, value| name == "dos" }.returns mod
+        mod = double('module')
+        expect(LDAP::Mod).to receive(:new).with(anything, "dos", anything).and_return(mod)
 
-        @manager.stubs(:modify)
+        allow(@manager).to receive(:modify)
 
         @manager.update(@name, @is, @should)
       end
@@ -595,10 +598,10 @@ describe Puppet::Util::Ldap::Manager do
       it "should create an LDAP::Mod instance of type LDAP_MOD_ADD for each attribute being added, with the attribute value converted to a string of arrays" do
         @is = {:one => :yay}
         @should = {:one => :yay, :two => :foo}
-        mod = mock 'module'
-        LDAP::Mod.expects(:new).with(LDAP::LDAP_MOD_ADD, "dos", ["foo"]).returns mod
+        mod = double('module')
+        expect(LDAP::Mod).to receive(:new).with(LDAP::LDAP_MOD_ADD, "dos", ["foo"]).and_return(mod)
 
-        @manager.stubs(:modify)
+        allow(@manager).to receive(:modify)
 
         @manager.update(@name, @is, @should)
       end
@@ -606,10 +609,10 @@ describe Puppet::Util::Ldap::Manager do
       it "should create an LDAP::Mod instance of type LDAP_MOD_DELETE for each attribute being deleted" do
         @is = {:one => :yay, :two => :foo}
         @should = {:one => :yay, :two => :absent}
-        mod = mock 'module'
-        LDAP::Mod.expects(:new).with(LDAP::LDAP_MOD_DELETE, "dos", []).returns mod
+        mod = double('module')
+        expect(LDAP::Mod).to receive(:new).with(LDAP::LDAP_MOD_DELETE, "dos", []).and_return(mod)
 
-        @manager.stubs(:modify)
+        allow(@manager).to receive(:modify)
 
         @manager.update(@name, @is, @should)
       end
@@ -617,10 +620,10 @@ describe Puppet::Util::Ldap::Manager do
       it "should create an LDAP::Mod instance of type LDAP_MOD_REPLACE for each attribute being modified, with the attribute converted to a string of arrays" do
         @is = {:one => :yay, :two => :four}
         @should = {:one => :yay, :two => :five}
-        mod = mock 'module'
-        LDAP::Mod.expects(:new).with(LDAP::LDAP_MOD_REPLACE, "dos", ["five"]).returns mod
+        mod = double('module')
+        expect(LDAP::Mod).to receive(:new).with(LDAP::LDAP_MOD_REPLACE, "dos", ["five"]).and_return(mod)
 
-        @manager.stubs(:modify)
+        allow(@manager).to receive(:modify)
 
         @manager.update(@name, @is, @should)
       end
@@ -628,11 +631,9 @@ describe Puppet::Util::Ldap::Manager do
       it "should pass all created Mod instances to the modify method" do
         @is = {:one => :yay, :two => :foo, :three => :absent}
         @should = {:one => :yay, :two => :foe, :three => :fee, :four => :fie}
-        LDAP::Mod.expects(:new).times(3).returns("mod1").then.returns("mod2").then.returns("mod3")
+        expect(LDAP::Mod).to receive(:new).exactly(3).times().and_return("mod1", "mod2", "mod3")
 
-        @manager.expects(:modify).with do |name, mods|
-          mods.sort == %w{mod1 mod2 mod3}.sort
-        end
+        expect(@manager).to receive(:modify).with(anything, contain_exactly(*%w{mod1 mod2 mod3}))
 
         @manager.update(@name, @is, @should)
       end
