@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 require 'puppet/util/network_device'
@@ -6,7 +5,7 @@ require 'puppet/util/network_device/cisco/facts'
 
 describe Puppet::Util::NetworkDevice::Cisco::Facts do
   before(:each) do
-    @transport = stub_everything 'transport'
+    @transport = double('transport')
     @facts = Puppet::Util::NetworkDevice::Cisco::Facts.new(@transport)
   end
 
@@ -18,7 +17,7 @@ describe Puppet::Util::NetworkDevice::Cisco::Facts do
     "cisco WS-C2950T-24 (RC32300) processor (revision R0) with 19959K bytes of memory." => {:hardwaremodel=>"WS-C2950T-24", :memorysize => "19959K", :processor => "RC32300", :hardwarerevision => "R0" }
   }.each do |ver, expected|
     it "should parse show ver output for hardware device facts" do
-      @transport.stubs(:command).with("sh ver").returns(<<eos)
+      allow(@transport).to receive(:command).with("sh ver").and_return(<<eos)
 Switch>sh ver
 #{ver}
 Switch>
@@ -36,7 +35,7 @@ eos
 "c2950 uptime is 2 years, 20 weeks, 6 minutes" => { :hostname => "c2950", :uptime=>"2 years, 20 weeks, 6 minutes", :uptime_seconds=>75168360, :uptime_days=>870 }
   }.each do |ver, expected|
     it "should parse show ver output for device uptime facts" do
-      @transport.stubs(:command).with("sh ver").returns(<<eos)
+      allow(@transport).to receive(:command).with("sh ver").and_return(<<eos)
 Switch>sh ver
 #{ver}
 Switch>
@@ -53,7 +52,7 @@ eos
 "Cisco IOS Software, 1841 Software (C1841-ADVSECURITYK9-M), Version 12.4(24)T4, RELEASE SOFTWARE (fc2)" =>{ :operatingsystem => "IOS", :operatingsystemrelease => "12.4(24)T4", :operatingsystemmajrelease => "12.4T", :operatingsystemfeature => "ADVSECURITYK9"},
   }.each do |ver, expected|
     it "should parse show ver output for device software version facts" do
-      @transport.stubs(:command).with("sh ver").returns(<<eos)
+      allow(@transport).to receive(:command).with("sh ver").and_return(<<eos)
 Switch>sh ver
 #{ver}
 Switch>
