@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 if Puppet.features.telnet?
@@ -7,7 +6,12 @@ if Puppet.features.telnet?
   describe Puppet::Util::NetworkDevice::Transport::Telnet do
 
     before(:each) do
-      TCPSocket.stubs(:open).returns stub_everything('tcp')
+      tcp = double(
+        'tcp',
+        :sync= => nil,
+        :binmode => nil,
+      )
+      allow(TCPSocket).to receive(:open).and_return(tcp)
       @transport = Puppet::Util::NetworkDevice::Transport::Telnet.new()
     end
 
@@ -16,7 +20,7 @@ if Puppet.features.telnet?
     end
 
     it "should not open any files" do
-      File.expects(:open).never
+      expect(File).not_to receive(:open)
       @transport.host = "localhost"
       @transport.port = 23
 
@@ -24,7 +28,7 @@ if Puppet.features.telnet?
     end
 
     it "should connect to the given host and port" do
-      Net::Telnet.expects(:new).with { |args| args["Host"] == "localhost" && args["Port"] == 23 }.returns stub_everything
+      expect(Net::Telnet).to receive(:new).with(hash_including("Host" => "localhost", "Port" => 23)).and_return(double("telnet connection"))
       @transport.host = "localhost"
       @transport.port = 23
 
@@ -33,7 +37,7 @@ if Puppet.features.telnet?
 
     it "should connect and specify the default prompt" do
       @transport.default_prompt = "prompt"
-      Net::Telnet.expects(:new).with { |args| args["Prompt"] == "prompt" }.returns stub_everything
+      expect(Net::Telnet).to receive(:new).with(hash_including("Prompt" => "prompt")).and_return(double("telnet connection"))
       @transport.host = "localhost"
       @transport.port = 23
 
@@ -42,29 +46,29 @@ if Puppet.features.telnet?
 
     describe "when connected" do
       before(:each) do
-        @telnet = stub_everything 'telnet'
-        Net::Telnet.stubs(:new).returns(@telnet)
+        @telnet = double('telnet')
+        allow(Net::Telnet).to receive(:new).and_return(@telnet)
         @transport.connect
       end
 
       it "should send line to the telnet session" do
-        @telnet.expects(:puts).with("line")
+        expect(@telnet).to receive(:puts).with("line")
         @transport.send("line")
       end
 
       describe "when expecting output" do
         it "should waitfor output on the telnet session" do
-          @telnet.expects(:waitfor).with(/regex/)
+          expect(@telnet).to receive(:waitfor).with(/regex/)
           @transport.expect(/regex/)
         end
 
         it "should return telnet session output" do
-          @telnet.expects(:waitfor).returns("output")
+          expect(@telnet).to receive(:waitfor).and_return("output")
           expect(@transport.expect(/regex/)).to eq("output")
         end
 
         it "should yield telnet session output to the given block" do
-          @telnet.expects(:waitfor).yields("output")
+          expect(@telnet).to receive(:waitfor).and_yield("output")
           @transport.expect(/regex/) { |out| expect(out).to eq("output") }
         end
       end
@@ -72,13 +76,13 @@ if Puppet.features.telnet?
 
     describe "when closing" do
       before(:each) do
-        @telnet = stub_everything 'telnet'
-        Net::Telnet.stubs(:new).returns(@telnet)
+        @telnet = double('telnet')
+        allow(Net::Telnet).to receive(:new).and_return(@telnet)
         @transport.connect
       end
 
       it "should close the telnet session" do
-        @telnet.expects(:close)
+        expect(@telnet).to receive(:close)
         @transport.close
       end
     end
