@@ -1,5 +1,3 @@
-#! /usr/bin/env ruby
-
 require 'spec_helper'
 
 describe Puppet::Util::SUIDManager do
@@ -12,18 +10,18 @@ describe Puppet::Util::SUIDManager do
   end
 
   before :each do
-    Puppet::Util::SUIDManager.stubs(:convert_xid).returns(42)
-    pwent = stub('pwent', :name => 'fred', :uid => 42, :gid => 42)
-    Etc.stubs(:getpwuid).with(42).returns(pwent)
+    allow(Puppet::Util::SUIDManager).to receive(:convert_xid).and_return(42)
+    pwent = double('pwent', :name => 'fred', :uid => 42, :gid => 42)
+    allow(Etc).to receive(:getpwuid).with(42).and_return(pwent)
 
     [:euid, :egid, :uid, :gid, :groups].each do |id|
-      Process.stubs("#{id}=").with {|value| xids[id] = value }
+      allow(Process).to receive("#{id}=") {|value| xids[id] = value}
     end
   end
 
   describe "#initgroups" do
     it "should use the primary group of the user as the 'basegid'" do
-      Process.expects(:initgroups).with('fred', 42)
+      expect(Process).to receive(:initgroups).with('fred', 42)
       described_class.initgroups(42)
     end
   end
@@ -40,11 +38,11 @@ describe Puppet::Util::SUIDManager do
 
   describe "#asuser" do
     it "should not get or set euid/egid when not root" do
-      Puppet.features.stubs(:microsoft_windows?).returns(false)
-      Process.stubs(:uid).returns(1)
+      allow(Puppet.features).to receive(:microsoft_windows?).and_return(false)
+      allow(Process).to receive(:uid).and_return(1)
 
-      Process.stubs(:egid).returns(51)
-      Process.stubs(:euid).returns(50)
+      allow(Process).to receive(:egid).and_return(51)
+      allow(Process).to receive(:euid).and_return(50)
 
       Puppet::Util::SUIDManager.asuser(user[:uid], user[:gid]) {}
 
@@ -53,17 +51,17 @@ describe Puppet::Util::SUIDManager do
 
     context "when root and not windows" do
       before :each do
-        Process.stubs(:uid).returns(0)
-        Puppet.features.stubs(:microsoft_windows?).returns(false)
+        allow(Process).to receive(:uid).and_return(0)
+        allow(Puppet.features).to receive(:microsoft_windows?).and_return(false)
       end
 
       it "should set euid/egid" do
-        Process.stubs(:egid).returns(51).then.returns(51).then.returns(user[:gid])
-        Process.stubs(:euid).returns(50).then.returns(50).then.returns(user[:uid])
+        allow(Process).to receive(:egid).and_return(51, 51, user[:gid])
+        allow(Process).to receive(:euid).and_return(50, 50, user[:uid])
 
-        Puppet::Util::SUIDManager.stubs(:convert_xid).with(:gid, 51).returns(51)
-        Puppet::Util::SUIDManager.stubs(:convert_xid).with(:uid, 50).returns(50)
-        Puppet::Util::SUIDManager.stubs(:initgroups).returns([])
+        allow(Puppet::Util::SUIDManager).to receive(:convert_xid).with(:gid, 51).and_return(51)
+        allow(Puppet::Util::SUIDManager).to receive(:convert_xid).with(:uid, 50).and_return(50)
+        allow(Puppet::Util::SUIDManager).to receive(:initgroups).and_return([])
 
         yielded = false
         Puppet::Util::SUIDManager.asuser(user[:uid], user[:gid]) do
@@ -95,7 +93,7 @@ describe Puppet::Util::SUIDManager do
       end
 
       it "should change gid to the primary group of uid by default" do
-        Process.stubs(:initgroups)
+        allow(Process).to receive(:initgroups)
 
         yielded = false
         Puppet::Util::SUIDManager.asuser(42) { yielded = true }
@@ -107,13 +105,10 @@ describe Puppet::Util::SUIDManager do
         # I don't like the sequence, but it is the only way to assert on the
         # internal behaviour in a reliable fashion, given we need multiple
         # sequenced calls to the same methods. --daniel 2012-02-05
-        horror = sequence('of user and group changes')
-        Puppet::Util::SUIDManager.expects(:change_group).with(43, false).in_sequence(horror)
-        Puppet::Util::SUIDManager.expects(:change_user).with(42, false).in_sequence(horror)
-        Puppet::Util::SUIDManager.expects(:change_group).
-          with(Puppet::Util::SUIDManager.egid, false).in_sequence(horror)
-        Puppet::Util::SUIDManager.expects(:change_user).
-          with(Puppet::Util::SUIDManager.euid, false).in_sequence(horror)
+        expect(Puppet::Util::SUIDManager).to receive(:change_group).with(43, false).ordered()
+        expect(Puppet::Util::SUIDManager).to receive(:change_user).with(42, false).ordered()
+        expect(Puppet::Util::SUIDManager).to receive(:change_group).with(Puppet::Util::SUIDManager.egid, false).ordered()
+        expect(Puppet::Util::SUIDManager).to receive(:change_user).with(Puppet::Util::SUIDManager.euid, false).ordered()
 
         yielded = false
         Puppet::Util::SUIDManager.asuser(42, 43) { yielded = true }
@@ -131,7 +126,7 @@ describe Puppet::Util::SUIDManager do
   describe "#change_group" do
     describe "when changing permanently" do
       it "should change_privilege" do
-        Process::GID.expects(:change_privilege).with do |gid|
+        expect(Process::GID).to receive(:change_privilege) do |gid|
           Process.gid = gid
           Process.egid = gid
         end
@@ -143,7 +138,7 @@ describe Puppet::Util::SUIDManager do
       end
 
       it "should not change_privilege when gid already matches" do
-        Process::GID.expects(:change_privilege).with do |gid|
+        expect(Process::GID).to receive(:change_privilege) do |gid|
           Process.gid = 42
           Process.egid = 42
         end
@@ -168,25 +163,26 @@ describe Puppet::Util::SUIDManager do
   describe "#change_user" do
     describe "when changing permanently" do
       it "should change_privilege" do
-        Process::UID.expects(:change_privilege).with do |uid|
+        expect(Process::UID).to receive(:change_privilege) do |uid|
           Process.uid = uid
           Process.euid = uid
         end
 
-        Puppet::Util::SUIDManager.expects(:initgroups).with(42)
+        expect(Puppet::Util::SUIDManager).to receive(:initgroups).with(42)
 
         Puppet::Util::SUIDManager.change_user(42, true)
 
         expect(xids[:euid]).to eq(42)
         expect(xids[:uid]).to eq(42)
       end
+
       it "should not change_privilege when uid already matches" do
-        Process::UID.expects(:change_privilege).with do |uid|
+        expect(Process::UID).to receive(:change_privilege) do |uid|
           Process.uid = 42
           Process.euid = 42
         end
 
-        Puppet::Util::SUIDManager.expects(:initgroups).with(42)
+        expect(Puppet::Util::SUIDManager).to receive(:initgroups).with(42)
 
         Puppet::Util::SUIDManager.change_user(42, true)
 
@@ -197,7 +193,7 @@ describe Puppet::Util::SUIDManager do
 
     describe "when changing temporarily" do
       it "should change only euid and groups" do
-        Puppet::Util::SUIDManager.stubs(:initgroups).returns([])
+        allow(Puppet::Util::SUIDManager).to receive(:initgroups).and_return([])
         Puppet::Util::SUIDManager.change_user(42, false)
 
         expect(xids[:euid]).to eq(42)
@@ -205,23 +201,19 @@ describe Puppet::Util::SUIDManager do
       end
 
       it "should set euid before groups if changing to root" do
-        Process.stubs(:euid).returns 50
+        allow(Process).to receive(:euid).and_return(50)
 
-        when_not_root = sequence 'when_not_root'
-
-        Process.expects(:euid=).in_sequence(when_not_root)
-        Puppet::Util::SUIDManager.expects(:initgroups).in_sequence(when_not_root)
+        expect(Process).to receive(:euid=).ordered()
+        expect(Puppet::Util::SUIDManager).to receive(:initgroups).ordered()
 
         Puppet::Util::SUIDManager.change_user(0, false)
       end
 
       it "should set groups before euid if changing from root" do
-        Process.stubs(:euid).returns 0
+        allow(Process).to receive(:euid).and_return(0)
 
-        when_root = sequence 'when_root'
-
-        Puppet::Util::SUIDManager.expects(:initgroups).in_sequence(when_root)
-        Process.expects(:euid=).in_sequence(when_root)
+        expect(Puppet::Util::SUIDManager).to receive(:initgroups).ordered()
+        expect(Process).to receive(:euid=).ordered()
 
         Puppet::Util::SUIDManager.change_user(50, false)
       end
@@ -231,18 +223,18 @@ describe Puppet::Util::SUIDManager do
   describe "#root?" do
     describe "on POSIX systems" do
       before :each do
-        Puppet.features.stubs(:posix?).returns(true)
-        Puppet.features.stubs(:microsoft_windows?).returns(false)
+        allow(Puppet.features).to receive(:posix?).and_return(true)
+        allow(Puppet.features).to receive(:microsoft_windows?).and_return(false)
       end
 
       it "should be root if uid is 0" do
-        Process.stubs(:uid).returns(0)
+        allow(Process).to receive(:uid).and_return(0)
 
         expect(Puppet::Util::SUIDManager).to be_root
       end
 
       it "should not be root if uid is not 0" do
-        Process.stubs(:uid).returns(1)
+        allow(Process).to receive(:uid).and_return(1)
 
         expect(Puppet::Util::SUIDManager).not_to be_root
       end
@@ -250,13 +242,13 @@ describe Puppet::Util::SUIDManager do
 
     describe "on Microsoft Windows", :if => Puppet.features.microsoft_windows? do
       it "should be root if user is privileged" do
-        Puppet::Util::Windows::User.stubs(:admin?).returns true
+        allow(Puppet::Util::Windows::User).to receive(:admin?).and_return(true)
 
         expect(Puppet::Util::SUIDManager).to be_root
       end
 
       it "should not be root if user is not privileged" do
-        Puppet::Util::Windows::User.stubs(:admin?).returns false
+        allow(Puppet::Util::Windows::User).to receive(:admin?).and_return(false)
 
         expect(Puppet::Util::SUIDManager).not_to be_root
       end
@@ -269,16 +261,15 @@ describe 'Puppet::Util::SUIDManager#groups=' do
     Puppet::Util::SUIDManager
   end
 
-
   it "(#3419) should rescue Errno::EINVAL on OS X" do
-    Process.expects(:groups=).raises(Errno::EINVAL, 'blew up')
-    subject.expects(:osx_maj_ver).returns('10.7').twice
+    expect(Process).to receive(:groups=).and_raise(Errno::EINVAL, 'blew up')
+    expect(subject).to receive(:osx_maj_ver).and_return('10.7').twice
     subject.groups = ['list', 'of', 'groups']
   end
 
   it "(#3419) should fail if an Errno::EINVAL is raised NOT on OS X" do
-    Process.expects(:groups=).raises(Errno::EINVAL, 'blew up')
-    subject.expects(:osx_maj_ver).returns(false)
+    expect(Process).to receive(:groups=).and_raise(Errno::EINVAL, 'blew up')
+    expect(subject).to receive(:osx_maj_ver).and_return(false)
     expect { subject.groups = ['list', 'of', 'groups'] }.to raise_error(Errno::EINVAL)
   end
 end
